@@ -97,7 +97,7 @@ public final class EssentialCycles {
         Objects.requireNonNull(relevant, "No RelevantCycles provided");
         this.initial = Objects.requireNonNull(initial, "No InitialCycles provided");
         this.basis = new GreedyBasis(initial.numberOfCycles(), initial.numberOfEdges());
-        this.essential = new ArrayList<Cycle>();
+        this.essential = new ArrayList<>();
 
         // for each cycle added to the basis, if it can be
         // replaced with one of equal size it is non-essential
@@ -136,10 +136,10 @@ public final class EssentialCycles {
      * @return all relevant cycles groped by weight
      */
     private List<List<Cycle>> groupByLength(final RelevantCycles relevant) {
-        LinkedList<List<Cycle>> cyclesByLength = new LinkedList<List<Cycle>>();
+        LinkedList<List<Cycle>> cyclesByLength = new LinkedList<>();
         for (int[] path : relevant.paths()) {
             if (cyclesByLength.isEmpty() || path.length > cyclesByLength.getLast().get(0).path().length) {
-                cyclesByLength.add(new ArrayList<Cycle>());
+                cyclesByLength.add(new ArrayList<>());
             }
             cyclesByLength.getLast().add(new MyCycle(path));
         }
@@ -171,7 +171,7 @@ public final class EssentialCycles {
     private boolean isEssential(final Cycle candidate, final Collection<Cycle> relevant) {
 
         // construct an alternative basis with all equal weight relevant cycles
-        final List<Cycle> alternate = new ArrayList<Cycle>(relevant.size() + basis.size());
+        final List<Cycle> alternate = new ArrayList<>(relevant.size() + basis.size());
 
         final int weight = candidate.length();
         for (final Cycle cycle : basis.members()) {
