@@ -147,9 +147,9 @@ public class DefaultChemObjectBuilder implements IChemObjectBuilder {
             // atom containers
             if (CDK_LEGACY_AC) {
                 System.err.println("[WARN] Using the old AtomContainer implementation.");
-                factory.register(IAtomContainer.class, AtomContainer.class);
+                factory.register(IAtomContainer.class, AtomContainerLegacy.class);
             } else {
-                factory.register(IAtomContainer.class, AtomContainer2.class);
+                factory.register(IAtomContainer.class, AtomContainer.class);
             }
 
             factory.register(IRing.class, Ring.class);
@@ -234,9 +234,9 @@ public class DefaultChemObjectBuilder implements IChemObjectBuilder {
         @Override
         public IAtomContainer newAtomContainer() {
             if (CDK_LEGACY_AC)
-                return new AtomContainer(0, 0, 0, 0);
+                return new AtomContainerLegacy(0, 0, 0, 0);
             else
-                return new AtomContainer2(0, 0, 0, 0);
+                return new AtomContainer(0, 0, 0, 0);
 
         }
 
