@@ -26,7 +26,6 @@ package org.openscience.cdk.templates;
 import javax.vecmath.Point2d;
 
 import org.openscience.cdk.Atom;
-import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.config.Isotopes;
 import org.openscience.cdk.interfaces.IAtom;
@@ -44,7 +43,7 @@ import org.openscience.cdk.tools.LoggingToolFactory;
  */
 public class TestMoleculeFactory {
 
-    private static ILoggingTool logger = LoggingToolFactory.createLoggingTool(TestMoleculeFactory.class);
+    private static final ILoggingTool logger = LoggingToolFactory.createLoggingTool(TestMoleculeFactory.class);
     
     private static IAtomContainer newAtomContainer() {
         return DefaultChemObjectBuilder.getInstance().newAtomContainer();
