@@ -21,9 +21,9 @@ package org.openscience.cdk.debug;
 
 import javax.vecmath.Point3d;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.interfaces.AbstractPDBAtomTest;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IChemObject;
@@ -36,10 +36,10 @@ import org.openscience.cdk.test.interfaces.ITestObjectBuilder;
  *
  * @cdk.module test-datadebug
  */
-public class DebugPDBAtomTest extends AbstractPDBAtomTest {
+class DebugPDBAtomTest extends AbstractPDBAtomTest {
 
-    @BeforeClass
-    public static void setUp() {
+    @BeforeAll
+    static void setUp() {
         setTestObjectBuilder(new ITestObjectBuilder() {
 
             @Override
@@ -50,35 +50,35 @@ public class DebugPDBAtomTest extends AbstractPDBAtomTest {
     }
 
     @Test
-    public void testDebugPDBAtom_IElement() {
+    void testDebugPDBAtom_IElement() {
         IElement element = new DebugElement();
         IAtom a = element.getBuilder().newInstance(IPDBAtom.class, element);
-        Assert.assertNotNull(a);
+        Assertions.assertNotNull(a);
     }
 
     /**
      * Method to test the Atom(String symbol) method.
      */
     @Test
-    public void testDebugPDBAtom_String() {
+    void testDebugPDBAtom_String() {
         IPDBAtom a = new DebugPDBAtom("C");
-        Assert.assertEquals("C", a.getSymbol());
-        Assert.assertNull(a.getPoint2d());
-        Assert.assertNull(a.getPoint3d());
-        Assert.assertNull(a.getFractionalPoint3d());
+        Assertions.assertEquals("C", a.getSymbol());
+        Assertions.assertNull(a.getPoint2d());
+        Assertions.assertNull(a.getPoint3d());
+        Assertions.assertNull(a.getFractionalPoint3d());
     }
 
     /**
      * Method to test the Atom(String symbol, javax.vecmath.Point3d point3D) method.
      */
     @Test
-    public void testDebugPDBAtom_String_Point3d() {
+    void testDebugPDBAtom_String_Point3d() {
         Point3d point3d = new Point3d(1.0, 2.0, 3.0);
 
         IPDBAtom a = new DebugPDBAtom("C", point3d);
-        Assert.assertEquals("C", a.getSymbol());
-        Assert.assertEquals(point3d, a.getPoint3d());
-        Assert.assertNull(a.getPoint2d());
-        Assert.assertNull(a.getFractionalPoint3d());
+        Assertions.assertEquals("C", a.getSymbol());
+        Assertions.assertEquals(point3d, a.getPoint3d());
+        Assertions.assertNull(a.getPoint2d());
+        Assertions.assertNull(a.getFractionalPoint3d());
     }
 }
