@@ -28,12 +28,12 @@ import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IChemObjectBuilder;
 import org.openscience.cdk.isomorphism.matchers.IQueryAtom;
-import org.openscience.cdk.isomorphism.matchers.IQueryAtomContainer;
 import org.openscience.cdk.isomorphism.matchers.IQueryBond;
 
 import java.lang.reflect.Method;
 import java.util.Arrays;
 import java.util.Iterator;
+import java.util.NoSuchElementException;
 
 /**
  * Internals of the DF ("Depth-First" {@cdk.cite Jeliazkova18}) substructure
@@ -97,7 +97,7 @@ final class DfState implements Iterable<int[]> {
     }
 
     private int          sptr;
-    private StackFrame[] stack;
+    private final StackFrame[] stack;
 
     DfState(IAtomContainer query) {
 
@@ -105,7 +105,7 @@ final class DfState implements Iterable<int[]> {
         if (builder == null) {
             builder = findBuilder();
             if (builder == null)
-                throw new IllegalArgumentException("Please ensure query molecule" +
+                throw new IllegalArgumentException("Please ensure query molecule " +
                                                    "has a IChemObjectBuilder set!");
         }
 
@@ -416,7 +416,7 @@ final class DfState implements Iterable<int[]> {
             @Override
             public int[] next() {
                 if (!hasNext())
-                    return new int[0];
+                    throw new NoSuchElementException();
                 hasNext = false;
                 return lstate.amap;
             }
