@@ -156,11 +156,11 @@ public class QueryAtomContainer extends QueryChemObject implements IQueryAtomCon
         stereoElements = new ArrayList<>(atomCount / 2);
 
         for (int f = 0; f < container.getAtomCount(); f++) {
-            atoms[f] = container.getAtom(f);
+            atoms[f] = AtomRef.deref(container.getAtom(f));
             container.getAtom(f).addListener(this);
         }
         for (int f = 0; f < this.bondCount; f++) {
-            bonds[f] = container.getBond(f);
+            bonds[f] = BondRef.deref(container.getBond(f));
             container.getBond(f).addListener(this);
         }
         for (int f = 0; f < this.lonePairCount; f++) {
@@ -224,8 +224,9 @@ public class QueryAtomContainer extends QueryChemObject implements IQueryAtomCon
     @Override
     public void setAtoms(IAtom[] atoms) {
         this.atoms = atoms;
-        for (IAtom atom : atoms) {
-            atom.addListener(this);
+        for (int i = 0; i < atoms.length; i++) {
+            atoms[i] = AtomRef.deref(atoms[i]);
+            atoms[i].addListener(this);
         }
         this.atomCount = atoms.length;
         notifyChanged();
@@ -241,8 +242,9 @@ public class QueryAtomContainer extends QueryChemObject implements IQueryAtomCon
     @Override
     public void setBonds(IBond[] bonds) {
         this.bonds = bonds;
-        for (IBond bond : bonds) {
-            bond.addListener(this);
+        for (int i = 0; i < bonds.length; i++) {
+            bonds[i] = BondRef.deref(bonds[i]);
+            bonds[i].addListener(this);
         }
         this.bondCount = bonds.length;
     }
@@ -254,6 +256,7 @@ public class QueryAtomContainer extends QueryChemObject implements IQueryAtomCon
     public void setAtom(int idx, IAtom atom) {
         if (idx >= atomCount)
             throw new IndexOutOfBoundsException("No atom at index: " + idx);
+        atom = AtomRef.deref(atom);
         int aidx = indexOf(atom);
         if (aidx >= 0)
             throw new IllegalArgumentException("Atom already in container at index: " + idx);
@@ -897,17 +900,9 @@ public class QueryAtomContainer extends QueryChemObject implements IQueryAtomCon
     public double getBondOrderSum(IAtom atom) {
         double count = 0;
         for (int i = 0; i < bondCount; i++) {
-            if (bonds[i].contains(atom)) {
-                if (bonds[i].getOrder() == IBond.Order.SINGLE) {
-                    count += 1;
-                } else if (bonds[i].getOrder() == IBond.Order.DOUBLE) {
-                    count += 2;
-                } else if (bonds[i].getOrder() == IBond.Order.TRIPLE) {
-                    count += 3;
-                } else if (bonds[i].getOrder() == IBond.Order.QUADRUPLE) {
-                    count += 4;
-                }
-            }
+            IBond bond = bonds[i];
+            if (bond.contains(atom) && bond.getOrder() != null)
+                count += bond.getOrder().numeric();
         }
         return count;
     }
@@ -923,8 +918,11 @@ public class QueryAtomContainer extends QueryChemObject implements IQueryAtomCon
     public Order getMaximumBondOrder(IAtom atom) {
         IBond.Order max = IBond.Order.SINGLE;
         for (int i = 0; i < bondCount; i++) {
-            if (bonds[i].contains(atom) && bonds[i].getOrder().ordinal() > max.ordinal()) {
-                max = bonds[i].getOrder();
+            IBond bond = bonds[i];
+            if (bond.contains(atom) &&
+                    bond.getOrder() != null &&
+                    bond.getOrder().numeric() > max.numeric()) {
+                max = bond.getOrder();
             }
         }
         return max;
@@ -941,8 +939,11 @@ public class QueryAtomContainer extends QueryChemObject implements IQueryAtomCon
     public Order getMinimumBondOrder(IAtom atom) {
         IBond.Order min = IBond.Order.QUADRUPLE;
         for (int i = 0; i < bondCount; i++) {
-            if (bonds[i].contains(atom) && bonds[i].getOrder().ordinal() < min.ordinal()) {
-                min = bonds[i].getOrder();
+            IBond bond = bonds[i];
+            if (bond.contains(atom) &&
+                    bond.getOrder() != null &&
+                    bond.getOrder().numeric() < min.numeric()) {
+                min = bond.getOrder();
             }
         }
         return min;
@@ -990,6 +991,7 @@ public class QueryAtomContainer extends QueryChemObject implements IQueryAtomCon
      */
     @Override
     public void addAtom(IAtom atom) {
+        atom = AtomRef.deref(atom);
         if (contains(atom)) {
             return;
         }
@@ -1010,6 +1012,7 @@ public class QueryAtomContainer extends QueryChemObject implements IQueryAtomCon
      */
     @Override
     public void addBond(IBond bond) {
+        bond = BondRef.deref(bond);
         if (bondCount >= bonds.length) growBondArray();
         bonds[bondCount] = bond;
         ++bondCount;
