@@ -61,7 +61,7 @@ public class QueryChemObject implements IChemObject {
      *  flag array with self-defined constants (flags[VISITED] = true). 100 flags
      *  per object should be more than enough.
      */
-    private short                     flags;                                   // flags are currently stored as a single short value MAX_FLAG_INDEX < 16
+    private int                       flags;                                   // flags are currently stored as a single short value MAX_FLAG_INDEX < 16
 
     private final IChemObjectBuilder  builder;
 
@@ -354,10 +354,30 @@ public class QueryChemObject implements IChemObject {
      *{@inheritDoc}
      */
     @Override
-    public Short getFlagValue() {
+    public Integer getFlagValue() {
         return flags;
     }
 
+    @Override
+    public void set(int flags) {
+        this.flags |= flags;
+    }
+
+    @Override
+    public void clear(int flags) {
+        this.flags &= ~flags;
+    }
+
+    @Override
+    public boolean is(int flags) {
+        return (this.flags&flags) == flags;
+    }
+
+    @Override
+    public int flags() {
+        return this.flags;
+    }
+
     @Override
     public void setNotification(boolean bool) {
         this.doNotification = bool;
