@@ -21,7 +21,6 @@ package org.openscience.cdk.reaction.mechanism;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.atomtype.CDKAtomTypeMatcher;
 import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.graph.ConnectivityChecker;
@@ -30,6 +29,7 @@ import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IAtomContainerSet;
 import org.openscience.cdk.interfaces.IAtomType;
 import org.openscience.cdk.interfaces.IBond;
+import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.interfaces.ILonePair;
 import org.openscience.cdk.interfaces.IMapping;
 import org.openscience.cdk.interfaces.IReaction;
@@ -121,12 +121,12 @@ public class RearrangementChargeMechanism implements IReactionMechanism {
             atom1C.setFormalCharge(charge + 1);
             List<ILonePair> ln = reactantCloned.getConnectedLonePairsList(atom1C);
             reactantCloned.removeLonePair(ln.get(ln.size() - 1));
-            atom1C.setFlag(CDKConstants.ISAROMATIC, false);
+            atom1C.setFlag(IChemObject.AROMATIC, false);
 
             charge = atom3C.getFormalCharge();
             atom3C.setFormalCharge(charge - 1);
             reactantCloned.addLonePair(bond2.getBuilder().newInstance(ILonePair.class, atom3C));
-            atom3C.setFlag(CDKConstants.ISAROMATIC, false);
+            atom3C.setFlag(IChemObject.AROMATIC, false);
         } else
             return null;
 
