@@ -24,6 +24,7 @@ import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IAtomContainerSet;
 import org.openscience.cdk.interfaces.IBond;
+import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.interfaces.IElement;
 import org.openscience.cdk.interfaces.IReaction;
 import org.openscience.cdk.interfaces.IReactionSet;
@@ -126,22 +127,22 @@ public class HyperconjugationReaction extends ReactionEngine implements IReactio
         if (ipr != null && !ipr.isSetParameter()) setActiveCenters(reactant);
 
         for (IAtom atomi : reactant.atoms()) {
-            if (atomi.getFlag(CDKConstants.REACTIVE_CENTER) && atomi.getFormalCharge() == 1) {
+            if (atomi.getFlag(IChemObject.REACTIVE_CENTER) && atomi.getFormalCharge() == 1) {
 
                 for (IBond bondi : reactant.getConnectedBondsList(atomi)) {
-                    if (bondi.getFlag(CDKConstants.REACTIVE_CENTER) && bondi.getOrder() == IBond.Order.SINGLE) {
+                    if (bondi.getFlag(IChemObject.REACTIVE_CENTER) && bondi.getOrder() == IBond.Order.SINGLE) {
 
                         IAtom atomj = bondi.getOther(atomi);
-                        if (atomj.getFlag(CDKConstants.REACTIVE_CENTER)
+                        if (atomj.getFlag(IChemObject.REACTIVE_CENTER)
                                 && (atomj.getFormalCharge() == CDKConstants.UNSET ? 0 : atomj.getFormalCharge()) == 0
                                 && reactant.getConnectedSingleElectronsCount(atomj) == 0) {
                             for (IBond bondj : reactant.getConnectedBondsList(atomj)) {
                                 if (bondj.equals(bondi)) continue;
 
-                                if (bondj.getFlag(CDKConstants.REACTIVE_CENTER)
+                                if (bondj.getFlag(IChemObject.REACTIVE_CENTER)
                                         && bondj.getOrder() == IBond.Order.SINGLE) {
                                     IAtom atomk = bondj.getOther(atomj);
-                                    if (atomk.getFlag(CDKConstants.REACTIVE_CENTER)
+                                    if (atomk.getFlag(IChemObject.REACTIVE_CENTER)
                                             && reactant.getConnectedSingleElectronsCount(atomk) == 0
                                             && (atomk.getFormalCharge() == CDKConstants.UNSET ? 0 : atomk
                                             .getFormalCharge()) == 0 && atomk.getAtomicNumber() == IElement.H) {
@@ -206,11 +207,11 @@ public class HyperconjugationReaction extends ReactionEngine implements IReactio
                                             && (atomk.getFormalCharge() == CDKConstants.UNSET ? 0 : atomk
                                             .getFormalCharge()) == 0 && atomk.getAtomicNumber() == IElement.H) {
 
-                                        atomi.setFlag(CDKConstants.REACTIVE_CENTER, true);
-                                        atomj.setFlag(CDKConstants.REACTIVE_CENTER, true);
-                                        atomk.setFlag(CDKConstants.REACTIVE_CENTER, true);
-                                        bondi.setFlag(CDKConstants.REACTIVE_CENTER, true);
-                                        bondj.setFlag(CDKConstants.REACTIVE_CENTER, true);
+                                        atomi.setFlag(IChemObject.REACTIVE_CENTER, true);
+                                        atomj.setFlag(IChemObject.REACTIVE_CENTER, true);
+                                        atomk.setFlag(IChemObject.REACTIVE_CENTER, true);
+                                        bondi.setFlag(IChemObject.REACTIVE_CENTER, true);
+                                        bondj.setFlag(IChemObject.REACTIVE_CENTER, true);
                                     }
 
                                 }
