@@ -18,11 +18,11 @@
  */
 package org.openscience.cdk.reaction.type;
 
-import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IAtomContainerSet;
 import org.openscience.cdk.interfaces.IBond;
+import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.interfaces.IReaction;
 import org.openscience.cdk.interfaces.IReactionSet;
 import org.openscience.cdk.interfaces.IRing;
@@ -149,7 +149,7 @@ public class PiBondingMovementReaction extends ReactionEngine implements IReacti
                     Iterator<IBond> bondfs = ring.bonds().iterator();
                     boolean ringCompletActive = false;
                     while (bondfs.hasNext()) {
-                        if (bondfs.next().getFlag(CDKConstants.REACTIVE_CENTER))
+                        if (bondfs.next().getFlag(IChemObject.REACTIVE_CENTER))
                             ringCompletActive = true;
                         else {
                             ringCompletActive = false;
@@ -211,7 +211,7 @@ public class PiBondingMovementReaction extends ReactionEngine implements IReacti
                 //if exactly half (nrAtoms/2==nrSingleBonds)
                 if (nrSingleBonds != 0 && nrAtoms / 2 == nrSingleBonds) {
                     for (IBond iBond : ring.bonds())
-                        iBond.setFlag(CDKConstants.REACTIVE_CENTER, true);
+                        iBond.setFlag(IChemObject.REACTIVE_CENTER, true);
 
                 }
             }
