@@ -18,12 +18,12 @@
  */
 package org.openscience.cdk.reaction.type;
 
-import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IAtomContainerSet;
 import org.openscience.cdk.interfaces.IBond;
+import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.interfaces.IReaction;
 import org.openscience.cdk.interfaces.IReactionSet;
 import org.openscience.cdk.reaction.IReactionProcess;
@@ -125,13 +125,13 @@ public class SharingChargeSBReaction extends ReactionEngine implements IReaction
         if (ipr != null && !ipr.isSetParameter()) setActiveCenters(reactant);
 
         for (IAtom atomi : reactant.atoms()) {
-            if (atomi.getFlag(CDKConstants.REACTIVE_CENTER) && atomi.getFormalCharge() == 1) {
+            if (atomi.getFlag(IChemObject.REACTIVE_CENTER) && atomi.getFormalCharge() == 1) {
 
                 for (IBond bondi : reactant.getConnectedBondsList(atomi)) {
-                    if (bondi.getFlag(CDKConstants.REACTIVE_CENTER) && bondi.getOrder() == IBond.Order.SINGLE) {
+                    if (bondi.getFlag(IChemObject.REACTIVE_CENTER) && bondi.getOrder() == IBond.Order.SINGLE) {
 
                         IAtom atomj = bondi.getOther(atomi);
-                        if (atomj.getFlag(CDKConstants.REACTIVE_CENTER) && atomj.getFormalCharge() == 0)
+                        if (atomj.getFlag(IChemObject.REACTIVE_CENTER) && atomj.getFormalCharge() == 0)
                             if (reactant.getConnectedSingleElectronsCount(atomj) == 0) {
 
                                 ArrayList<IAtom> atomList = new ArrayList<>();
@@ -178,9 +178,9 @@ public class SharingChargeSBReaction extends ReactionEngine implements IReaction
 
                         IAtom atomj = bondi.getOther(atomi);
                         if (atomj.getFormalCharge() == 0) if (reactant.getConnectedSingleElectronsCount(atomj) == 0) {
-                            atomi.setFlag(CDKConstants.REACTIVE_CENTER, true);
-                            bondi.setFlag(CDKConstants.REACTIVE_CENTER, true);
-                            atomj.setFlag(CDKConstants.REACTIVE_CENTER, true);
+                            atomi.setFlag(IChemObject.REACTIVE_CENTER, true);
+                            bondi.setFlag(IChemObject.REACTIVE_CENTER, true);
+                            atomj.setFlag(IChemObject.REACTIVE_CENTER, true);
                         }
                     }
                 }
