@@ -20,7 +20,6 @@ package org.openscience.cdk.reaction.type;
 
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
-import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.LonePair;
 import org.openscience.cdk.atomtype.CDKAtomTypeMatcher;
@@ -29,6 +28,7 @@ import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IAtomContainerSet;
 import org.openscience.cdk.interfaces.IBond;
+import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.interfaces.IChemObjectBuilder;
 import org.openscience.cdk.interfaces.IReactionSet;
 import org.openscience.cdk.isomorphism.UniversalIsomorphismTester;
@@ -124,11 +124,11 @@ public class CarbonylEliminationReactionTest extends ReactionProcessTest {
 
         /* initiate */
         /* manually put the reactive center */
-        molecule.getAtom(0).setFlag(CDKConstants.REACTIVE_CENTER, true);
-        molecule.getAtom(4).setFlag(CDKConstants.REACTIVE_CENTER, true);
-        molecule.getAtom(5).setFlag(CDKConstants.REACTIVE_CENTER, true);
-        molecule.getBond(3).setFlag(CDKConstants.REACTIVE_CENTER, true);
-        molecule.getBond(4).setFlag(CDKConstants.REACTIVE_CENTER, true);
+        molecule.getAtom(0).setFlag(IChemObject.REACTIVE_CENTER, true);
+        molecule.getAtom(4).setFlag(IChemObject.REACTIVE_CENTER, true);
+        molecule.getAtom(5).setFlag(IChemObject.REACTIVE_CENTER, true);
+        molecule.getBond(3).setFlag(IChemObject.REACTIVE_CENTER, true);
+        molecule.getBond(4).setFlag(IChemObject.REACTIVE_CENTER, true);
 
         List<IParameterReact> paramList = new ArrayList<>();
         IParameterReact param = new SetReactionCenter();
