@@ -19,9 +19,9 @@
  */
 package org.openscience.cdk.silent;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.interfaces.AbstractMappingTest;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IChemObject;
@@ -33,10 +33,10 @@ import org.openscience.cdk.test.interfaces.ITestObjectBuilder;
  *
  * @cdk.module test-silent
  */
-public class MappingTest extends AbstractMappingTest {
+class MappingTest extends AbstractMappingTest {
 
-    @BeforeClass
-    public static void setUp() {
+    @BeforeAll
+    static void setUp() {
         setTestObjectBuilder(new ITestObjectBuilder() {
 
             @Override
@@ -47,10 +47,10 @@ public class MappingTest extends AbstractMappingTest {
     }
 
     @Test
-    public void testMapping_IChemObject_IChemObject() {
+    void testMapping_IChemObject_IChemObject() {
         IMapping mapping = new Mapping(newChemObject().getBuilder().newInstance(IAtom.class), newChemObject()
                 .getBuilder().newInstance(IAtom.class));
-        Assert.assertNotNull(mapping);
+        Assertions.assertNotNull(mapping);
     }
 
     // Overwrite default methods: no notifications are expected!
