@@ -19,9 +19,9 @@
  */
 package org.openscience.cdk.silent;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.interfaces.AbstractMolecularFormulaSetTest;
 import org.openscience.cdk.interfaces.IMolecularFormula;
 import org.openscience.cdk.interfaces.IMolecularFormulaSet;
@@ -31,23 +31,23 @@ import org.openscience.cdk.interfaces.IMolecularFormulaSet;
  *
  * @cdk.module test-silent
  */
-public class MolecularFormulaSetTest extends AbstractMolecularFormulaSetTest {
+class MolecularFormulaSetTest extends AbstractMolecularFormulaSetTest {
 
-    @BeforeClass
-    public static void setUp() {
+    @BeforeAll
+    static void setUp() {
         setBuilder(SilentChemObjectBuilder.getInstance());
     }
 
     @Test
-    public void testMolecularFormulaSet() {
+    void testMolecularFormulaSet() {
         IMolecularFormulaSet mfS = new MolecularFormulaSet();
-        Assert.assertNotNull(mfS);
+        Assertions.assertNotNull(mfS);
     }
 
     @Test
-    public void testMolecularFormulaSet_IMolecularFormula() {
+    void testMolecularFormulaSet_IMolecularFormula() {
         IMolecularFormulaSet mfS = new MolecularFormulaSet(getBuilder().newInstance(IMolecularFormula.class));
-        Assert.assertEquals(1, mfS.size());
+        Assertions.assertEquals(1, mfS.size());
     }
 
 }
