@@ -19,9 +19,9 @@
  */
 package org.openscience.cdk.silent;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.interfaces.IPDBStructure;
 import org.openscience.cdk.test.interfaces.AbstractPDBStructureTest;
 
@@ -30,27 +30,27 @@ import org.openscience.cdk.test.interfaces.AbstractPDBStructureTest;
  *
  * @cdk.module test-silent
  */
-public class PDBStructureTest extends AbstractPDBStructureTest {
+class PDBStructureTest extends AbstractPDBStructureTest {
 
-    @BeforeClass
-    public static void setUp() {
+    @BeforeAll
+    static void setUp() {
         setChemObject(new PDBStructure());
     }
 
     @Test
-    public void testPDBStructure() {
+    void testPDBStructure() {
         IPDBStructure structure = new PDBStructure();
-        Assert.assertNotNull(structure);
+        Assertions.assertNotNull(structure);
     }
 
     @Test
-    public void testGetBuilder() {
+    void testGetBuilder() {
         PDBStructure structure = new PDBStructure();
-        Assert.assertTrue(structure.getBuilder() instanceof SilentChemObjectBuilder);
+        Assertions.assertTrue(structure.getBuilder().getClass().getName().contains("SilentChemObjectBuilder"));
     }
 
     @Test
-    public void testAddListener_IChemObjectListener() {
+    void testAddListener_IChemObjectListener() {
         ChemObjectTestHelper.testAddListener_IChemObjectListener(newChemObject());
     }
 
