@@ -62,10 +62,10 @@ import java.util.Set;
  *   fingerprint.length(); // returns the highest set bit
  * </pre> <p>
  *
- *  The FingerPrinter assumes that hydrogens are explicitly given! Furthermore,
- *  if pseudo atoms or atoms with malformed symbols are present, their atomic
- *  number is taken as one more than the last element currently supported in
- *  {@link org.openscience.cdk.tools.periodictable.PeriodicTable}.
+ * <p>The FingerPrinter has the option to ignore explicit hydrogen's
+ * ({@link #setHashExplicitHydrogens(boolean)}) and pseudo atoms
+ * ({@link #setHashPseudoAtoms(boolean)}). This ensures the
+ * fingerprint can be used for substructure screening by default.</p>
  *
  *  <span style="color: #FF0000;">Warning: The aromaticity detection for this
  *  FingerPrinter relies on AllRingsFinder, which is known to take very long
@@ -93,27 +93,32 @@ import java.util.Set;
  */
 public class Fingerprinter extends AbstractFingerprinter implements IFingerprinter {
 
-    /** Throw an exception if too many paths (per atom) are generated. */
-    private final static int                 DEFAULT_PATH_LIMIT   = 42000;
+    /**
+     * Throw an exception if too many paths (per atom) are generated.
+     */
+    private final static int DEFAULT_PATH_LIMIT = 42000;
 
-    /** The default length of created fingerprints. */
-    public final static int                  DEFAULT_SIZE         = 1024;
-    /** The default search depth used to create the fingerprints. */
-    public final static int                  DEFAULT_SEARCH_DEPTH = 7;
+    /**
+     * The default length of created fingerprints.
+     */
+    public final static int DEFAULT_SIZE = 1024;
+    /**
+     * The default search depth used to create the fingerprints.
+     */
+    public final static int DEFAULT_SEARCH_DEPTH = 7;
 
-    private final int                              size;
-    private final int                              searchDepth;
-    private int                              pathLimit = DEFAULT_PATH_LIMIT;
-
-    private boolean                          hashPseudoAtoms = false;
-
-    static int                               debugCounter         = 0;
-
-
-    private static final ILoggingTool              logger               = LoggingToolFactory
-                                                                          .createLoggingTool(Fingerprinter.class);
+    private final int size;
+    private final int searchDepth;
+    private int pathLimit = DEFAULT_PATH_LIMIT;
 
+    private boolean hashPseudoAtoms = false;
+    /** Encode paths with pass through a hydrogen atom. Hydrogens may be
+     *  implicit or explicit which will result in different FPs - default:
+     *  false*/
+    private boolean hashExplHydrogens = false;
 
+    private static final ILoggingTool logger = LoggingToolFactory
+            .createLoggingTool(Fingerprinter.class);
 
     /**
      * Creates a fingerprint generator of length <code>DEFAULT_SIZE</code>
@@ -146,7 +151,8 @@ public class Fingerprinter extends AbstractFingerprinter implements IFingerprint
         return Arrays.asList(
             new SimpleImmutableEntry<>("searchDepth", Integer.toString(searchDepth)),
             new SimpleImmutableEntry<>("pathLimit", Integer.toString(pathLimit)),
-            new SimpleImmutableEntry<>("hashPseudoAtoms", Boolean.toString(hashPseudoAtoms))
+            new SimpleImmutableEntry<>("hashPseudoAtoms", Boolean.toString(hashPseudoAtoms)),
+            new SimpleImmutableEntry<>("hashExplicitHydrogens", Boolean.toString(hashExplHydrogens))
         );
     }
 
@@ -407,7 +413,7 @@ public class Fingerprinter extends AbstractFingerprinter implements IFingerprint
     }
 
     private void traversePaths(State state, IAtom beg, IBond prev) throws CDKException {
-        if (!hashPseudoAtoms && isPseudo(beg))
+        if (skipAtom(beg))
             return;
         state.push(beg, prev);
         state.storePath();
@@ -427,6 +433,12 @@ public class Fingerprinter extends AbstractFingerprinter implements IFingerprint
         state.pop();
     }
 
+    private boolean skipAtom(IAtom beg) {
+        int elem = getElem(beg);
+        return !hashPseudoAtoms && elem == IAtom.Wildcard ||
+                !hashExplHydrogens && elem == IAtom.H;
+    }
+
     /**
      * Get all paths of lengths 0 to the specified length.
      *
@@ -447,7 +459,8 @@ public class Fingerprinter extends AbstractFingerprinter implements IFingerprint
         for (IAtom startAtom : container.atoms()) {
             List<List<IAtom>> p = PathTools.getLimitedPathsOfLengthUpto(container, startAtom, searchDepth, pathLimit);
             for (List<IAtom> path : p) {
-                if (hashPseudoAtoms || !hasPseudoAtom(path))
+                if ((hashPseudoAtoms || !hasPseudoAtom(path)) &&
+                    (hashExplHydrogens || !hasExplHydrogen(path)))
                     hashes.add(encodeUniquePath(container, path, buffer));
             }
         }
@@ -470,13 +483,17 @@ public class Fingerprinter extends AbstractFingerprinter implements IFingerprint
         }
     }
 
-    private static boolean isPseudo(IAtom a) {
-        return getElem(a) == 0;
-    }
 
     private static boolean hasPseudoAtom(Iterable<IAtom> path) {
         for (IAtom atom : path)
-            if (isPseudo(atom))
+            if (getElem(atom) == IAtom.Wildcard)
+                return true;
+        return false;
+    }
+
+    private static boolean hasExplHydrogen(Iterable<IAtom> path) {
+        for (IAtom atom : path)
+            if (getElem(atom) == IAtom.H)
                 return true;
         return false;
     }
@@ -623,10 +640,29 @@ public class Fingerprinter extends AbstractFingerprinter implements IFingerprint
         this.pathLimit = limit;
     }
 
+    /**
+     * Include pseudo/query atoms in the fingerprint with atomic number 0.
+     * Generally for substructure screening, which path based fingerprints are
+     * most useful, this is not wanted.
+     *
+     * @param value the setting (false by default)
+     */
     public void setHashPseudoAtoms(boolean value) {
         this.hashPseudoAtoms = value;
     }
 
+    /**
+     * Include explicit hydrogen atoms in the fingerprint. This means you
+     * get a different fingerprint if hydrogens are implicit/explicit.
+     * Generally for substructure screening, which path based fingerprints are
+     * most useful, this is not wanted.
+     *
+     * @param value the setting (false by default)
+     */
+    public void setHashExplicitHydrogens(boolean value) {
+        this.hashExplHydrogens = value;
+    }
+
     public int getSearchDepth() {
         return searchDepth;
     }
