@@ -26,11 +26,11 @@
  */
 package org.openscience.cdk.isomorphism;
 
-import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
+import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.interfaces.IElement;
 import org.openscience.cdk.isomorphism.matchers.IQueryAtom;
 import org.openscience.cdk.isomorphism.matchers.IQueryAtomContainer;
@@ -550,7 +550,7 @@ public class UniversalIsomorphismTester {
                 table.put(a, a2);
             }
             IBond newBond = g.getBuilder().newInstance(IBond.class, a1, a2, bond.getOrder());
-            newBond.setFlag(CDKConstants.ISAROMATIC, bond.getFlag(CDKConstants.ISAROMATIC));
+            newBond.setFlag(IChemObject.AROMATIC, bond.getFlag(IChemObject.AROMATIC));
             ac.addBond(newBond);
         }
         return ac;
@@ -767,9 +767,9 @@ public class UniversalIsomorphismTester {
                     if (( // bond type conditions
                             ( // same bond order and same aromaticity flag (either both on or off)
                             ac1.getBond(i).getOrder() == ac2.getBond(j).getOrder() && ac1.getBond(i).getFlag(
-                                    CDKConstants.ISAROMATIC) == ac2.getBond(j).getFlag(CDKConstants.ISAROMATIC)) || ( // both bond are aromatic
-                            ac1.getBond(i).getFlag(CDKConstants.ISAROMATIC) && ac2.getBond(j).getFlag(
-                                    CDKConstants.ISAROMATIC)))
+                                    IChemObject.AROMATIC) == ac2.getBond(j).getFlag(IChemObject.AROMATIC)) || ( // both bond are aromatic
+                            ac1.getBond(i).getFlag(IChemObject.AROMATIC) && ac2.getBond(j).getFlag(
+                                    IChemObject.AROMATIC)))
                             && ( // atom type conditions
                             ( // a1 = a2 && b1 = b2
                               ac1.getBond(i).getBegin().getSymbol().equals(ac2.getBond(j).getBegin().getSymbol()) && ac1
@@ -997,7 +997,7 @@ public class UniversalIsomorphismTester {
         IAtom atom;
         for (int i = 0; i < ac1.getBondCount(); i++) {
             bond = ac1.getBond(i);
-            if (bond.getFlag(CDKConstants.ISAROMATIC))
+            if (bond.getFlag(IChemObject.AROMATIC))
                 ac1AromaticBondCount++;
             else if (bond.getOrder() == IBond.Order.SINGLE)
                 ac1SingleBondCount++;
@@ -1008,7 +1008,7 @@ public class UniversalIsomorphismTester {
         for (int i = 0; i < ac2.getBondCount(); i++) {
             bond = ac2.getBond(i);
             if (bond instanceof IQueryBond) continue;
-            if (bond.getFlag(CDKConstants.ISAROMATIC))
+            if (bond.getFlag(IChemObject.AROMATIC))
                 ac2AromaticBondCount++;
             else if (bond.getOrder() == IBond.Order.SINGLE)
                 ac2SingleBondCount++;
