@@ -29,7 +29,7 @@ public class DoubleArrayResultType implements IDescriptorResult {
 
     private static final long serialVersionUID = -8255004284721233969L;
 
-    private int               size;
+    private final int               size;
 
     public DoubleArrayResultType(int size) {
         this.size = size;
