@@ -24,6 +24,15 @@
  */
 package org.openscience.cdk.tools;
 
+import java.io.IOException;
+import java.util.ArrayList;
+import java.util.Comparator;
+import java.util.List;
+import java.util.Map;
+import java.util.Objects;
+import java.util.stream.Collectors;
+import java.util.stream.Stream;
+
 import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.config.IsotopeFactory;
 import org.openscience.cdk.config.Isotopes;
@@ -33,16 +42,11 @@ import org.openscience.cdk.graph.invariant.CanonicalLabeler;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
+import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.interfaces.IIsotope;
 import org.openscience.cdk.interfaces.IRingSet;
 import org.openscience.cdk.smiles.InvPair;
 
-import java.io.IOException;
-import java.util.ArrayList;
-import java.util.Comparator;
-import java.util.List;
-import java.util.Objects;
-
 /**
  * Generates HOSE codes {@cdk.cite BRE78}.
  * IMPORTANT: Your molecule must contain implicit or explicit hydrogens
@@ -110,25 +114,19 @@ public class HOSECodeGenerator implements java.io.Serializable {
 
     protected String            centerCode           = null;
 
-    private TreeNode             rootNode             = null;
-
     boolean                     debug                = false;
 
     private final IAtomContainer      acold                = null;
     private IRingSet            soar                 = null;
 
     /**
-     *  The rank order for the given element symbols.
+     *  The ranks for the given element and other symbols.
      */
-
-    private static final String[]       rankedSymbols        = {"C", "O", "N", "S", "P", "Si", "B", "F", "Cl", "Br", ";", "I",
-            "#", "&", ","                            };
-
-    /**
-     *  The ranking values to be used for the symbols above.
-     */
-    private static final int[]          symbolRankings       = {9000, 8900, 8800, 8700, 8600, 8500, 8400, 8300, 8200, 8100,
-            8000, 7900, 1200, 1100, 1000             };
+    private static final long RING_RANK = 1100l;
+    private Map<String, Long> rankedSymbols = Stream.of(new Object[][] {
+    	{"C",9000l},{"O",8900l},{"N",8800l},{"S",8700l},{"P",8600l},{"Si",8500l},{"B",8400l},{"F",8300l},
+    	{"Cl",8200l},{"Br",8100l},{";",8000l},{"I",7900l},{"#",1200l},{"&",RING_RANK},{",",1000l}
+    }).collect(Collectors.toMap(data -> (String) data[0], data -> (Long) data[1]));
 
     /**
      * The bond rankings to be used for the four bond order possibilities.
@@ -215,10 +213,9 @@ public class HOSECodeGenerator implements java.io.Serializable {
         spheres = new List[noOfSpheres + 1];
         spheresWithAtoms = new List[noOfSpheres + 1];
         for (int i = 0; i < ac.getAtomCount(); i++) {
-            ac.getAtom(i).setFlag(CDKConstants.VISITED, false);
+            ac.getAtom(i).setFlag(IChemObject.VISITED, false);
         }
-        root.setFlag(CDKConstants.VISITED, true);
-        rootNode = new TreeNode(root.getSymbol(), null, root, 0, atomContainer.getConnectedBondsCount(root), 0);
+        root.setFlag(IChemObject.VISITED, true);
         /*
          * All we need to observe is how the ranking of substituents in the
          * subsequent spheres of the root nodes influences the ranking of the
@@ -282,10 +279,9 @@ public class HOSECodeGenerator implements java.io.Serializable {
         maxSphere = noOfSpheres;
         spheres = new List[noOfSpheres + 1];
         for (int i = 0; i < ac.getAtomCount(); i++) {
-            ac.getAtom(i).setFlag(CDKConstants.VISITED, false);
+            ac.getAtom(i).setFlag(IChemObject.VISITED, false);
         }
-        root.setFlag(CDKConstants.VISITED, true);
-        rootNode = new TreeNode(root.getSymbol(), null, root, 0, atomContainer.getConnectedBondsCount(root), 0);
+        root.setFlag(IChemObject.VISITED, true);
         /*
          * All we need to observe is how the ranking of substituents in the
          * subsequent spheres of the root nodes influences the ranking of the
@@ -377,7 +373,7 @@ public class HOSECodeGenerator implements java.io.Serializable {
                  * In the first sphere the atoms are labeled with their own atom
                  * atom as source
                  */
-                if (bond.getFlag(CDKConstants.ISAROMATIC)) {
+                if (bond.getFlag(IChemObject.AROMATIC)) {
                     tempNode = new TreeNode(atom.getSymbol(), new TreeNode(root.getSymbol(), null, root, 0, 0,
                                                                            0), atom, 4, atomContainer.getConnectedBondsCount(atom), 0);
                 } else {
@@ -390,7 +386,7 @@ public class HOSECodeGenerator implements java.io.Serializable {
                 if (!addTreeNode) sphereNodesWithAtoms.add(atom);
 
                 //		        rootNode.childs.addElement(tempNode);
-                atom.setFlag(CDKConstants.VISITED, true);
+                atom.setFlag(IChemObject.VISITED, true);
             } catch (Exception exc) {
                 throw new CDKException("Error in HOSECodeGenerator->breadthFirstSearch.", exc);
             }
@@ -434,7 +430,7 @@ public class HOSECodeGenerator implements java.io.Serializable {
                         toNode = conAtom;
                         if (!toNode.equals(treeNode.source.atom)) {
                             bond = atomContainer.getBond(node, toNode);
-                            if (bond.getFlag(CDKConstants.ISAROMATIC)) {
+                            if (bond.getFlag(IChemObject.AROMATIC)) {
                                 nextSphereNodes.add(new TreeNode(toNode.getSymbol(), treeNode, toNode, 4, atomContainer
                                         .getConnectedBondsCount(toNode), treeNode.score));
                             } else {
@@ -469,7 +465,7 @@ public class HOSECodeGenerator implements java.io.Serializable {
      */
     private void createCode() throws CDKException {
         for (int f = 0; f < atomContainer.getAtomCount(); f++) {
-            atomContainer.getAtom(f).setFlag(CDKConstants.VISITED, false);
+            atomContainer.getAtom(f).setFlag(IChemObject.VISITED, false);
         }
         for (int f = 0; f < maxSphere; f++) {
             for (TreeNode tn : spheres[maxSphere - f]) {
@@ -504,7 +500,10 @@ public class HOSECodeGenerator implements java.io.Serializable {
                 sortNodesByScore(spheres[f]);
             }
         }
-
+        for (int i = 0; i < atomContainer.getAtomCount(); i++) {
+            atomContainer.getAtom(i).setFlag(IChemObject.VISITED, false);
+        }
+        
         HOSECode.append(centerCode);
         for (int f = 0; f < maxSphere; f++) {
             sphere = f + 1;
@@ -546,16 +545,16 @@ public class HOSECodeGenerator implements java.io.Serializable {
                 } else {
                     throw new CDKException("Unknown bond type");
                 }
-                if (treeNode.atom != null && !treeNode.atom.getFlag(CDKConstants.VISITED)) {
+                if (treeNode.atom != null && !treeNode.atom.getFlag(IChemObject.VISITED)) {
                     tempCode.append(getElementSymbol(treeNode.symbol));
-                } else if (treeNode.atom != null && treeNode.atom.getFlag(CDKConstants.VISITED)) {
+                } else if (treeNode.atom != null && treeNode.atom.getFlag(IChemObject.VISITED)) {
                     tempCode.append('&');
                     treeNode.stopper = true;
                 }
                 code.append(tempCode).append(createChargeCode(treeNode.atom));
                 treeNode.hSymbol = tempCode.toString();
             }
-            if (treeNode.atom != null) treeNode.atom.setFlag(CDKConstants.VISITED, true);
+            if (treeNode.atom != null) treeNode.atom.setFlag(IChemObject.VISITED, true);
             if (treeNode.source.stopper) treeNode.stopper = true;
         }
         code.append(sphereDelimiters[sphere - 1]);
@@ -569,15 +568,12 @@ public class HOSECodeGenerator implements java.io.Serializable {
      *@param  symbol  The element symbol for which the rank is to be determined
      *@return         The element rank
      */
-    private double getElementRank(String symbol) {
-        for (int f = 0; f < rankedSymbols.length; f++) {
-            if (rankedSymbols[f].equals(symbol)) {
-                return symbolRankings[f];
-            }
-        }
+    private long getElementRank(String symbol) {
+        if(rankedSymbols.containsKey(symbol))
+        	return rankedSymbols.get(symbol);
         IIsotope isotope = isotopeFac.getMajorIsotope(symbol);
         if (isotope.getMassNumber() != null) {
-            return ((double) 800000 - isotope.getMassNumber());
+            return ((long) 800000 - isotope.getMassNumber());
         }
         return 800000;
     }
@@ -605,7 +601,7 @@ public class HOSECodeGenerator implements java.io.Serializable {
         return sym;
     }
 
-    /**
+	/**
      *  Determines the ranking score for each node, allowing for a sorting of nodes
      *  within one sphere.
      *
@@ -614,14 +610,23 @@ public class HOSECodeGenerator implements java.io.Serializable {
      */
     private void calculateNodeScores(List<TreeNode> sphereNodes) throws CDKException {
         TreeNode treeNode;
+        List<TreeNode> visitedTreeNodes=new ArrayList<>();
         for (TreeNode sphereNode : sphereNodes) {
             treeNode = sphereNode;
-            treeNode.score += getElementRank(treeNode.symbol);
+            if ((flags&LEGACY_MODE) == 0 && treeNode.atom != null && treeNode.atom.getFlag(IChemObject.VISITED)) {
+            	treeNode.score += RING_RANK;
+            }else {
+            	treeNode.score += getElementRank(treeNode.symbol);
+            }
             if (treeNode.bondType <= 4) {
                 treeNode.score += bondRankings[(int) treeNode.bondType];
             } else {
                 throw new CDKException("Unknown bond type encountered in HOSECodeGenerator");
             }
+            if (treeNode.atom != null) visitedTreeNodes.add(treeNode);
+        }
+        for(TreeNode treeNode2 : visitedTreeNodes) {
+        	treeNode2.atom.setFlag(IChemObject.VISITED, true);
         }
     }
 
