@@ -54,7 +54,10 @@ import org.openscience.cdk.stereo.Atropisomeric;
 import org.openscience.cdk.stereo.DoubleBondStereochemistry;
 import org.openscience.cdk.stereo.ExtendedCisTrans;
 import org.openscience.cdk.stereo.ExtendedTetrahedral;
+import org.openscience.cdk.stereo.Octahedral;
+import org.openscience.cdk.stereo.SquarePlanar;
 import org.openscience.cdk.stereo.TetrahedralChirality;
+import org.openscience.cdk.stereo.TrigonalBipyramidal;
 import org.openscience.cdk.tools.LoggingToolFactory;
 
 import javax.vecmath.Point2d;
@@ -74,7 +77,7 @@ import java.util.Set;
 import java.util.function.Predicate;
 import java.util.stream.Collectors;
 
-import static org.openscience.cdk.CDKConstants.SINGLE_OR_DOUBLE;
+import static org.openscience.cdk.interfaces.IChemObject.SINGLE_OR_DOUBLE;
 import static org.openscience.cdk.interfaces.IDoubleBondStereochemistry.Conformation;
 
 /**
@@ -712,6 +715,7 @@ public class AtomContainerManipulator {
 
         // store a single explicit hydrogen of each original neighbor
         Map<IAtom, IAtom> hNeighbor = new HashMap<>(2*atomContainer.getAtomCount());
+        final int oldAtomCount = atomContainer.getAtomCount();
 
         for (IAtom atom : atomContainer.atoms()) {
             if (atom.getAtomicNumber() != IElement.H) {
@@ -726,8 +730,7 @@ public class AtomContainerManipulator {
                         newBonds.add(atom.getBuilder().newInstance(IBond.class, atom, hydrogen,
                                 Order.SINGLE));
 
-                        if (hNeighbor.get(atom) == null) hNeighbor.put(atom, hydrogen);
-
+                        hNeighbor.putIfAbsent(atom, hydrogen);
                     }
                     atom.setImplicitHydrogenCount(0);
                 }
@@ -740,24 +743,34 @@ public class AtomContainerManipulator {
 
         // update stereo elements with an implicit part
         List<IStereoElement> stereos = new ArrayList<>();
+        List<IAtom> explHatoms = new ArrayList<>();
         for (IStereoElement stereo : atomContainer.stereoElements()) {
             if (stereo instanceof ITetrahedralChirality) {
-                ITetrahedralChirality tc = (ITetrahedralChirality) stereo;
-
-                IAtom   focus    = tc.getFocus();
-                IAtom[] carriers = tc.getCarriers().toArray(new IAtom[4]);
-                IAtom   hydrogen = hNeighbor.get(focus);
-
-                // in sulfoxide - the implicit part of the tetrahedral centre
-                // is a lone pair
-
-                if (hydrogen != null) {
-                    replaceAtom(carriers, focus, hydrogen);
-                    TetrahedralChirality newStereo = new TetrahedralChirality(focus, carriers, tc.getStereo());
-                    newStereo.setGroupInfo(tc.getGroupInfo());
-                    stereos.add(newStereo);
+                @SuppressWarnings("unchecked")
+                IStereoElement<IAtom,IAtom> atomStereo = (IStereoElement<IAtom,IAtom>) stereo;
+                IAtom explH = hNeighbor.get(atomStereo.getFocus());
+                if (explH != null) {
+                    stereos.add(atomStereo.updateCarriers(atomStereo.getFocus(),
+                                                          explH));
                 } else {
-                    stereos.add(stereo);
+                    stereos.add(atomStereo);
+                }
+            } else if (stereo instanceof SquarePlanar ||
+                       stereo instanceof TrigonalBipyramidal ||
+                       stereo instanceof Octahedral) {
+
+                @SuppressWarnings("unchecked")
+                IStereoElement<IAtom,IAtom> atomStereo = (IStereoElement<IAtom,IAtom>) stereo;
+                if (hNeighbor.get(atomStereo.getFocus()) != null) {
+                    // update the carriers
+                    explHatoms.clear();
+                    for (IAtom atom : atomContainer.getConnectedAtomsList(atomStereo.getFocus())) {
+                        if (atom.getIndex() >= oldAtomCount)
+                            explHatoms.add(atom);
+                    }
+                    stereos.add(atomStereo.updateCarriers(atomStereo.getFocus(), explHatoms));
+                } else {
+                    stereos.add(atomStereo);
                 }
             } else if (stereo instanceof ExtendedTetrahedral) {
                 ExtendedTetrahedral tc = (ExtendedTetrahedral) stereo;
@@ -777,6 +790,7 @@ public class AtomContainerManipulator {
                     stereos.add(stereo);
                 }
             } else {
+                // may be broken but best we can do for now
                 stereos.add(stereo);
             }
         }
@@ -1199,6 +1213,9 @@ public class AtomContainerManipulator {
             } else if (se instanceof Atropisomeric) {
                 // can not have any H's
                 elements.add(se);
+            } else {
+                IAtom focus = (IAtom)se.getFocus();
+                elements.add(se.updateCarriers(hydrogens, focus));
             }
         }
 
@@ -1661,10 +1678,10 @@ public class AtomContainerManipulator {
             atom.setFormalCharge((Integer) CDKConstants.UNSET);
             atom.setHybridization((IAtomType.Hybridization) CDKConstants.UNSET);
             atom.setFormalNeighbourCount((Integer) CDKConstants.UNSET);
-            atom.setFlag(CDKConstants.IS_HYDROGENBOND_ACCEPTOR, false);
-            atom.setFlag(CDKConstants.IS_HYDROGENBOND_DONOR, false);
+            atom.setFlag(IChemObject.HYDROGEN_BOND_ACCEPTOR, false);
+            atom.setFlag(IChemObject.HYDROGEN_BOND_DONOR, false);
             atom.setProperty(CDKConstants.CHEMICAL_GROUP_CONSTANT, CDKConstants.UNSET);
-            atom.setFlag(CDKConstants.ISAROMATIC, false);
+            atom.setFlag(IChemObject.AROMATIC, false);
             atom.setProperty("org.openscience.cdk.renderer.color", CDKConstants.UNSET);
             atom.setExactMass((Double) CDKConstants.UNSET);
         }
@@ -1720,14 +1737,14 @@ public class AtomContainerManipulator {
         IAtomContainer query = atomContainer.clone();
         for (int i = 0; i < query.getBondCount(); i++) {
             query.getBond(i).setOrder(IBond.Order.SINGLE);
-            query.getBond(i).setFlag(CDKConstants.ISAROMATIC, false);
-            query.getBond(i).setFlag(CDKConstants.SINGLE_OR_DOUBLE, false);
+            query.getBond(i).setFlag(IChemObject.AROMATIC, false);
+            query.getBond(i).setFlag(IChemObject.SINGLE_OR_DOUBLE, false);
             query.getBond(i).getBegin().setSymbol("C");
             query.getBond(i).getBegin().setHybridization(null);
             query.getBond(i).getEnd().setSymbol("C");
             query.getBond(i).getEnd().setHybridization(null);
-            query.getBond(i).getBegin().setFlag(CDKConstants.ISAROMATIC, false);
-            query.getBond(i).getEnd().setFlag(CDKConstants.ISAROMATIC, false);
+            query.getBond(i).getBegin().setFlag(IChemObject.AROMATIC, false);
+            query.getBond(i).getEnd().setFlag(IChemObject.AROMATIC, false);
         }
         return query;
     }
@@ -1824,7 +1841,7 @@ public class AtomContainerManipulator {
     }
 
     /**
-     * Assigns {@link CDKConstants#SINGLE_OR_DOUBLE} flags to the bonds of
+     * Assigns {@link org.openscience.cdk.interfaces.IChemObject#SINGLE_OR_DOUBLE} flags to the bonds of
      * a container. The single or double flag indicates uncertainty of bond
      * order and in this case is assigned to all aromatic bonds (and atoms)
      * which occur in rings. If any such bonds are found the flag is also set
@@ -1849,7 +1866,7 @@ public class AtomContainerManipulator {
         RingSearch rs = new RingSearch(ac);
         boolean singleOrDouble = false;
         for (IBond bond : rs.ringFragments().bonds()) {
-            if (bond.getFlag(CDKConstants.ISAROMATIC)) {
+            if (bond.getFlag(IChemObject.AROMATIC)) {
                 bond.setFlag(SINGLE_OR_DOUBLE, true);
                 bond.getBegin().setFlag(SINGLE_OR_DOUBLE, true);
                 bond.getEnd().setFlag(SINGLE_OR_DOUBLE, true);
@@ -1857,7 +1874,7 @@ public class AtomContainerManipulator {
             }
         }
         if (singleOrDouble) {
-            ac.setFlag(CDKConstants.SINGLE_OR_DOUBLE, true);
+            ac.setFlag(IChemObject.SINGLE_OR_DOUBLE, true);
         }
         return ac;
     }
