@@ -23,8 +23,8 @@ import java.io.StringReader;
 import java.util.Map;
 import java.util.Set;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.CDKTestCase;
 
 /**
@@ -32,7 +32,7 @@ import org.openscience.cdk.test.CDKTestCase;
  *
  * @cdk.module test-atomtype
  */
-public class OWLAtomTypeMappingReaderTest extends CDKTestCase {
+class OWLAtomTypeMappingReaderTest extends CDKTestCase {
 
     private final String OWL_CONTENT = "<?xml version=\"1.0\"?>" + "<!DOCTYPE rdf:RDF ["
                                              + "  <!ENTITY rdf  \"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" >"
@@ -57,35 +57,35 @@ public class OWLAtomTypeMappingReaderTest extends CDKTestCase {
                                              + "  </owl:Thing>" + "</rdf:RDF>";
 
     @Test
-    public void testOWLAtomTypeMappingReader_Reader() {
+    void testOWLAtomTypeMappingReader_Reader() {
         OWLAtomTypeMappingReader reader = new OWLAtomTypeMappingReader(new StringReader(""));
-        Assert.assertNotNull(reader);
+        Assertions.assertNotNull(reader);
     }
 
     @Test
-    public void testReadAtomTypeMappings() {
+    void testReadAtomTypeMappings() {
         OWLAtomTypeMappingReader reader = new OWLAtomTypeMappingReader(new StringReader(OWL_CONTENT));
-        Assert.assertNotNull(reader);
+        Assertions.assertNotNull(reader);
         Map<String, String> mappings = reader.readAtomTypeMappings();
-        Assert.assertNotNull(mappings);
-        Assert.assertEquals(2, mappings.size());
+        Assertions.assertNotNull(mappings);
+        Assertions.assertEquals(2, mappings.size());
     }
 
     @Test
-    public void testReadAtomTypes_CDK2Sybyl() {
+    void testReadAtomTypes_CDK2Sybyl() {
         OWLAtomTypeMappingReader reader = new OWLAtomTypeMappingReader(new StringReader(OWL_CONTENT));
-        Assert.assertNotNull(reader);
+        Assertions.assertNotNull(reader);
         Map<String, String> mappings = reader.readAtomTypeMappings();
-        Assert.assertNotNull(mappings);
-        Assert.assertEquals(2, mappings.size());
+        Assertions.assertNotNull(mappings);
+        Assertions.assertEquals(2, mappings.size());
 
         Set<String> cdkTypes = mappings.keySet();
-        Assert.assertNotNull(cdkTypes);
-        Assert.assertTrue(cdkTypes.contains("C.sp3"));
-        Assert.assertTrue(cdkTypes.contains("X"));
+        Assertions.assertNotNull(cdkTypes);
+        Assertions.assertTrue(cdkTypes.contains("C.sp3"));
+        Assertions.assertTrue(cdkTypes.contains("X"));
 
-        Assert.assertEquals("X", mappings.get("X"));
-        Assert.assertEquals("C.3", mappings.get("C.sp3"));
+        Assertions.assertEquals("X", mappings.get("X"));
+        Assertions.assertEquals("C.3", mappings.get("C.sp3"));
     }
 
 }
