@@ -23,7 +23,8 @@
  */
 package org.openscience.cdk.graph;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -34,9 +35,7 @@ import java.util.Random;
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.CoreMatchers.sameInstance;
 import static org.hamcrest.core.IsNot.not;
-import static org.junit.Assert.assertFalse;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assert.assertTrue;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 import static org.openscience.cdk.graph.InitialCycles.Cycle;
@@ -45,12 +44,12 @@ import static org.openscience.cdk.graph.InitialCycles.Cycle;
  * @author John May
  * @cdk.module test-core
  */
-public class BitMatrixTest {
+class BitMatrixTest {
 
     @Test
-    public void swap_basic() {
+    void swap_basic() {
         BitMatrix m = new BitMatrix(0, 4);
-        List<BitSet> rows = new ArrayList<BitSet>();
+        List<BitSet> rows = new ArrayList<>();
         for (int i = 0; i < 4; i++) {
             BitSet row = new BitSet();
             rows.add(row);
@@ -67,9 +66,9 @@ public class BitMatrixTest {
 
     // ensure we can access the rows by with original index even after swapping
     @Test
-    public void swap() {
+    void swap() {
         BitMatrix m = new BitMatrix(0, 100);
-        List<BitSet> rows = new ArrayList<BitSet>();
+        List<BitSet> rows = new ArrayList<>();
         for (int i = 0; i < 100; i++) {
             BitSet row = new BitSet();
             rows.add(row);
@@ -89,7 +88,7 @@ public class BitMatrixTest {
     }
 
     @Test
-    public void clear() {
+    void clear() {
         BitMatrix m = new BitMatrix(9, 3);
         BitSet r1 = toBitSet("110000000");
         BitSet r2 = toBitSet("100000000");
@@ -110,7 +109,7 @@ public class BitMatrixTest {
     }
 
     @Test
-    public void indexOf() {
+    void indexOf() {
         BitMatrix m = new BitMatrix(9, 3);
         BitSet r1 = toBitSet("010000000");
         BitSet r2 = toBitSet("100001000");
@@ -130,7 +129,7 @@ public class BitMatrixTest {
     }
 
     @Test
-    public void string() {
+    void string() {
         BitMatrix m = new BitMatrix(9, 3);
         m.add(toBitSet("110000000"));
         m.add(toBitSet("110011000"));
@@ -140,33 +139,33 @@ public class BitMatrixTest {
     }
 
     @Test
-    public void eliminate1() throws Exception {
+    void eliminate1() throws Exception {
         // vectors[0] = vectors[1] ^ vectors[2] (xor)
         BitMatrix m = new BitMatrix(9, 3);
         m.add(toBitSet("110000000"));
         m.add(toBitSet("110011000"));
         m.add(toBitSet("000011000"));
         assertThat(m.eliminate(), is(2));
-        assertFalse(m.eliminated(0));
-        assertFalse(m.eliminated(1));
-        assertTrue(m.eliminated(2));
+        Assertions.assertFalse(m.eliminated(0));
+        Assertions.assertFalse(m.eliminated(1));
+        Assertions.assertTrue(m.eliminated(2));
     }
 
     @Test
-    public void eliminate2() throws Exception {
+    void eliminate2() throws Exception {
         // vectors[2] = vectors[0] ^ vectors[1] (xor)
         BitMatrix m = new BitMatrix(9, 3);
         m.add(toBitSet("110011000"));
         m.add(toBitSet("001000110"));
         m.add(toBitSet("111011110"));
         assertThat(m.eliminate(), is(2));
-        assertFalse(m.eliminated(0));
-        assertFalse(m.eliminated(1));
-        assertTrue(m.eliminated(2));
+        Assertions.assertFalse(m.eliminated(0));
+        Assertions.assertFalse(m.eliminated(1));
+        Assertions.assertTrue(m.eliminated(2));
     }
 
     @Test
-    public void eliminate3() throws Exception {
+    void eliminate3() throws Exception {
         // all vectors are independent
         BitMatrix m = new BitMatrix(15, 4);
 
@@ -182,36 +181,36 @@ public class BitMatrixTest {
         assertThat(m.eliminate(), is(3));
 
         // 4 was not
-        assertFalse(m.eliminated(3));
+        Assertions.assertFalse(m.eliminated(3));
     }
 
     @Test
-    public void independent1() throws Exception {
+    void independent1() throws Exception {
         BitMatrix m = new BitMatrix(9, 3);
         m.add(toBitSet("010011000"));
         m.add(toBitSet("001000110"));
         m.add(toBitSet("111011110"));
         assertThat(m.eliminate(), is(3));
-        assertFalse(m.eliminated(0));
-        assertFalse(m.eliminated(1));
-        assertFalse(m.eliminated(2));
+        Assertions.assertFalse(m.eliminated(0));
+        Assertions.assertFalse(m.eliminated(1));
+        Assertions.assertFalse(m.eliminated(2));
     }
 
     @Test
-    public void independent2() throws Exception {
+    void independent2() throws Exception {
         // all vectors are independent
         BitMatrix m = new BitMatrix(9, 3);
         m.add(toBitSet("110011000"));
         m.add(toBitSet("110011011"));
         m.add(toBitSet("110011010"));
         assertThat(m.eliminate(), is(3));
-        assertFalse(m.eliminated(0));
-        assertFalse(m.eliminated(1));
-        assertFalse(m.eliminated(2));
+        Assertions.assertFalse(m.eliminated(0));
+        Assertions.assertFalse(m.eliminated(1));
+        Assertions.assertFalse(m.eliminated(2));
     }
 
     @Test
-    public void duplicates() throws Exception {
+    void duplicates() throws Exception {
         // ensure duplicates are handled
         BitMatrix m = new BitMatrix(9, 3);
         m.add(toBitSet("110000000"));
@@ -238,7 +237,7 @@ public class BitMatrixTest {
     }
 
     @Test
-    public void xor() {
+    void xor() {
         BitSet s = toBitSet("00011");
         BitSet t = toBitSet("10010");
         BitSet u = BitMatrix.xor(s, t);
@@ -248,7 +247,7 @@ public class BitMatrixTest {
     }
 
     @Test
-    public void from_cycles() {
+    void from_cycles() {
         Cycle c1 = mock(Cycle.class);
         Cycle c2 = mock(Cycle.class);
         Cycle c3 = mock(Cycle.class);
@@ -265,7 +264,7 @@ public class BitMatrixTest {
     }
 
     @Test
-    public void from_cycles_cycle() {
+    void from_cycles_cycle() {
         Cycle c1 = mock(Cycle.class);
         Cycle c2 = mock(Cycle.class);
         Cycle last = mock(Cycle.class);
