@@ -19,8 +19,8 @@
  */
 package org.openscience.cdk.tools;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.CDKTestCase;
 
 /**
@@ -31,11 +31,11 @@ import org.openscience.cdk.test.CDKTestCase;
  *
  * @see org.openscience.cdk.CDKConstants
  */
-public class DataFeaturesTest extends CDKTestCase {
+class DataFeaturesTest extends CDKTestCase {
 
     @Test
-    public void testDataFeatures() {
-        Assert.assertFalse(DataFeatures.HAS_2D_COORDINATES == -1);
+    void testDataFeatures() {
+        Assertions.assertFalse(DataFeatures.HAS_2D_COORDINATES == -1);
     }
 
     // FIXME: should add a test here that used introspection and test whether there
