@@ -27,8 +27,9 @@ import org.hamcrest.number.IsCloseTo;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
-import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.Bond;
+import org.openscience.cdk.exception.InvalidSmilesException;
+import org.openscience.cdk.smiles.SmilesParser;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.Reaction;
@@ -79,7 +80,7 @@ class GeometryUtilTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(1, 1));
         Atom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(1, 0));
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
         Assertions.assertTrue(GeometryUtil.has2DCoordinates(container));
@@ -88,7 +89,7 @@ class GeometryUtilTest extends CDKTestCase {
         atom1.setPoint3d(new Point3d(1, 1, 1));
         atom2 = new Atom("C");
         atom2.setPoint3d(new Point3d(1, 0, 5));
-        container = new AtomContainer();
+        container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
         Assertions.assertFalse(GeometryUtil.has2DCoordinates(container));
@@ -96,14 +97,14 @@ class GeometryUtilTest extends CDKTestCase {
 
     @Test
     void testHas2DCoordinates_EmptyAtomContainer() {
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         Assertions.assertFalse(GeometryUtil.has2DCoordinates(container));
         Assertions.assertFalse(GeometryUtil.has2DCoordinates((IAtomContainer) null));
     }
 
     @Test
     void testHas2DCoordinates_Partial() {
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         Atom atom1 = new Atom("C");
         Atom atom2 = new Atom("C");
         atom1.setPoint2d(new Point2d(1, 1));
@@ -122,13 +123,13 @@ class GeometryUtilTest extends CDKTestCase {
         InputStream ins = this.getClass().getResourceAsStream(filenameMol);
         IAtomContainer molOne;
         MDLV2000Reader reader = new MDLV2000Reader(ins, Mode.STRICT);
-        molOne = reader.read(new AtomContainer());
+        molOne = reader.read(DefaultChemObjectBuilder.getInstance().newAtomContainer());
         Assertions.assertTrue(GeometryUtil.has2DCoordinates(molOne));
     }
 
     @Test
     void get2DCoordinateCoverage_EmptyAtomContainer() {
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         Assertions.assertEquals(GeometryUtil.CoordinateCoverage.NONE, GeometryUtil.get2DCoordinateCoverage(container));
         Assertions.assertEquals(GeometryUtil.CoordinateCoverage.NONE, GeometryUtil.get2DCoordinateCoverage(null));
     }
@@ -136,7 +137,7 @@ class GeometryUtilTest extends CDKTestCase {
     @Test
     void get2DCoordinateCoverage_Partial() {
 
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
 
         IAtom atom1 = new Atom("C");
         IAtom atom2 = new Atom("C");
@@ -156,7 +157,7 @@ class GeometryUtilTest extends CDKTestCase {
     @Test
     void get2DCoordinateCoverage_Full() {
 
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
 
         IAtom atom1 = new Atom("C");
         IAtom atom2 = new Atom("C");
@@ -177,7 +178,7 @@ class GeometryUtilTest extends CDKTestCase {
     @Test
     void get2DCoordinateCoverage_None_3D() {
 
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
 
         IAtom atom1 = new Atom("C");
         IAtom atom2 = new Atom("C");
@@ -197,7 +198,7 @@ class GeometryUtilTest extends CDKTestCase {
 
     @Test
     void testTranslateAllPositive_IAtomContainer() {
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         IAtom atom = new Atom(Elements.CARBON);
         atom.setPoint2d(new Point2d(-3, -2));
         container.addAtom(atom);
@@ -224,11 +225,11 @@ class GeometryUtilTest extends CDKTestCase {
         IAtomContainer molTwo;
         Map<Integer, Integer> mappedAtoms = new HashMap<>();
         MDLV2000Reader reader = new MDLV2000Reader(ins, Mode.STRICT);
-        molOne = reader.read(new AtomContainer());
+        molOne = reader.read(DefaultChemObjectBuilder.getInstance().newAtomContainer());
 
         ins = this.getClass().getResourceAsStream(filenameMolTwo);
         reader = new MDLV2000Reader(ins, Mode.STRICT);
-        molTwo = reader.read(new AtomContainer());
+        molTwo = reader.read(DefaultChemObjectBuilder.getInstance().newAtomContainer());
 
         mappedAtoms = AtomMappingTools.mapAtomsOfAlignedStructures(molOne, molTwo, mappedAtoms);
         //logger.debug("mappedAtoms:"+mappedAtoms.toString());
@@ -352,7 +353,7 @@ class GeometryUtilTest extends CDKTestCase {
 
     @Test
     void testGet2DCenter_arrayIAtom() {
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         Atom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(1, 1));
         Atom atom2 = new Atom("C");
@@ -428,7 +429,7 @@ class GeometryUtilTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(1, 1));
         Atom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(1, 0));
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
         Assertions.assertEquals(2, GeometryUtil.has2DCoordinatesNew(container));
@@ -437,7 +438,7 @@ class GeometryUtilTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(1, 1));
         atom2 = new Atom("C");
         atom2.setPoint3d(new Point3d(1, 0, 1));
-        container = new AtomContainer();
+        container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
         Assertions.assertEquals(1, GeometryUtil.has2DCoordinatesNew(container));
@@ -446,7 +447,7 @@ class GeometryUtilTest extends CDKTestCase {
         atom1.setPoint3d(new Point3d(1, 1, 1));
         atom2 = new Atom("C");
         atom2.setPoint3d(new Point3d(1, 0, 5));
-        container = new AtomContainer();
+        container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
         Assertions.assertEquals(0, GeometryUtil.has2DCoordinatesNew(container));
@@ -458,7 +459,7 @@ class GeometryUtilTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(1, 1));
         Atom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(1, 0));
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
         Assertions.assertFalse(GeometryUtil.has3DCoordinates(container));
@@ -467,7 +468,7 @@ class GeometryUtilTest extends CDKTestCase {
         atom1.setPoint3d(new Point3d(1, 1, 1));
         atom2 = new Atom("C");
         atom2.setPoint3d(new Point3d(1, 0, 5));
-        container = new AtomContainer();
+        container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
         Assertions.assertTrue(GeometryUtil.has3DCoordinates(container));
@@ -475,14 +476,14 @@ class GeometryUtilTest extends CDKTestCase {
 
     @Test
     void testHas3DCoordinates_EmptyAtomContainer() {
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         Assertions.assertFalse(GeometryUtil.has3DCoordinates(container));
         Assertions.assertFalse(GeometryUtil.has3DCoordinates((IAtomContainer) null));
     }
 
     @Test
     void get3DCoordinateCoverage_EmptyAtomContainer() {
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         Assertions.assertEquals(GeometryUtil.CoordinateCoverage.NONE, GeometryUtil.get3DCoordinateCoverage(container));
         Assertions.assertEquals(GeometryUtil.CoordinateCoverage.NONE, GeometryUtil.get3DCoordinateCoverage(null));
     }
@@ -490,7 +491,7 @@ class GeometryUtilTest extends CDKTestCase {
     @Test
     void get3DCoordinateCoverage_Partial() {
 
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
 
         IAtom atom1 = new Atom("C");
         IAtom atom2 = new Atom("C");
@@ -510,7 +511,7 @@ class GeometryUtilTest extends CDKTestCase {
     @Test
     void get3DCoordinateCoverage_Full() {
 
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
 
         IAtom atom1 = new Atom("C");
         IAtom atom2 = new Atom("C");
@@ -531,7 +532,7 @@ class GeometryUtilTest extends CDKTestCase {
     @Test
     void get3DCoordinateCoverage_None_2D() {
 
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
 
         IAtom atom1 = new Atom("C");
         IAtom atom2 = new Atom("C");
@@ -586,7 +587,7 @@ class GeometryUtilTest extends CDKTestCase {
         atom2.setPoint2d(new Point2d(1, 0));
         IAtom atom3 = new Atom("C");
         atom3.setPoint2d(new Point2d(5, 0));
-        IAtomContainer acont = new AtomContainer();
+        IAtomContainer acont = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         acont.addAtom(atom1);
         acont.addAtom(atom2);
         acont.addAtom(atom3);
@@ -601,7 +602,7 @@ class GeometryUtilTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(1, 0));
         IAtom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(5, 0));
-        IAtomContainer acont = new AtomContainer();
+        IAtomContainer acont = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         acont.addAtom(atom1);
         acont.addAtom(atom2);
         Assertions.assertEquals(atom2, GeometryUtil.getClosestAtom(1.0, 0.0, acont, atom1));
@@ -617,7 +618,7 @@ class GeometryUtilTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(-1, -1));
         IAtom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(1, 0));
-        IAtomContainer acont = new AtomContainer();
+        IAtomContainer acont = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         acont.addAtom(atom1);
         acont.addAtom(atom2);
         Assertions.assertEquals(atom2, GeometryUtil.getClosestAtom(acont, atom1));
@@ -630,7 +631,7 @@ class GeometryUtilTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(0, 1));
         IAtom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(1, 0));
-        IAtomContainer react1 = new AtomContainer();
+        IAtomContainer react1 = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         react1.addAtom(atom1);
         react1.addAtom(atom2);
         IAtomContainer react2 = react1.clone();
@@ -661,7 +662,7 @@ class GeometryUtilTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(0, 0));
         IAtom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(0, 1));
-        IAtomContainer react1 = new AtomContainer();
+        IAtomContainer react1 = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         react1.addAtom(atom1);
         react1.addAtom(atom2);
         IAtomContainer react2 = react1.clone();
@@ -686,7 +687,7 @@ class GeometryUtilTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(0, 0));
         IAtom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(1, 0));
-        IAtomContainer acont = new AtomContainer();
+        IAtomContainer acont = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         IReaction reaction = new Reaction();
         reaction.addReactant(acont);
         acont.addAtom(atom1);
@@ -708,7 +709,7 @@ class GeometryUtilTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(0, 0));
         IAtom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(1, 0));
-        IAtomContainer acont = new AtomContainer();
+        IAtomContainer acont = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         reaction.addReactant(acont);
         acont.addAtom(atom1);
         acont.addAtom(atom2);
@@ -719,7 +720,7 @@ class GeometryUtilTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(0, 0));
         atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(3, 0));
-        acont = new AtomContainer();
+        acont = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         reaction.addProduct(acont);
         acont.addAtom(atom1);
         acont.addAtom(atom2);
@@ -734,7 +735,7 @@ class GeometryUtilTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(0, 1));
         IAtom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(1, 0));
-        IAtomContainer react1 = new AtomContainer();
+        IAtomContainer react1 = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         IReaction reaction = new Reaction();
         reaction.addReactant(react1);
         react1.addAtom(atom1);
@@ -770,7 +771,7 @@ class GeometryUtilTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(0, 0));
         IAtom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(1, 0));
-        IAtomContainer react1 = new AtomContainer();
+        IAtomContainer react1 = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         IReaction reaction = new Reaction();
         reaction.addReactant(react1);
         react1.addAtom(atom1);
@@ -818,7 +819,7 @@ class GeometryUtilTest extends CDKTestCase {
 
     @Test
     void medianBondLength() {
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atomAt(new Point2d(0, 0)));
         container.addAtom(atomAt(new Point2d(0, 1.5)));
         container.addAtom(atomAt(new Point2d(0, -1.5)));
@@ -832,7 +833,7 @@ class GeometryUtilTest extends CDKTestCase {
     @Test
     void medianBondLengthNoBonds() {
         Assertions.assertThrows(IllegalArgumentException.class, () -> {
-            IAtomContainer container = new AtomContainer();
+            IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
             container.addAtom(atomAt(new Point2d(0, 0)));
             container.addAtom(atomAt(new Point2d(0, 1.5)));
             container.addAtom(atomAt(new Point2d(0, -1.5)));
@@ -844,7 +845,7 @@ class GeometryUtilTest extends CDKTestCase {
     @Test
     void medianBondLengthNoPoints() {
         Assertions.assertThrows(IllegalArgumentException.class, () -> {
-            IAtomContainer container = new AtomContainer();
+            IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
             container.addAtom(atomAt(new Point2d(0, 0)));
             container.addAtom(atomAt(new Point2d(0, 1.5)));
             container.addAtom(atomAt(null));
@@ -858,7 +859,7 @@ class GeometryUtilTest extends CDKTestCase {
 
     @Test
     void medianBondLengthOneBond() {
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atomAt(new Point2d(0, 0)));
         container.addAtom(atomAt(new Point2d(0, 1.5)));
         container.addBond(0, 1, IBond.Order.SINGLE);
@@ -867,7 +868,7 @@ class GeometryUtilTest extends CDKTestCase {
 
     @Test
     void medianBondLengthWithZeroLengthBonds() {
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atomAt(new Point2d(0, 0)));
         container.addAtom(atomAt(new Point2d(0, 0)));
         container.addAtom(atomAt(new Point2d(0, 0)));
@@ -955,7 +956,7 @@ class GeometryUtilTest extends CDKTestCase {
     }
 
     private int alignmentTestHelper(IAtom zero, IAtom... pos) {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         mol.addAtom(zero);
         for (IAtom atom : pos) {
             mol.addAtom(atom);
@@ -963,4 +964,35 @@ class GeometryUtilTest extends CDKTestCase {
         }
         return GeometryUtil.getBestAlignmentForLabelXY(mol, zero);
     }
+
+
+    @Test
+    public void findCrossingBonds_1() throws InvalidSmilesException {
+        SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
+        IAtomContainer mol = smipar.parseSmiles("[C@@H]12C[C@@H](CCC1)CC2 |(-7.14,4.4,;-7.68,3.86,;-6.9,4.12,;-6.14,3.78,;-5.91,4.58,;-6.32,4.08,;-7.07,4.93,;-7.32,5.2,)|");
+        List<Map.Entry<IBond,IBond>> crossing = GeometryUtil.intersectingBonds(mol);
+        Assertions.assertEquals(1, crossing.size());
+        Assertions.assertEquals(5, crossing.get(0).getKey().getIndex());
+        Assertions.assertEquals(6, crossing.get(0).getValue().getIndex());
+    }
+
+    @Test
+    public void findCrossingBonds_2() throws InvalidSmilesException {
+        SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
+        IAtomContainer mol = smipar.parseSmiles("C12C3C4C1C5C2C3C45 |(2.39,4.98,;3.03,4.82,;3.03,3.8,;2.38,3.96,;1.56,3.84,;1.57,4.86,;2.22,4.7,;2.21,3.68,)|");
+        List<Map.Entry<IBond,IBond>> crossing = GeometryUtil.intersectingBonds(mol);
+        Assertions.assertEquals(2, crossing.size());
+        Assertions.assertEquals(3, crossing.get(0).getKey().getIndex());
+        Assertions.assertEquals(8, crossing.get(0).getValue().getIndex());
+        Assertions.assertEquals(4, crossing.get(1).getKey().getIndex());
+        Assertions.assertEquals(9, crossing.get(1).getValue().getIndex());
+    }
+
+    @Test
+    public void findCrossingBonds_3() throws InvalidSmilesException {
+        SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
+        IAtomContainer mol = smipar.parseSmiles("c12c3c4c5c1c6c7c8c2c9c%10c3c%11c%12c4c%13c%14c5c%15c6c%16c7c%17c%18c8c9c%19c%20c%10c%11c%21c%22c%12c%13c%23c%24c%14c%15c%25c%16c%26c%17c%27c%18c%19c%28c%20c%21c%29c%22c%23c%30c%24c%25c%26c%31c%27c%28c%29c%30%31 |(-1.18,4.19,;-1.25,3.95,;-2.89,2.89,;-3.4,2.51,;-2.35,3.5,;-1.85,2.36,;-0.24,2.34,;0.9,3.16,;0.62,4.13,;1.64,3.95,;1.44,3.76,;-0.18,3.78,;-0.22,2.55,;-1.68,1.63,;-3.12,1.86,;-3.79,0.18,;-4.25,-0.17,;-4.09,1.02,;-3.53,0.2,;-2.43,0.88,;-1.19,0.06,;0.04,0.83,;1.56,0.18,;2.62,0.94,;2.4,2.6,;2.78,2.95,;3.76,1.66,;3.54,1.5,;2.21,2.47,;1.25,1.8,;1.42,-0.1,;0.01,-0.96,;-1.58,-0.17,;-2.92,-1.05,;-2.52,-2.69,;-3,-2.99,;-3.85,-1.66,;-3.41,-1.49,;-2.24,-2.31,;-1.13,-1.6,;0.24,-2.29,;1.69,-1.43,;2.9,-1.69,;3.49,-0.25,;4.04,0.09,;4.04,-1.03,;3.71,-0.29,;2.72,-0.98,;2.01,-2.61,;0.36,-2.64,;-0.87,-3.45,;-0.47,-4.19,;-1.75,-3.85,;-1.41,-3.59,;0.2,-3.49,;1.42,-3.81,;2.81,-2.84,;3.34,-2.68,;2.44,-3.41,;1.21,-4.2,)| fullerene");
+        List<Map.Entry<IBond,IBond>> crossing = GeometryUtil.intersectingBonds(mol);
+        Assertions.assertEquals(22, crossing.size());
+    }
 }
