@@ -24,7 +24,7 @@ import javax.vecmath.Point3d;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
-import org.openscience.cdk.AtomContainer;
+import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.config.AtomTypeFactory;
 import org.openscience.cdk.interfaces.IAtomContainer;
@@ -49,7 +49,7 @@ class RebondToolTest extends CDKTestCase {
     @Test
     void testRebond_IAtomContainer() throws Exception {
         RebondTool rebonder = new RebondTool(2.0, 0.5, 0.5);
-        IAtomContainer methane = new AtomContainer();
+        IAtomContainer methane = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         methane.addAtom(new Atom("C", new Point3d(0.0, 0.0, 0.0)));
         methane.addAtom(new Atom("H", new Point3d(0.6, 0.6, 0.6)));
         methane.addAtom(new Atom("H", new Point3d(-0.6, -0.6, 0.6)));
