@@ -18,21 +18,21 @@
  */
 package org.openscience.cdk.isomorphism.mcss;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.CDKTestCase;
 
 /**
  * @cdk.module test-standard
  */
-public class RNodeTest extends CDKTestCase {
+class RNodeTest extends CDKTestCase {
 
     @Test
-    public void testRNode_int_int() {
+    void testRNode_int_int() {
         RNode node = new RNode(1, 2);
-        Assert.assertNotNull(node);
-        Assert.assertNotNull(node.getExtension());
-        Assert.assertNotNull(node.getForbidden());
+        Assertions.assertNotNull(node);
+        Assertions.assertNotNull(node.getExtension());
+        Assertions.assertNotNull(node.getForbidden());
     }
 
 }
