@@ -18,8 +18,8 @@
  */
 package org.openscience.cdk.qsar;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.qsar.result.DoubleArrayResult;
@@ -31,9 +31,9 @@ import static org.hamcrest.CoreMatchers.is;
 /**
  * @cdk.module test-standard
  */
-public class DescriptorValueTest extends CDKTestCase {
+class DescriptorValueTest extends CDKTestCase {
 
-    public DescriptorValueTest() {
+    DescriptorValueTest() {
         super();
     }
 
@@ -43,71 +43,71 @@ public class DescriptorValueTest extends CDKTestCase {
     private final static String DESC_IMPL_ID     = "bla4";
 
     @Test
-    public void testDescriptorValue_DescriptorSpecification_arrayString_arrayObject_IDescriptorResult_arrayString() {
+    void testDescriptorValue_DescriptorSpecification_arrayString_arrayObject_IDescriptorResult_arrayString() {
         DescriptorSpecification spec = new DescriptorSpecification(DESC_REF, DESC_IMPL_TITLE, DESC_IMPL_ID,
                 DESC_IMPL_VENDOR);
         DescriptorValue value = new DescriptorValue(spec, new String[0], new Object[0], new DoubleResult(0.7),
                 new String[]{"bla"});
-        Assert.assertNotNull(value);
+        Assertions.assertNotNull(value);
     }
 
     @Test
-    public void testGetValue() {
+    void testGetValue() {
         DescriptorSpecification spec = new DescriptorSpecification(DESC_REF, DESC_IMPL_TITLE, DESC_IMPL_ID,
                 DESC_IMPL_VENDOR);
         DoubleResult doubleVal = new DoubleResult(0.7);
         DescriptorValue value = new DescriptorValue(spec, new String[0], new Object[0], doubleVal, new String[]{"bla"});
-        Assert.assertEquals(doubleVal, value.getValue());
+        Assertions.assertEquals(doubleVal, value.getValue());
     }
 
     @Test
-    public void testGetSpecification() {
+    void testGetSpecification() {
         DescriptorSpecification spec = new DescriptorSpecification(DESC_REF, DESC_IMPL_TITLE, DESC_IMPL_ID,
                 DESC_IMPL_VENDOR);
         DoubleResult doubleVal = new DoubleResult(0.7);
         DescriptorValue value = new DescriptorValue(spec, new String[0], new Object[0], doubleVal, new String[]{"bla"});
-        Assert.assertEquals(spec, value.getSpecification());
+        Assertions.assertEquals(spec, value.getSpecification());
     }
 
     @Test
-    public void testGetParameters() {
+    void testGetParameters() {
         DescriptorSpecification spec = new DescriptorSpecification(DESC_REF, DESC_IMPL_TITLE, DESC_IMPL_ID,
                 DESC_IMPL_VENDOR);
         DoubleResult doubleVal = new DoubleResult(0.7);
         DescriptorValue value = new DescriptorValue(spec, new String[0], new Object[0], doubleVal, new String[]{"bla"});
-        Assert.assertEquals(0, value.getParameters().length);
+        Assertions.assertEquals(0, value.getParameters().length);
     }
 
     @Test
-    public void testGetParameterNames() {
+    void testGetParameterNames() {
         DescriptorSpecification spec = new DescriptorSpecification(DESC_REF, DESC_IMPL_TITLE, DESC_IMPL_ID,
                 DESC_IMPL_VENDOR);
         DoubleResult doubleVal = new DoubleResult(0.7);
         DescriptorValue value = new DescriptorValue(spec, new String[0], new Object[0], doubleVal, new String[]{"bla"});
-        Assert.assertEquals(0, value.getParameterNames().length);
+        Assertions.assertEquals(0, value.getParameterNames().length);
     }
 
     @Test
-    public void testGetNames() {
+    void testGetNames() {
         DescriptorSpecification spec = new DescriptorSpecification(DESC_REF, DESC_IMPL_TITLE, DESC_IMPL_ID,
                 DESC_IMPL_VENDOR);
         DoubleResult doubleVal = new DoubleResult(0.7);
         DoubleArrayResult doubleVals = new DoubleArrayResult();
-        doubleVals.add(Double.valueOf(0.1));
-        doubleVals.add(Double.valueOf(0.2));
+        doubleVals.add(0.1);
+        doubleVals.add(0.2);
         DescriptorValue value;
         value = new DescriptorValue(spec, new String[0], new Object[0], doubleVal, new String[]{"bla"});
-        Assert.assertEquals(1, value.getNames().length);
+        Assertions.assertEquals(1, value.getNames().length);
         value = new DescriptorValue(spec, new String[0], new Object[0], doubleVal, new String[]{ });
-        Assert.assertEquals(1, value.getNames().length);
+        Assertions.assertEquals(1, value.getNames().length);
         value = new DescriptorValue(spec, new String[0], new Object[0], doubleVal, null);
-        Assert.assertEquals(1, value.getNames().length);
+        Assertions.assertEquals(1, value.getNames().length);
         value = new DescriptorValue(spec, new String[0], new Object[0], doubleVals, null);
-        Assert.assertEquals(2, value.getNames().length);
+        Assertions.assertEquals(2, value.getNames().length);
     }
 
     @Test
-    public void testGetException() {
+    void testGetException() {
         DescriptorSpecification spec = new DescriptorSpecification(DESC_REF, DESC_IMPL_TITLE, DESC_IMPL_ID,
                 DESC_IMPL_VENDOR);
         DoubleResult doubleVal = new DoubleResult(0.7);
