@@ -18,33 +18,33 @@
  */
 package org.openscience.cdk.qsar.result;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.CDKTestCase;
 
 /**
  * @cdk.module test-standard
  */
-public class IntegerResultTypeTest extends CDKTestCase {
+class IntegerResultTypeTest extends CDKTestCase {
 
-    public IntegerResultTypeTest() {
+    IntegerResultTypeTest() {
         super();
     }
 
     @Test
-    public void testIntegerResultType() {
+    void testIntegerResultType() {
         IDescriptorResult type = new IntegerResultType();
-        Assert.assertNotNull(type);
+        Assertions.assertNotNull(type);
     }
 
     @Test
-    public void testToString() {
-        Assert.assertEquals("IntegerResultType", new IntegerResultType().toString());
+    void testToString() {
+        Assertions.assertEquals("IntegerResultType", new IntegerResultType().toString());
     }
 
     @Test
-    public void testLength() {
-        Assert.assertEquals(1, new IntegerResultType().length());
+    void testLength() {
+        Assertions.assertEquals(1, new IntegerResultType().length());
     }
 
 }
