@@ -67,10 +67,10 @@ class ReactionManipulatorTest extends CDKTestCase {
     void testReverse_IReaction() {
         Reaction reaction = new Reaction();
         reaction.setDirection(IReaction.Direction.BACKWARD);
-        IAtomContainer water = new AtomContainer();
+        IAtomContainer water = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         reaction.addReactant(water, 3.0);
-        reaction.addReactant(new AtomContainer());
-        reaction.addProduct(new AtomContainer());
+        reaction.addReactant(DefaultChemObjectBuilder.getInstance().newAtomContainer());
+        reaction.addProduct(DefaultChemObjectBuilder.getInstance().newAtomContainer());
 
         Reaction reversedReaction = (Reaction) ReactionManipulator.reverse(reaction);
         Assertions.assertEquals(IReaction.Direction.FORWARD, reversedReaction.getDirection());
@@ -83,7 +83,7 @@ class ReactionManipulatorTest extends CDKTestCase {
     void testGetAllIDs_IReaction() {
         Reaction reaction = new Reaction();
         reaction.setID("r1");
-        IAtomContainer water = new AtomContainer();
+        IAtomContainer water = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         water.setID("m1");
         Atom oxygen = new Atom("O");
         oxygen.setID("a1");
@@ -151,22 +151,22 @@ class ReactionManipulatorTest extends CDKTestCase {
     }
 
     @Test
-    void testGetAtomCount_IReaction() throws Exception {
+    void testGetAtomCount_IReaction() {
         Assertions.assertEquals(19, ReactionManipulator.getAtomCount(reaction));
     }
 
     @Test
-    void testGetBondCount_IReaction() throws Exception {
+    void testGetBondCount_IReaction() {
         Assertions.assertEquals(18, ReactionManipulator.getBondCount(reaction));
     }
 
     @Test
-    void testGetAllAtomContainers_IReaction() throws Exception {
+    void testGetAllAtomContainers_IReaction() {
         Assertions.assertEquals(3, ReactionManipulator.getAllAtomContainers(reaction).size());
     }
 
     @Test
-    void testSetAtomProperties_IReactionSet_Object_Object() throws Exception {
+    void testSetAtomProperties_IReactionSet_Object_Object() {
         ReactionManipulator.setAtomProperties(reaction, "test", "ok");
         for (IAtomContainer container : ReactionManipulator.getAllAtomContainers(reaction)) {
             for (IAtom atom : container.atoms()) {
@@ -284,7 +284,7 @@ class ReactionManipulatorTest extends CDKTestCase {
         IAtomContainer mol = ReactionManipulator.toMolecule(reaction);
         assertThat(smigen.create(mol),
                 is("CCO.CC(=O)O.[H+].CCOC(=O)C.O"));
-        assertThat(smigen.createReactionSMILES(ReactionManipulator.toReaction(mol)),
+        assertThat(smigen.create(ReactionManipulator.toReaction(mol)),
                 is("CCO.CC(=O)O>[H+]>CCOC(=O)C.O"));
     }
 
@@ -298,7 +298,7 @@ class ReactionManipulatorTest extends CDKTestCase {
         IAtomContainer mol = ReactionManipulator.toMolecule(reaction);
         assertThat(smigen.create(mol),
                 is("[CH2]CO.CC(=O)O.[H+].CCOC(=O)C.O |^1:0|"));
-        assertThat(smigen.createReactionSMILES(ReactionManipulator.toReaction(mol)),
+        assertThat(smigen.create(ReactionManipulator.toReaction(mol)),
                 is("[CH2]CO.CC(=O)O>[H+]>CCOC(=O)C.O |^1:0|"));
     }
 
@@ -310,9 +310,9 @@ class ReactionManipulatorTest extends CDKTestCase {
     @Test
     void perceiveAtomTypesAndConfigureAtomsUnknownAtomTypeTest() throws CDKException {
         // arrange
-        IAtomContainer reactant = new AtomContainer();
+        IAtomContainer reactant = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         reactant.addAtom(new Atom("R"));
-        IAtomContainer product = new AtomContainer();
+        IAtomContainer product = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         reactant.addAtom(new Atom("C"));
         IReaction reaction = new Reaction();
         reaction.addReactant(reactant);
@@ -334,7 +334,7 @@ class ReactionManipulatorTest extends CDKTestCase {
         IAtom reactantOneAtomThree = new Atom("C");
         IBond reactantOneBondOne = new Bond(reactantOneAtomOne, reactantOneAtomTwo, Order.SINGLE);
         IBond reactantOneBondTwo = new Bond(reactantOneAtomTwo, reactantOneAtomThree, Order.DOUBLE);
-        IAtomContainer reactantOne = new AtomContainer();
+        IAtomContainer reactantOne = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         reactantOne.addAtom(reactantOneAtomOne);
         reactantOne.addAtom(reactantOneAtomTwo);
         reactantOne.addAtom(reactantOneAtomThree);
@@ -343,12 +343,12 @@ class ReactionManipulatorTest extends CDKTestCase {
 
         // reactant two: Br
         IAtom reactantTwoAtom1 = new Atom("Br");
-        IAtomContainer reactantTwo = new AtomContainer();
+        IAtomContainer reactantTwo = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         reactantTwo.addAtom(reactantTwoAtom1);
 
         // agent one: O
         IAtom agentOneAtomOne = new Atom("O");
-        IAtomContainer agentOne = new AtomContainer();
+        IAtomContainer agentOne = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         agentOne.addAtom(agentOneAtomOne);
 
         // product one: CC(Br)C
@@ -359,7 +359,7 @@ class ReactionManipulatorTest extends CDKTestCase {
         IBond productOneBondOne = new Bond(productOneAtomOne, productOneAtomTwo, Order.SINGLE);
         IBond productOneBondTwo = new Bond(productOneAtomTwo, productOneAtomThree, Order.SINGLE);
         IBond productOneBondThree = new Bond(productOneAtomTwo, productOneAtomFour, Order.SINGLE);
-        IAtomContainer productOne = new AtomContainer();
+        IAtomContainer productOne = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         productOne.addAtom(productOneAtomOne);
         productOne.addAtom(productOneAtomTwo);
         productOne.addAtom(productOneAtomThree);
@@ -431,7 +431,7 @@ class ReactionManipulatorTest extends CDKTestCase {
         reactantOneAtomThree.setFormalNeighbourCount(2);
         IBond reactantOneBondOne = new Bond(reactantOneAtomOne, reactantOneAtomTwo, Order.SINGLE);
         IBond reactantOneBondTwo = new Bond(reactantOneAtomTwo, reactantOneAtomThree, Order.DOUBLE);
-        IAtomContainer reactantOne = new AtomContainer();
+        IAtomContainer reactantOne = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         reactantOne.addAtom(reactantOneAtomOne);
         reactantOne.addAtom(reactantOneAtomTwo);
         reactantOne.addAtom(reactantOneAtomThree);
@@ -440,12 +440,12 @@ class ReactionManipulatorTest extends CDKTestCase {
 
         // reactant two: Br
         IAtom reactantTwoAtom1 = new Atom("Br");
-        IAtomContainer reactantTwo = new AtomContainer();
+        IAtomContainer reactantTwo = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         reactantTwo.addAtom(reactantTwoAtom1);
 
         // agent one: O
         IAtom agentOneAtomOne = new Atom("O");
-        IAtomContainer agentOne = new AtomContainer();
+        IAtomContainer agentOne = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         agentOne.addAtom(agentOneAtomOne);
 
         // product one: CC(Br)C
@@ -458,7 +458,7 @@ class ReactionManipulatorTest extends CDKTestCase {
         IBond productOneBondOne = new Bond(productOneAtomOne, productOneAtomTwo, Order.SINGLE);
         IBond productOneBondTwo = new Bond(productOneAtomTwo, productOneAtomThree, Order.SINGLE);
         IBond productOneBondThree = new Bond(productOneAtomTwo, productOneAtomFour, Order.SINGLE);
-        IAtomContainer productOne = new AtomContainer();
+        IAtomContainer productOne = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         productOne.addAtom(productOneAtomOne);
         productOne.addAtom(productOneAtomTwo);
         productOne.addAtom(productOneAtomThree);
@@ -547,7 +547,7 @@ class ReactionManipulatorTest extends CDKTestCase {
         IAtom reactantOneAtomThree = new Atom("C");
         IBond reactantOneBondOne = new Bond(reactantOneAtomOne, reactantOneAtomTwo, Order.SINGLE);
         IBond reactantOneBondTwo = new Bond(reactantOneAtomTwo, reactantOneAtomThree, Order.DOUBLE);
-        IAtomContainer reactantOne = new AtomContainer();
+        IAtomContainer reactantOne = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         reactantOne.addAtom(reactantOneAtomOne);
         reactantOne.addAtom(reactantOneAtomTwo);
         reactantOne.addAtom(reactantOneAtomThree);
@@ -556,12 +556,12 @@ class ReactionManipulatorTest extends CDKTestCase {
 
         // reactant two: Br
         IAtom reactantTwoAtom1 = new Atom("Br");
-        IAtomContainer reactantTwo = new AtomContainer();
+        IAtomContainer reactantTwo = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         reactantTwo.addAtom(reactantTwoAtom1);
 
         // agent one: O
         IAtom agentOneAtomOne = new Atom("O");
-        IAtomContainer agentOne = new AtomContainer();
+        IAtomContainer agentOne = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         agentOne.addAtom(agentOneAtomOne);
 
         // product one: CC(Br)C
@@ -572,7 +572,7 @@ class ReactionManipulatorTest extends CDKTestCase {
         IBond productOneBondOne = new Bond(productOneAtomOne, productOneAtomTwo, Order.SINGLE);
         IBond productOneBondTwo = new Bond(productOneAtomTwo, productOneAtomThree, Order.SINGLE);
         IBond productOneBondThree = new Bond(productOneAtomTwo, productOneAtomFour, Order.SINGLE);
-        IAtomContainer productOne = new AtomContainer();
+        IAtomContainer productOne = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         productOne.addAtom(productOneAtomOne);
         productOne.addAtom(productOneAtomTwo);
         productOne.addAtom(productOneAtomThree);
