@@ -21,9 +21,9 @@ package org.openscience.cdk.tools.manipulator;
 import java.util.ArrayList;
 import java.util.Iterator;
 
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.interfaces.IAtomContainerSet;
@@ -36,22 +36,22 @@ import org.openscience.cdk.interfaces.IReactionSet;
 /**
  * @cdk.module test-standard
  */
-public class ReactionSchemeManipulatorTest extends CDKTestCase {
+class ReactionSchemeManipulatorTest extends CDKTestCase {
 
     private IChemObjectBuilder builder;
 
-    public ReactionSchemeManipulatorTest() {
+    ReactionSchemeManipulatorTest() {
         super();
     }
 
-    @Before
-    public void setUp() throws Exception {
+    @BeforeEach
+    void setUp() throws Exception {
         builder = DefaultChemObjectBuilder.getInstance();
 
     }
 
     @Test
-    public void testGetAllMolecules_IReactionScheme() {
+    void testGetAllMolecules_IReactionScheme() {
         IReactionScheme reactionScheme = builder.newInstance(IReactionScheme.class);
         IReaction reaction1 = builder.newInstance(IReaction.class);
         reaction1.addProduct(builder.newInstance(IAtomContainer.class));
@@ -60,12 +60,12 @@ public class ReactionSchemeManipulatorTest extends CDKTestCase {
         reactionScheme.addReaction(reaction1); // 1
         reactionScheme.addReaction(reaction2); // 2
 
-        Assert.assertEquals(2, ReactionSchemeManipulator.getAllAtomContainers(reactionScheme).getAtomContainerCount());
+        Assertions.assertEquals(2, ReactionSchemeManipulator.getAllAtomContainers(reactionScheme).getAtomContainerCount());
 
     }
 
     @Test
-    public void testGetAllMolecules_IReactionScheme_IAtomContainerSet() {
+    void testGetAllMolecules_IReactionScheme_IAtomContainerSet() {
         IReactionScheme reactionScheme = builder.newInstance(IReactionScheme.class);
         IReaction reaction1 = builder.newInstance(IReaction.class);
         reaction1.addProduct(builder.newInstance(IAtomContainer.class));
@@ -74,15 +74,13 @@ public class ReactionSchemeManipulatorTest extends CDKTestCase {
         reactionScheme.addReaction(reaction1); // 1
         reactionScheme.addReaction(reaction2); // 2
 
-        Assert.assertEquals(
-                2,
-                ReactionSchemeManipulator.getAllAtomContainers(reactionScheme,
-                        builder.newInstance(IAtomContainerSet.class)).getAtomContainerCount());
+        Assertions.assertEquals(2, ReactionSchemeManipulator.getAllAtomContainers(reactionScheme,
+                                                                                  builder.newInstance(IAtomContainerSet.class)).getAtomContainerCount());
 
     }
 
     @Test
-    public void testGetAllMolecules_IReactionScheme2() {
+    void testGetAllMolecules_IReactionScheme2() {
         IReactionScheme reactionScheme = builder.newInstance(IReactionScheme.class);
         IReaction reaction1 = builder.newInstance(IReaction.class);
         IAtomContainer molecule = builder.newInstance(IAtomContainer.class);
@@ -94,12 +92,12 @@ public class ReactionSchemeManipulatorTest extends CDKTestCase {
         reaction2.addReactant(molecule);
         reactionScheme.addReaction(reaction2);
 
-        Assert.assertEquals(3, ReactionSchemeManipulator.getAllAtomContainers(reactionScheme).getAtomContainerCount());
+        Assertions.assertEquals(3, ReactionSchemeManipulator.getAllAtomContainers(reactionScheme).getAtomContainerCount());
 
     }
 
     @Test
-    public void testGetAllMolecules_IReactionScheme3() {
+    void testGetAllMolecules_IReactionScheme3() {
         IReactionScheme scheme1 = builder.newInstance(IReactionScheme.class);
 
         IReactionScheme scheme11 = builder.newInstance(IReactionScheme.class);
@@ -125,12 +123,12 @@ public class ReactionSchemeManipulatorTest extends CDKTestCase {
         reaction11.addProduct(builder.newInstance(IAtomContainer.class));
         scheme1.addReaction(reaction11);
 
-        Assert.assertEquals(5, ReactionSchemeManipulator.getAllAtomContainers(scheme1).getAtomContainerCount());
+        Assertions.assertEquals(5, ReactionSchemeManipulator.getAllAtomContainers(scheme1).getAtomContainerCount());
 
     }
 
     @Test
-    public void testGetAllIDs_IReactionScheme() {
+    void testGetAllIDs_IReactionScheme() {
         IReactionScheme scheme1 = builder.newInstance(IReactionScheme.class);
         scheme1.setID("scheme1");
 
@@ -164,12 +162,12 @@ public class ReactionSchemeManipulatorTest extends CDKTestCase {
         reaction11.addProduct(builder.newInstance(IAtomContainer.class));
         scheme1.addReaction(reaction11);
 
-        Assert.assertEquals(6, ReactionSchemeManipulator.getAllIDs(scheme1).size());
+        Assertions.assertEquals(6, ReactionSchemeManipulator.getAllIDs(scheme1).size());
 
     }
 
     @Test
-    public void testCreateReactionScheme_IReactionSet() {
+    void testCreateReactionScheme_IReactionSet() {
         IAtomContainer molA = builder.newInstance(IAtomContainer.class);
         molA.setID("A");
         IAtomContainer molB = builder.newInstance(IAtomContainer.class);
@@ -207,27 +205,27 @@ public class ReactionSchemeManipulatorTest extends CDKTestCase {
         reactionSet.addReaction(reaction4);
 
         IReactionScheme scheme1 = ReactionSchemeManipulator.createReactionScheme(reactionSet);
-        Assert.assertEquals(1, scheme1.getReactionCount());
-        Assert.assertEquals("r1", scheme1.getReaction(0).getID());
-        Assert.assertEquals(1, scheme1.getReactionSchemeCount());
+        Assertions.assertEquals(1, scheme1.getReactionCount());
+        Assertions.assertEquals("r1", scheme1.getReaction(0).getID());
+        Assertions.assertEquals(1, scheme1.getReactionSchemeCount());
 
         Iterator<IReactionScheme> iter = scheme1.reactionSchemes().iterator();
         IReactionScheme scheme2 = iter.next();
-        Assert.assertEquals(2, scheme2.getReactionCount());
-        Assert.assertEquals("r2", scheme2.getReaction(0).getID());
-        Assert.assertEquals("r3", scheme2.getReaction(1).getID());
-        Assert.assertEquals(1, scheme2.getReactionSchemeCount());
+        Assertions.assertEquals(2, scheme2.getReactionCount());
+        Assertions.assertEquals("r2", scheme2.getReaction(0).getID());
+        Assertions.assertEquals("r3", scheme2.getReaction(1).getID());
+        Assertions.assertEquals(1, scheme2.getReactionSchemeCount());
 
         Iterator<IReactionScheme> iter2 = scheme2.reactionSchemes().iterator();
         IReactionScheme scheme3 = iter2.next();
-        Assert.assertEquals(1, scheme3.getReactionCount());
-        Assert.assertEquals("r4", scheme3.getReaction(0).getID());
-        Assert.assertEquals(0, scheme3.getReactionSchemeCount());
+        Assertions.assertEquals(1, scheme3.getReactionCount());
+        Assertions.assertEquals("r4", scheme3.getReaction(0).getID());
+        Assertions.assertEquals(0, scheme3.getReactionSchemeCount());
 
     }
 
     @Test
-    public void testGetMoleculeSet_IAtomContainer_IAtomContainer_IReactionScheme() {
+    void testGetMoleculeSet_IAtomContainer_IAtomContainer_IReactionScheme() {
         IReactionScheme scheme1 = builder.newInstance(IReactionScheme.class);
 
         IReactionScheme scheme11 = builder.newInstance(IReactionScheme.class);
@@ -264,15 +262,15 @@ public class ReactionSchemeManipulatorTest extends CDKTestCase {
 
         ArrayList<IAtomContainerSet> listSet = ReactionSchemeManipulator.getAtomContainerSet(startMol, finalMol,
                 scheme1);
-        Assert.assertEquals(1, listSet.size());
+        Assertions.assertEquals(1, listSet.size());
         IAtomContainerSet moleculeSet = listSet.get(0);
-        Assert.assertEquals("startMol", moleculeSet.getAtomContainer(0).getID());
-        Assert.assertEquals("mitMol", moleculeSet.getAtomContainer(1).getID());
-        Assert.assertEquals("finalMol", moleculeSet.getAtomContainer(2).getID());
+        Assertions.assertEquals("startMol", moleculeSet.getAtomContainer(0).getID());
+        Assertions.assertEquals("mitMol", moleculeSet.getAtomContainer(1).getID());
+        Assertions.assertEquals("finalMol", moleculeSet.getAtomContainer(2).getID());
     }
 
     @Test
-    public void testGetAllReactions_IReactionScheme() {
+    void testGetAllReactions_IReactionScheme() {
         IReactionScheme scheme1 = builder.newInstance(IReactionScheme.class);
 
         IReactionScheme scheme11 = builder.newInstance(IReactionScheme.class);
@@ -304,15 +302,15 @@ public class ReactionSchemeManipulatorTest extends CDKTestCase {
         scheme1.addReaction(reaction11);
 
         IReactionSet reactionSet = ReactionSchemeManipulator.getAllReactions(scheme1);
-        Assert.assertEquals(4, reactionSet.getReactionCount());
-        Assert.assertEquals(reaction1, reactionSet.getReaction(0));
-        Assert.assertEquals(reaction2, reactionSet.getReaction(1));
-        Assert.assertEquals(reaction3, reactionSet.getReaction(2));
-        Assert.assertEquals(reaction11, reactionSet.getReaction(3));
+        Assertions.assertEquals(4, reactionSet.getReactionCount());
+        Assertions.assertEquals(reaction1, reactionSet.getReaction(0));
+        Assertions.assertEquals(reaction2, reactionSet.getReaction(1));
+        Assertions.assertEquals(reaction3, reactionSet.getReaction(2));
+        Assertions.assertEquals(reaction11, reactionSet.getReaction(3));
     }
 
     @Test
-    public void testExtractTopReactions_IReactionScheme() {
+    void testExtractTopReactions_IReactionScheme() {
         IReactionScheme scheme1 = builder.newInstance(IReactionScheme.class);
         IReaction reaction1 = builder.newInstance(IReaction.class);
         IAtomContainer molA = builder.newInstance(IAtomContainer.class);
@@ -342,8 +340,8 @@ public class ReactionSchemeManipulatorTest extends CDKTestCase {
         scheme1.addReaction(reaction4);
 
         IReactionSet reactionSet = ReactionSchemeManipulator.extractTopReactions(scheme1);
-        Assert.assertEquals(2, reactionSet.getReactionCount());
-        Assert.assertEquals(reaction1, reactionSet.getReaction(0));
-        Assert.assertEquals(reaction4, reactionSet.getReaction(1));
+        Assertions.assertEquals(2, reactionSet.getReactionCount());
+        Assertions.assertEquals(reaction1, reactionSet.getReaction(0));
+        Assertions.assertEquals(reaction4, reactionSet.getReaction(1));
     }
 }
