@@ -21,10 +21,6 @@ package org.openscience.cdk.tools;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
-import org.openscience.cdk.Atom;
-import org.openscience.cdk.AtomType;
-import org.openscience.cdk.Bond;
-import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.config.Elements;
 import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.exception.InvalidSmilesException;
@@ -33,8 +29,8 @@ import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IAtomType;
 import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IBond.Order;
+import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.interfaces.IElement;
-import org.openscience.cdk.silent.AtomContainer;
 import org.openscience.cdk.silent.SilentChemObjectBuilder;
 import org.openscience.cdk.smiles.SmilesParser;
 import org.openscience.cdk.test.CDKTestCase;
@@ -68,32 +64,26 @@ class ATASaturationCheckerTest extends CDKTestCase {
     @Test
     void testASimpleCarbonRing() throws Exception {
         // First we create a simple carbon ring to play with...
-        IAtomContainer mol = new AtomContainer();
-        IAtomType carbon = new AtomType(Elements.CARBON);
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
+        IAtomType carbon = mol.getBuilder().newInstance(IAtomType.class, Elements.CARBON);
 
-        IAtom a0 = new Atom("C");
+        IAtom a0 = mol.newAtom(6, 1);
         a0.setHybridization(IAtomType.Hybridization.SP2);
-        a0.setImplicitHydrogenCount(1);
         AtomTypeManipulator.configureUnsetProperties(a0, carbon);
-        IAtom a1 = new Atom("C");
+        IAtom a1 = mol.newAtom(6, 1);
         a1.setHybridization(IAtomType.Hybridization.SP2);
-        a1.setImplicitHydrogenCount(1);
         AtomTypeManipulator.configureUnsetProperties(a1, carbon);
-        IAtom a2 = new Atom("C");
+        IAtom a2 = mol.newAtom(6, 1);
         a2.setHybridization(IAtomType.Hybridization.SP2);
-        a2.setImplicitHydrogenCount(1);
         AtomTypeManipulator.configureUnsetProperties(a2, carbon);
-        IAtom a3 = new Atom("C");
+        IAtom a3 = mol.newAtom(6, 1);
         a3.setHybridization(IAtomType.Hybridization.SP2);
-        a3.setImplicitHydrogenCount(1);
         AtomTypeManipulator.configureUnsetProperties(a3, carbon);
-        IAtom a4 = new Atom("C");
+        IAtom a4 = mol.newAtom(6, 1);
         a4.setHybridization(IAtomType.Hybridization.SP2);
-        a4.setImplicitHydrogenCount(1);
         AtomTypeManipulator.configureUnsetProperties(a4, carbon);
-        IAtom a5 = new Atom("C");
+        IAtom a5 = mol.newAtom(6, 1);
         a5.setHybridization(IAtomType.Hybridization.SP2);
-        a5.setImplicitHydrogenCount(1);
         AtomTypeManipulator.configureUnsetProperties(a5, carbon);
 
         mol.addAtom(a0);
@@ -103,24 +93,18 @@ class ATASaturationCheckerTest extends CDKTestCase {
         mol.addAtom(a4);
         mol.addAtom(a5);
 
-        IBond b0 = new Bond(a0, a1);
-        b0.setFlag(CDKConstants.SINGLE_OR_DOUBLE, true);
-        mol.addBond(b0);
-        IBond b1 = new Bond(a1, a2);
-        b1.setFlag(CDKConstants.SINGLE_OR_DOUBLE, true);
-        mol.addBond(b1);
-        IBond b2 = new Bond(a2, a3);
-        b2.setFlag(CDKConstants.SINGLE_OR_DOUBLE, true);
-        mol.addBond(b2);
-        IBond b3 = new Bond(a3, a4);
-        b3.setFlag(CDKConstants.SINGLE_OR_DOUBLE, true);
-        mol.addBond(b3);
-        IBond b4 = new Bond(a4, a5);
-        b4.setFlag(CDKConstants.SINGLE_OR_DOUBLE, true);
-        mol.addBond(b4);
-        IBond b5 = new Bond(a5, a0);
-        b5.setFlag(CDKConstants.SINGLE_OR_DOUBLE, true);
-        mol.addBond(b5);
+        IBond b0 = mol.newBond(a0, a1);
+        b0.setFlag(IChemObject.SINGLE_OR_DOUBLE, true);
+        IBond b1 = mol.newBond(a1, a2);
+        b1.setFlag(IChemObject.SINGLE_OR_DOUBLE, true);
+        IBond b2 = mol.newBond(a2, a3);
+        b2.setFlag(IChemObject.SINGLE_OR_DOUBLE, true);
+        IBond b3 = mol.newBond(a3, a4);
+        b3.setFlag(IChemObject.SINGLE_OR_DOUBLE, true);
+        IBond b4 = mol.newBond(a4, a5);
+        b4.setFlag(IChemObject.SINGLE_OR_DOUBLE, true);
+        IBond b5 = mol.newBond(a5, a0);
+        b5.setFlag(IChemObject.SINGLE_OR_DOUBLE, true);
 
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         AtomTypeTools att = new AtomTypeTools();
@@ -583,7 +567,7 @@ class ATASaturationCheckerTest extends CDKTestCase {
          * molecule don't have any rings
          */
         for (IBond bond : mol.bonds())
-            bond.setFlag(CDKConstants.SINGLE_OR_DOUBLE, true);
+            bond.setFlag(IChemObject.SINGLE_OR_DOUBLE, true);
 
         atasc.decideBondOrder(mol, false);
 
@@ -596,24 +580,20 @@ class ATASaturationCheckerTest extends CDKTestCase {
 
     @Test
     void testButadiene() throws Exception {
-        IAtomContainer mol = new AtomContainer();
-        IAtomType carbon = new AtomType(Elements.CARBON);
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
+        IAtomType carbon = mol.getBuilder().newInstance(IAtomType.class, Elements.CARBON);
 
-        IAtom a0 = new Atom("C");
+        IAtom a0 = mol.newAtom(6, 2);
         a0.setHybridization(IAtomType.Hybridization.SP2);
-        a0.setImplicitHydrogenCount(2);
         AtomTypeManipulator.configureUnsetProperties(a0, carbon);
-        IAtom a1 = new Atom("C");
+        IAtom a1 = mol.newAtom(6, 1);
         a1.setHybridization(IAtomType.Hybridization.SP2);
-        a1.setImplicitHydrogenCount(1);
         AtomTypeManipulator.configureUnsetProperties(a1, carbon);
-        IAtom a2 = new Atom("C");
+        IAtom a2 = mol.newAtom(6, 1);
         a2.setHybridization(IAtomType.Hybridization.SP2);
-        a2.setImplicitHydrogenCount(1);
         AtomTypeManipulator.configureUnsetProperties(a2, carbon);
-        IAtom a3 = new Atom("C");
+        IAtom a3 = mol.newAtom(6, 2);
         a3.setHybridization(IAtomType.Hybridization.SP2);
-        a3.setImplicitHydrogenCount(2);
         AtomTypeManipulator.configureUnsetProperties(a3, carbon);
 
         mol.addAtom(a0);
@@ -621,15 +601,12 @@ class ATASaturationCheckerTest extends CDKTestCase {
         mol.addAtom(a2);
         mol.addAtom(a3);
 
-        IBond b0 = new Bond(a0, a1);
-        b0.setFlag(CDKConstants.SINGLE_OR_DOUBLE, true);
-        mol.addBond(b0);
-        IBond b1 = new Bond(a1, a2);
-        b1.setFlag(CDKConstants.SINGLE_OR_DOUBLE, true);
-        mol.addBond(b1);
-        IBond b2 = new Bond(a2, a3);
-        b2.setFlag(CDKConstants.SINGLE_OR_DOUBLE, true);
-        mol.addBond(b2);
+        IBond b0 = mol.newBond(a0, a1);
+        b0.setFlag(IChemObject.SINGLE_OR_DOUBLE, true);
+        IBond b1 = mol.newBond(a1, a2);
+        b1.setFlag(IChemObject.SINGLE_OR_DOUBLE, true);
+        IBond b2 = mol.newBond(a2, a3);
+        b2.setFlag(IChemObject.SINGLE_OR_DOUBLE, true);
 
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         AtomTypeTools att = new AtomTypeTools();
