@@ -28,7 +28,7 @@ import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.Bond;
-import org.openscience.cdk.CDKConstants;
+import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.ChemFile;
 import org.openscience.cdk.PseudoAtom;
@@ -44,7 +44,6 @@ import org.openscience.cdk.interfaces.IChemObjectBuilder;
 import org.openscience.cdk.interfaces.IElement;
 import org.openscience.cdk.interfaces.IMolecularFormula;
 import org.openscience.cdk.io.MDLV2000Reader;
-import org.openscience.cdk.silent.AtomContainer;
 import org.openscience.cdk.silent.SilentChemObjectBuilder;
 import org.openscience.cdk.tools.manipulator.AtomContainerManipulator;
 import org.openscience.cdk.tools.manipulator.AtomTypeManipulator;
@@ -77,7 +76,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testMethane() throws Exception {
-        IAtomContainer molecule = new AtomContainer();
+        IAtomContainer molecule = SilentChemObjectBuilder.getInstance().newAtomContainer();
         IAtom newAtom = new Atom(Elements.CARBON);
         molecule.addAtom(newAtom);
         IAtomType type = matcher.findMatchingAtomType(molecule, newAtom);
@@ -92,7 +91,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testFormaldehyde() throws Exception {
-        IAtomContainer molecule = new AtomContainer();
+        IAtomContainer molecule = SilentChemObjectBuilder.getInstance().newAtomContainer();
         IAtom newAtom = new Atom(Elements.CARBON);
         IAtom newAtom2 = new Atom(Elements.OXYGEN);
         molecule.addAtom(newAtom);
@@ -115,7 +114,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testMethanol() throws Exception {
-        IAtomContainer molecule = new AtomContainer();
+        IAtomContainer molecule = SilentChemObjectBuilder.getInstance().newAtomContainer();
         IAtom newAtom = new Atom(Elements.CARBON);
         IAtom newAtom2 = new Atom(Elements.OXYGEN);
         molecule.addAtom(newAtom);
@@ -138,7 +137,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testHCN() throws Exception {
-        IAtomContainer molecule = new AtomContainer();
+        IAtomContainer molecule = SilentChemObjectBuilder.getInstance().newAtomContainer();
         IAtom newAtom = new Atom(Elements.CARBON);
         IAtom newAtom2 = new Atom(Elements.NITROGEN);
         molecule.addAtom(newAtom);
@@ -161,7 +160,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testMethylAmine() throws Exception {
-        IAtomContainer molecule = new AtomContainer();
+        IAtomContainer molecule = SilentChemObjectBuilder.getInstance().newAtomContainer();
         IAtom newAtom = new Atom(Elements.CARBON);
         IAtom newAtom2 = new Atom(Elements.NITROGEN);
         molecule.addAtom(newAtom);
@@ -184,7 +183,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testMethyleneImine() throws Exception {
-        IAtomContainer molecule = new AtomContainer();
+        IAtomContainer molecule = SilentChemObjectBuilder.getInstance().newAtomContainer();
         IAtom newAtom = new Atom(Elements.CARBON);
         IAtom newAtom2 = new Atom(Elements.NITROGEN);
         molecule.addAtom(newAtom);
@@ -207,7 +206,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testSulphur() throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
         Atom atom = new Atom("S");
         mol.addAtom(atom);
         IAtomType type = matcher.findMatchingAtomType(mol, atom);
@@ -223,7 +222,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testProton() throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
         Atom proton = new Atom("H");
         proton.setFormalCharge(+1);
         mol.addAtom(proton);
@@ -243,7 +242,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testHydrogen() throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
         Atom proton = new Atom("H");
         mol.addAtom(proton);
         IAtomType type = matcher.findMatchingAtomType(mol, proton);
@@ -262,7 +261,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testAmmonia() throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
         Atom nitrogen = new Atom("N");
         mol.addAtom(nitrogen);
         IAtomType type = matcher.findMatchingAtomType(mol, nitrogen);
@@ -276,7 +275,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testAmmonium() throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
         Atom nitrogen = new Atom("N");
         nitrogen.setFormalCharge(+1);
         mol.addAtom(nitrogen);
@@ -291,7 +290,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testWater() throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
         Atom oxygen = new Atom("O");
         mol.addAtom(oxygen);
         IAtomType type = matcher.findMatchingAtomType(mol, oxygen);
@@ -305,7 +304,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testHydroxonium() throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
         Atom oxygen = new Atom("O");
         oxygen.setFormalCharge(+1);
         mol.addAtom(oxygen);
@@ -320,7 +319,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testHydroxyl() throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
         Atom oxygen = new Atom("O");
         oxygen.setFormalCharge(-1);
         mol.addAtom(oxygen);
@@ -350,7 +349,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
     }
 
     private void halogenTest(String halogen) throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
         Atom atom = new Atom(halogen);
         mol.addAtom(atom);
         IAtomType type = matcher.findMatchingAtomType(mol, atom);
@@ -364,7 +363,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
     }
 
     private void negativeHalogenTest(String halogen) throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
         Atom atom = new Atom(halogen);
         atom.setFormalCharge(-1);
         mol.addAtom(atom);
@@ -380,7 +379,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testSulfite() throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
         Atom s = new Atom("S");
         Atom o1 = new Atom("O");
         Atom o2 = new Atom("O");
@@ -425,7 +424,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testAceticAcid() throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
         Atom carbonylOxygen = new Atom("O");
         Atom hydroxylOxygen = new Atom("O");
         Atom methylCarbon = new Atom("C");
@@ -453,7 +452,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testEthane() throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
         Atom carbon1 = new Atom("C");
         Atom carbon2 = new Atom("C");
         Bond b = new Bond(carbon1, carbon2, IBond.Order.SINGLE);
@@ -471,7 +470,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testEthaneWithPresetImplicitHCount() throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
         Atom carbon1 = new Atom("C");
         Atom carbon2 = new Atom("C");
         Bond b = new Bond(carbon1, carbon2, IBond.Order.SINGLE);
@@ -492,7 +491,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testEthene() throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
         Atom carbon1 = new Atom("C");
         Atom carbon2 = new Atom("C");
         Bond b = new Bond(carbon1, carbon2, IBond.Order.DOUBLE);
@@ -510,7 +509,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testEthyne() throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
         Atom carbon1 = new Atom("C");
         Atom carbon2 = new Atom("C");
         Bond b = new Bond(carbon1, carbon2, IBond.Order.TRIPLE);
@@ -528,7 +527,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testAromaticSaturation() throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
         mol.addAtom(new Atom("C")); // 0
         mol.addAtom(new Atom("C")); // 1
         mol.addAtom(new Atom("C")); // 2
@@ -548,9 +547,9 @@ class CDKHydrogenAdderTest extends CDKTestCase {
         mol.addBond(6, 7, IBond.Order.TRIPLE); // 8
 
         for (int f = 0; f < 6; f++) {
-            mol.getAtom(f).setFlag(CDKConstants.ISAROMATIC, true);
+            mol.getAtom(f).setFlag(IChemObject.AROMATIC, true);
             mol.getAtom(f).setHybridization(IAtomType.Hybridization.SP2);
-            mol.getBond(f).setFlag(CDKConstants.ISAROMATIC, true);
+            mol.getBond(f).setFlag(IChemObject.AROMATIC, true);
         }
         findAndConfigureAtomTypesForAllAtoms(mol);
         adder.addImplicitHydrogens(mol);
@@ -559,7 +558,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testaddImplicitHydrogensToSatisfyValency_OldValue() throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
         mol.addAtom(new Atom("C"));
         Atom oxygen = new Atom("O");
         mol.addAtom(oxygen);
@@ -577,7 +576,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testAdenine() throws Exception {
-        IAtomContainer mol = new AtomContainer(); // Adenine
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer(); // Adenine
         IAtom a1 = mol.getBuilder().newInstance(IAtom.class, "C");
         a1.setPoint2d(new Point2d(21.0223, -17.2946));
         mol.addAtom(a1);
@@ -646,7 +645,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
         String filename = "carbocations.mol";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         MDLV2000Reader reader = new MDLV2000Reader(ins);
-        molecule = reader.read(new AtomContainer());
+        molecule = reader.read(SilentChemObjectBuilder.getInstance().newAtomContainer());
         findAndConfigureAtomTypesForAllAtoms(molecule);
         adder.addImplicitHydrogens(molecule);
         Assertions.assertEquals(2, molecule.getAtom(0).getImplicitHydrogenCount().intValue());
@@ -663,7 +662,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
         String filename = "furan.mol";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         MDLV2000Reader reader = new MDLV2000Reader(ins);
-        IAtomContainer molecule = reader.read(new AtomContainer());
+        IAtomContainer molecule = reader.read(SilentChemObjectBuilder.getInstance().newAtomContainer());
         findAndConfigureAtomTypesForAllAtoms(molecule);
         adder.addImplicitHydrogens(molecule);
         Assertions.assertEquals(1, molecule.getAtom(0).getImplicitHydrogenCount().intValue());
@@ -677,7 +676,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
         String filename = "furan.mol";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         MDLV2000Reader reader = new MDLV2000Reader(ins);
-        IAtomContainer molecule = reader.read(new AtomContainer());
+        IAtomContainer molecule = reader.read(SilentChemObjectBuilder.getInstance().newAtomContainer());
         findAndConfigureAtomTypesForAllAtoms(molecule);
         for (IAtom atom : molecule.atoms()) {
             adder.addImplicitHydrogens(molecule, atom);
@@ -690,7 +689,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testPseudoAtom() throws Exception {
-        IAtomContainer molecule = new AtomContainer();
+        IAtomContainer molecule = SilentChemObjectBuilder.getInstance().newAtomContainer();
         molecule.addAtom(new PseudoAtom("Waterium"));
         findAndConfigureAtomTypesForAllAtoms(molecule);
         Assertions.assertNull(molecule.getAtom(0).getImplicitHydrogenCount());
@@ -698,7 +697,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testNaCl() throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
         Atom cl = new Atom("Cl");
         cl.setFormalCharge(-1);
         mol.addAtom(cl);
@@ -750,7 +749,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
      */
     @Test
     void testBug1627763() throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
         mol.addAtom(mol.getBuilder().newInstance(IAtom.class, "C"));
         mol.addAtom(mol.getBuilder().newInstance(IAtom.class, "O"));
         mol.addBond(mol.getBuilder().newInstance(IBond.class, mol.getAtom(0), mol.getAtom(1),
@@ -772,7 +771,7 @@ class CDKHydrogenAdderTest extends CDKTestCase {
 
     @Test
     void testMercaptan() throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = SilentChemObjectBuilder.getInstance().newAtomContainer();
         mol.addAtom(mol.getBuilder().newInstance(IAtom.class, "C"));
         mol.addAtom(mol.getBuilder().newInstance(IAtom.class, "C"));
         mol.addAtom(mol.getBuilder().newInstance(IAtom.class, "C"));
