@@ -38,6 +38,20 @@ public abstract class AbstractReactionTest extends AbstractChemObjectTest {
         Assertions.assertEquals(1, reaction.getProductCount());
     }
 
+    @Test
+    void getAgentCount_test() {
+        IReaction reaction = (IReaction) newChemObject();
+        Assertions.assertEquals(0, reaction.getAgentCount());
+
+        reaction.addReactant(reaction.getBuilder().newInstance(IAtomContainer.class));
+        reaction.addReactant(reaction.getBuilder().newInstance(IAtomContainer.class));
+        reaction.addProduct(reaction.getBuilder().newInstance(IAtomContainer.class));
+        Assertions.assertEquals(0, reaction.getAgentCount());
+
+        reaction.addAgent(reaction.getBuilder().newInstance(IAtomContainer.class));
+        Assertions.assertEquals(1, reaction.getAgentCount());
+    }
+
     @Test
     public void testAddReactant_IAtomContainer() {
         IReaction reaction = (IReaction) newChemObject();
@@ -296,7 +310,7 @@ public abstract class AbstractReactionTest extends AbstractChemObjectTest {
         IReaction reaction = (IReaction) newChemObject();
         Object clone = reaction.clone();
         Assertions.assertNotNull(clone);
-        Assertions.assertTrue(clone instanceof IReaction);
+        Assertions.assertInstanceOf(IReaction.class, clone);
     }
 
     @Test
@@ -370,4 +384,26 @@ public abstract class AbstractReactionTest extends AbstractChemObjectTest {
         reaction.addMapping(mapping);
         Assertions.assertEquals(1, reaction.getMappingCount());
     }
+
+    @Test
+    public void testIterator() {
+        IReaction reaction = (IReaction) newChemObject();
+        IAtomContainer r1 = reaction.getBuilder().newInstance(IAtomContainer.class);
+        IAtomContainer r2 = reaction.getBuilder().newInstance(IAtomContainer.class);
+        IAtomContainer a1 = reaction.getBuilder().newInstance(IAtomContainer.class);
+        IAtomContainer a2 = reaction.getBuilder().newInstance(IAtomContainer.class);
+        IAtomContainer p  = reaction.getBuilder().newInstance(IAtomContainer.class);
+        reaction.addReactant(r1);
+        reaction.addReactant(r2);
+        reaction.addAgent(a1);
+        reaction.addAgent(a2);
+        reaction.addProduct(p);
+        Iterator<IAtomContainer> iterator = reaction.iterator();
+        Assertions.assertEquals(r1, iterator.next());
+        Assertions.assertEquals(r2, iterator.next());
+        Assertions.assertEquals(a1, iterator.next());
+        Assertions.assertEquals(a2, iterator.next());
+        Assertions.assertEquals(p, iterator.next());
+        Assertions.assertFalse(iterator.hasNext());
+    }
 }
