@@ -22,8 +22,8 @@
  */
 package org.openscience.cdk.geometry.cip;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.silent.SilentChemObjectBuilder;
@@ -32,17 +32,17 @@ import org.openscience.cdk.smiles.SmilesParser;
 /**
  * @cdk.module test-cip
  */
-public class ImplicitHydrogenLigandTest extends CDKTestCase {
+class ImplicitHydrogenLigandTest extends CDKTestCase {
 
     @Test
-    public void testConstructorAndGetMethods() throws Exception {
+    void testConstructorAndGetMethods() throws Exception {
         SmilesParser smiles = new SmilesParser(SilentChemObjectBuilder.getInstance());
         IAtomContainer molecule = smiles.parseSmiles("ClC(Br)(I)");
 
         ILigand ligand = new ImplicitHydrogenLigand(molecule, new VisitedAtoms(), molecule.getAtom(1));
-        Assert.assertNotNull(ligand);
-        Assert.assertEquals(molecule, ligand.getAtomContainer());
-        Assert.assertEquals(molecule.getAtom(1), ligand.getCentralAtom());
-        Assert.assertTrue(ligand.getLigandAtom() instanceof ImmutableHydrogen);
+        Assertions.assertNotNull(ligand);
+        Assertions.assertEquals(molecule, ligand.getAtomContainer());
+        Assertions.assertEquals(molecule.getAtom(1), ligand.getCentralAtom());
+        Assertions.assertTrue(ligand.getLigandAtom() instanceof ImmutableHydrogen);
     }
 }
