@@ -24,7 +24,6 @@ package org.openscience.cdk.fingerprint;
 
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
-import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.aromaticity.Aromaticity;
 import org.openscience.cdk.aromaticity.Kekulization;
@@ -32,6 +31,7 @@ import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
+import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.interfaces.IChemObjectBuilder;
 import org.openscience.cdk.io.IChemObjectReader.Mode;
 import org.openscience.cdk.io.MDLV2000Reader;
@@ -229,16 +229,16 @@ abstract class AbstractFixedLengthFingerprinterTest extends AbstractFingerprinte
         IAtom a3 = builder.newInstance(IAtom.class, "O");
         mol.addAtom(a3);
         IAtom a4 = builder.newInstance(IAtom.class, "C");
-        a4.setFlag(CDKConstants.ISAROMATIC, true);
+        a4.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a4);
         IAtom a5 = builder.newInstance(IAtom.class, "C");
-        a5.setFlag(CDKConstants.ISAROMATIC, true);
+        a5.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a5);
         IAtom a6 = builder.newInstance(IAtom.class, "C");
-        a6.setFlag(CDKConstants.ISAROMATIC, true);
+        a6.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a6);
         IAtom a7 = builder.newInstance(IAtom.class, "C");
-        a7.setFlag(CDKConstants.ISAROMATIC, true);
+        a7.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a7);
         IAtom a8 = builder.newInstance(IAtom.class, "O");
         mol.addAtom(a8);
@@ -261,10 +261,10 @@ abstract class AbstractFixedLengthFingerprinterTest extends AbstractFingerprinte
         IAtom a17 = builder.newInstance(IAtom.class, "O");
         mol.addAtom(a17);
         IAtom a18 = builder.newInstance(IAtom.class, "C");
-        a18.setFlag(CDKConstants.ISAROMATIC, true);
+        a18.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a18);
         IAtom a19 = builder.newInstance(IAtom.class, "C");
-        a19.setFlag(CDKConstants.ISAROMATIC, true);
+        a19.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a19);
         IBond b1 = builder.newInstance(IBond.class, a2, a1, IBond.Order.SINGLE);
         mol.addBond(b1);
@@ -273,13 +273,13 @@ abstract class AbstractFixedLengthFingerprinterTest extends AbstractFingerprinte
         IBond b3 = builder.newInstance(IBond.class, a4, a2, IBond.Order.SINGLE);
         mol.addBond(b3);
         IBond b4 = builder.newInstance(IBond.class, a5, a4, IBond.Order.DOUBLE);
-        b4.setFlag(CDKConstants.ISAROMATIC, true);
+        b4.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b4);
         IBond b5 = builder.newInstance(IBond.class, a6, a5, IBond.Order.SINGLE);
-        b5.setFlag(CDKConstants.ISAROMATIC, true);
+        b5.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b5);
         IBond b6 = builder.newInstance(IBond.class, a7, a6, IBond.Order.DOUBLE);
-        b6.setFlag(CDKConstants.ISAROMATIC, true);
+        b6.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b6);
         IBond b7 = builder.newInstance(IBond.class, a8, a7, IBond.Order.SINGLE);
         mol.addBond(b7);
@@ -304,13 +304,13 @@ abstract class AbstractFixedLengthFingerprinterTest extends AbstractFingerprinte
         IBond b17 = builder.newInstance(IBond.class, a17, a16, IBond.Order.SINGLE);
         mol.addBond(b17);
         IBond b18 = builder.newInstance(IBond.class, a18, a7, IBond.Order.SINGLE);
-        b18.setFlag(CDKConstants.ISAROMATIC, true);
+        b18.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b18);
         IBond b19 = builder.newInstance(IBond.class, a19, a18, IBond.Order.DOUBLE);
-        b19.setFlag(CDKConstants.ISAROMATIC, true);
+        b19.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b19);
         IBond b20 = builder.newInstance(IBond.class, a19, a4, IBond.Order.SINGLE);
-        b20.setFlag(CDKConstants.ISAROMATIC, true);
+        b20.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b20);
         return mol;
     }
@@ -330,22 +330,22 @@ abstract class AbstractFixedLengthFingerprinterTest extends AbstractFingerprinte
         IAtom a3 = builder.newInstance(IAtom.class, "O");
         mol.addAtom(a3);
         IAtom a4 = builder.newInstance(IAtom.class, "C");
-        a4.setFlag(CDKConstants.ISAROMATIC, true);
+        a4.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a4);
         IAtom a5 = builder.newInstance(IAtom.class, "C");
-        a5.setFlag(CDKConstants.ISAROMATIC, true);
+        a5.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a5);
         IAtom a6 = builder.newInstance(IAtom.class, "C");
-        a6.setFlag(CDKConstants.ISAROMATIC, true);
+        a6.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a6);
         IAtom a7 = builder.newInstance(IAtom.class, "C");
-        a7.setFlag(CDKConstants.ISAROMATIC, true);
+        a7.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a7);
         IAtom a8 = builder.newInstance(IAtom.class, "C");
-        a8.setFlag(CDKConstants.ISAROMATIC, true);
+        a8.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a8);
         IAtom a9 = builder.newInstance(IAtom.class, "C");
-        a9.setFlag(CDKConstants.ISAROMATIC, true);
+        a9.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a9);
         IAtom a10 = builder.newInstance(IAtom.class, "C");
         mol.addAtom(a10);
@@ -356,22 +356,22 @@ abstract class AbstractFixedLengthFingerprinterTest extends AbstractFingerprinte
         IBond b3 = builder.newInstance(IBond.class, a4, a3, IBond.Order.SINGLE);
         mol.addBond(b3);
         IBond b4 = builder.newInstance(IBond.class, a5, a4, IBond.Order.DOUBLE);
-        b4.setFlag(CDKConstants.ISAROMATIC, true);
+        b4.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b4);
         IBond b5 = builder.newInstance(IBond.class, a6, a5, IBond.Order.SINGLE);
-        b5.setFlag(CDKConstants.ISAROMATIC, true);
+        b5.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b5);
         IBond b6 = builder.newInstance(IBond.class, a7, a6, IBond.Order.DOUBLE);
-        b6.setFlag(CDKConstants.ISAROMATIC, true);
+        b6.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b6);
         IBond b7 = builder.newInstance(IBond.class, a8, a7, IBond.Order.SINGLE);
-        b7.setFlag(CDKConstants.ISAROMATIC, true);
+        b7.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b7);
         IBond b8 = builder.newInstance(IBond.class, a9, a8, IBond.Order.DOUBLE);
-        b8.setFlag(CDKConstants.ISAROMATIC, true);
+        b8.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b8);
         IBond b9 = builder.newInstance(IBond.class, a9, a4, IBond.Order.SINGLE);
-        b9.setFlag(CDKConstants.ISAROMATIC, true);
+        b9.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b9);
         IBond b10 = builder.newInstance(IBond.class, a10, a9, IBond.Order.SINGLE);
         mol.addBond(b10);
@@ -397,19 +397,19 @@ abstract class AbstractFixedLengthFingerprinterTest extends AbstractFingerprinte
         IAtom a3 = builder.newInstance(IAtom.class, "O");
         mol.addAtom(a3);
         IAtom a4 = builder.newInstance(IAtom.class, "C");
-        a4.setFlag(CDKConstants.ISAROMATIC, true);
+        a4.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a4);
         IAtom a5 = builder.newInstance(IAtom.class, "C");
-        a5.setFlag(CDKConstants.ISAROMATIC, true);
+        a5.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a5);
         IAtom a6 = builder.newInstance(IAtom.class, "C");
-        a6.setFlag(CDKConstants.ISAROMATIC, true);
+        a6.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a6);
         IAtom a7 = builder.newInstance(IAtom.class, "C");
-        a7.setFlag(CDKConstants.ISAROMATIC, true);
+        a7.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a7);
         IAtom a8 = builder.newInstance(IAtom.class, "S");
-        a8.setFlag(CDKConstants.ISAROMATIC, true);
+        a8.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a8);
         IBond b1 = builder.newInstance(IBond.class, a2, a1, IBond.Order.SINGLE);
         mol.addBond(b1);
@@ -418,19 +418,19 @@ abstract class AbstractFixedLengthFingerprinterTest extends AbstractFingerprinte
         IBond b3 = builder.newInstance(IBond.class, a4, a2, IBond.Order.SINGLE);
         mol.addBond(b3);
         IBond b4 = builder.newInstance(IBond.class, a5, a4, IBond.Order.DOUBLE);
-        b4.setFlag(CDKConstants.ISAROMATIC, true);
+        b4.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b4);
         IBond b5 = builder.newInstance(IBond.class, a6, a5, IBond.Order.SINGLE);
-        b5.setFlag(CDKConstants.ISAROMATIC, true);
+        b5.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b5);
         IBond b6 = builder.newInstance(IBond.class, a7, a6, IBond.Order.DOUBLE);
-        b6.setFlag(CDKConstants.ISAROMATIC, true);
+        b6.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b6);
         IBond b7 = builder.newInstance(IBond.class, a8, a7, IBond.Order.SINGLE);
-        b7.setFlag(CDKConstants.ISAROMATIC, true);
+        b7.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b7);
         IBond b8 = builder.newInstance(IBond.class, a8, a4, IBond.Order.SINGLE);
-        b8.setFlag(CDKConstants.ISAROMATIC, true);
+        b8.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b8);
         return mol;
     }
@@ -454,38 +454,38 @@ abstract class AbstractFixedLengthFingerprinterTest extends AbstractFingerprinte
         IAtom a5 = builder.newInstance(IAtom.class, "S");
         mol.addAtom(a5);
         IAtom a6 = builder.newInstance(IAtom.class, "C");
-        a6.setFlag(CDKConstants.ISAROMATIC, true);
+        a6.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a6);
         IAtom a7 = builder.newInstance(IAtom.class, "C");
-        a7.setFlag(CDKConstants.ISAROMATIC, true);
+        a7.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a7);
         IAtom a8 = builder.newInstance(IAtom.class, "C");
-        a8.setFlag(CDKConstants.ISAROMATIC, true);
+        a8.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a8);
         IAtom a9 = builder.newInstance(IAtom.class, "C");
-        a9.setFlag(CDKConstants.ISAROMATIC, true);
+        a9.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a9);
         IAtom a10 = builder.newInstance(IAtom.class, "S");
-        a10.setFlag(CDKConstants.ISAROMATIC, true);
+        a10.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a10);
         IAtom a11 = builder.newInstance(IAtom.class, "C");
         mol.addAtom(a11);
         IAtom a12 = builder.newInstance(IAtom.class, "C");
         mol.addAtom(a12);
         IAtom a13 = builder.newInstance(IAtom.class, "C");
-        a13.setFlag(CDKConstants.ISAROMATIC, true);
+        a13.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a13);
         IAtom a14 = builder.newInstance(IAtom.class, "C");
-        a14.setFlag(CDKConstants.ISAROMATIC, true);
+        a14.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a14);
         IAtom a15 = builder.newInstance(IAtom.class, "C");
-        a15.setFlag(CDKConstants.ISAROMATIC, true);
+        a15.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a15);
         IAtom a16 = builder.newInstance(IAtom.class, "C");
-        a16.setFlag(CDKConstants.ISAROMATIC, true);
+        a16.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a16);
         IAtom a17 = builder.newInstance(IAtom.class, "S");
-        a17.setFlag(CDKConstants.ISAROMATIC, true);
+        a17.setFlag(IChemObject.AROMATIC, true);
         mol.addAtom(a17);
         IAtom a18 = builder.newInstance(IAtom.class, "N");
         a18.setFormalCharge(1);
@@ -506,19 +506,19 @@ abstract class AbstractFixedLengthFingerprinterTest extends AbstractFingerprinte
         IBond b5 = builder.newInstance(IBond.class, a6, a5, IBond.Order.SINGLE);
         mol.addBond(b5);
         IBond b6 = builder.newInstance(IBond.class, a7, a6, IBond.Order.DOUBLE);
-        b6.setFlag(CDKConstants.ISAROMATIC, true);
+        b6.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b6);
         IBond b7 = builder.newInstance(IBond.class, a8, a7, IBond.Order.SINGLE);
-        b7.setFlag(CDKConstants.ISAROMATIC, true);
+        b7.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b7);
         IBond b8 = builder.newInstance(IBond.class, a9, a8, IBond.Order.DOUBLE);
-        b8.setFlag(CDKConstants.ISAROMATIC, true);
+        b8.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b8);
         IBond b9 = builder.newInstance(IBond.class, a10, a9, IBond.Order.SINGLE);
-        b9.setFlag(CDKConstants.ISAROMATIC, true);
+        b9.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b9);
         IBond b10 = builder.newInstance(IBond.class, a10, a6, IBond.Order.SINGLE);
-        b10.setFlag(CDKConstants.ISAROMATIC, true);
+        b10.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b10);
         IBond b11 = builder.newInstance(IBond.class, a11, a9, IBond.Order.SINGLE);
         mol.addBond(b11);
@@ -527,19 +527,19 @@ abstract class AbstractFixedLengthFingerprinterTest extends AbstractFingerprinte
         IBond b13 = builder.newInstance(IBond.class, a13, a12, IBond.Order.SINGLE);
         mol.addBond(b13);
         IBond b14 = builder.newInstance(IBond.class, a14, a13, IBond.Order.DOUBLE);
-        b14.setFlag(CDKConstants.ISAROMATIC, true);
+        b14.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b14);
         IBond b15 = builder.newInstance(IBond.class, a15, a14, IBond.Order.SINGLE);
-        b15.setFlag(CDKConstants.ISAROMATIC, true);
+        b15.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b15);
         IBond b16 = builder.newInstance(IBond.class, a16, a15, IBond.Order.DOUBLE);
-        b16.setFlag(CDKConstants.ISAROMATIC, true);
+        b16.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b16);
         IBond b17 = builder.newInstance(IBond.class, a17, a16, IBond.Order.SINGLE);
-        b17.setFlag(CDKConstants.ISAROMATIC, true);
+        b17.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b17);
         IBond b18 = builder.newInstance(IBond.class, a17, a13, IBond.Order.SINGLE);
-        b18.setFlag(CDKConstants.ISAROMATIC, true);
+        b18.setFlag(IChemObject.AROMATIC, true);
         mol.addBond(b18);
         IBond b19 = builder.newInstance(IBond.class, a18, a16, IBond.Order.SINGLE);
         mol.addBond(b19);
