@@ -33,14 +33,15 @@ import javax.vecmath.Point2d;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
-import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.Bond;
-import org.openscience.cdk.CDKConstants;
+import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.graph.Cycles;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
+import org.openscience.cdk.interfaces.IChemObject;
+import org.openscience.cdk.interfaces.IChemObjectBuilder;
 import org.openscience.cdk.interfaces.IRingSet;
 import org.openscience.cdk.io.MDLV2000Reader;
 import org.openscience.cdk.ringsearch.RingPartitioner;
@@ -48,6 +49,7 @@ import org.openscience.cdk.silent.SilentChemObjectBuilder;
 import org.openscience.cdk.smiles.SmilesParser;
 import org.openscience.cdk.templates.TestMoleculeFactory;
 import org.openscience.cdk.tools.diff.AtomContainerDiff;
+import org.openscience.cdk.tools.manipulator.AtomContainerManipulator;
 
 /**
  * @cdk.module test-fingerprint
@@ -134,7 +136,7 @@ class ExtendedFingerprinterTest extends AbstractFixedLengthFingerprinterTest {
     @Test
     void testDifferentRingFinders() throws Exception {
         IFingerprinter fingerprinter = new ExtendedFingerprinter();
-        IAtomContainer ac1 = new AtomContainer();
+        IAtomContainer ac1 = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         Atom atom1 = new Atom("C");
         Atom atom2 = new Atom("C");
         Atom atom3 = new Atom("C");
@@ -159,7 +161,7 @@ class ExtendedFingerprinterTest extends AbstractFixedLengthFingerprinterTest {
         ac1.addBond(bond4);
         ac1.addBond(bond5);
         ac1.addBond(bond6);
-        IAtomContainer ac2 = new AtomContainer();
+        IAtomContainer ac2 = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         ac2.addAtom(atom1);
         ac2.addAtom(atom2);
         ac2.addAtom(atom3);
@@ -187,7 +189,7 @@ class ExtendedFingerprinterTest extends AbstractFixedLengthFingerprinterTest {
      */
     @Test
     void testCondensedSingle() throws Exception {
-        IAtomContainer molcondensed = new AtomContainer();
+        IAtomContainer molcondensed = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         IAtom a1 = molcondensed.getBuilder().newInstance(IAtom.class, "C");
         a1.setPoint2d(new Point2d(421.99999999999994, 860.0));
         molcondensed.addAtom(a1);
@@ -273,7 +275,7 @@ class ExtendedFingerprinterTest extends AbstractFixedLengthFingerprinterTest {
         IBond b18 = molcondensed.getBuilder().newInstance(IBond.class, a13, a16, IBond.Order.SINGLE);
         molcondensed.addBond(b18);
 
-        IAtomContainer molsingle = new AtomContainer();
+        IAtomContainer molsingle = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         IAtom a1s = molsingle.getBuilder().newInstance(IAtom.class, "C");
         a1s.setPoint2d(new Point2d(421.99999999999994, 860.0));
         molsingle.addAtom(a1s);
@@ -399,12 +401,12 @@ class ExtendedFingerprinterTest extends AbstractFixedLengthFingerprinterTest {
         String filename = "chebisearch.mol";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         MDLV2000Reader reader = new MDLV2000Reader(ins);
-        searchmol = reader.read(new AtomContainer());
+        searchmol = reader.read(DefaultChemObjectBuilder.getInstance().newAtomContainer());
         reader.close();
         filename = "chebifind.mol";
         ins = this.getClass().getResourceAsStream(filename);
         reader = new MDLV2000Reader(ins);
-        findmol = reader.read(new AtomContainer());
+        findmol = reader.read(DefaultChemObjectBuilder.getInstance().newAtomContainer());
         reader.close();
         IFingerprinter fingerprinter = new ExtendedFingerprinter();
         BitSet superBS = fingerprinter.getBitFingerprint(findmol).asBitSet();
@@ -427,7 +429,7 @@ class ExtendedFingerprinterTest extends AbstractFixedLengthFingerprinterTest {
 
         // should pass since we have not explicitly detected aromaticity
         for (IAtom atom : mol.atoms()) {
-            Assertions.assertFalse(atom.getFlag(CDKConstants.ISAROMATIC));
+            Assertions.assertFalse(atom.getFlag(IChemObject.AROMATIC));
         }
 
         String diff1 = AtomContainerDiff.diff(mol, clone);
@@ -527,4 +529,23 @@ class ExtendedFingerprinterTest extends AbstractFixedLengthFingerprinterTest {
         ICountFingerprint actual = fpr.getCountFingerprint(mol);
         Assertions.assertEquals(65, actual.numOfPopulatedbins());
     }
+
+    @Test
+    void testHydrogenRepresentations() throws CDKException, CloneNotSupportedException {
+        String smiles = "C=1C=C(C(=C(C1)Cl)Cl)N2CCN(CC2)CCCCOC=3C=CC4=C(C3)NC(=O)CC4";
+        IChemObjectBuilder bldr = SilentChemObjectBuilder.getInstance();
+        IAtomContainer abilify = new SmilesParser(bldr).parseSmiles(smiles);
+        IAtomContainer abilifyExplH = abilify.clone();
+        AtomContainerManipulator.convertImplicitToExplicitHydrogens(abilifyExplH);
+        Assertions.assertNotEquals(abilify.getAtomCount(), abilifyExplH.getAtomCount());
+        Assertions.assertNotEquals(abilify.getBondCount(), abilifyExplH.getBondCount());
+
+        ExtendedFingerprinter fp = new ExtendedFingerprinter();
+        Assertions.assertEquals(fp.getBitFingerprint(abilify),
+                                fp.getBitFingerprint(abilifyExplH));
+
+        Assertions.assertNotEquals(abilify.getAtomCount(), abilifyExplH.getAtomCount());
+        Assertions.assertNotEquals(abilify.getBondCount(), abilifyExplH.getBondCount());
+    }
+
 }
