@@ -18,13 +18,12 @@
  */
 package org.openscience.cdk.qsar.descriptors.atomic;
 
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.aromaticity.Aromaticity;
-import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
@@ -40,16 +39,16 @@ import org.openscience.cdk.tools.manipulator.AtomContainerManipulator;
  *
  * @cdk.module test-qsaratomic
  */
-public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
+class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
 
     private final static IChemObjectBuilder builder = SilentChemObjectBuilder.getInstance();
-    LonePairElectronChecker                 lpcheck = new LonePairElectronChecker();
+    private final LonePairElectronChecker                 lpcheck = new LonePairElectronChecker();
 
     /**
      *  Constructor for the PartialSigmaChargeDescriptorTest object
      *
      */
-    public PartialSigmaChargeDescriptorTest() {}
+    PartialSigmaChargeDescriptorTest() {}
 
     /**
      *  A unit test suite for JUnit
@@ -57,8 +56,8 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
      *@return    The test suite
      */
 
-    @Before
-    public void setUp() throws Exception {
+    @BeforeEach
+    void setUp() throws Exception {
         setDescriptor(PartialSigmaChargeDescriptor.class);
         Integer[] params = {6};
         descriptor.setParameters(params);
@@ -70,7 +69,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
      *  @cdk.inchi InChI=1/C2H3F/c1-2-3/h2H,1H2
      */
     @Test
-    public void testPartialSigmaChargeDescriptor_Fluoroethylene() throws ClassNotFoundException, CDKException,
+    void testPartialSigmaChargeDescriptor_Fluoroethylene() throws
             java.lang.Exception {
         double[] testResult = {-0.2138, 0.079, 0.0942, -0.072, 0.0563, 0.0563};/*
                                                                                 * from
@@ -120,7 +119,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
         for (int i = 0; i < molecule.getAtomCount(); i++) {
             double result = ((DoubleResult) descriptor.calculate(molecule.getAtom(i), molecule).getValue())
                     .doubleValue();
-            Assert.assertEquals(testResult[i], result, 0.003);
+            Assertions.assertEquals(testResult[i], result, 0.003);
         }
     }
 
@@ -130,7 +129,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
      *  @cdk.inchi InChI=1/CH3F/c1-2/h1H3
      */
     @Test
-    public void testPartialSigmaChargeDescriptor_Methyl_Floride() throws ClassNotFoundException, CDKException,
+    void testPartialSigmaChargeDescriptor_Methyl_Floride() throws
             java.lang.Exception {
         double[] testResult = {0.07915, -0.25264, 0.05783, 0.05783, 0.05783};/*
                                                                               * from
@@ -173,7 +172,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
         for (int i = 0; i < molecule.getAtomCount(); i++) {
             double result = ((DoubleResult) descriptor.calculate(molecule.getAtom(i), molecule).getValue())
                     .doubleValue();
-            Assert.assertEquals(testResult[i], result, 0.001);
+            Assertions.assertEquals(testResult[i], result, 0.001);
         }
     }
 
@@ -183,7 +182,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
      *  @cdk.inchi  InChI=1/CH3Cl/c1-2/h1H3
      */
     @Test
-    public void testPartialSigmaChargeDescriptor_Methyl_chloride() throws ClassNotFoundException, CDKException,
+    void testPartialSigmaChargeDescriptor_Methyl_chloride() throws
             java.lang.Exception {
         double[] testResult = {0.0382, -0.1755, 0.0457, 0.0457, 0.0457};/*
                                                                          * from
@@ -219,7 +218,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
         for (int i = 0; i < molecule.getAtomCount(); i++) {
             double result = ((DoubleResult) descriptor.calculate(molecule.getAtom(i), molecule).getValue())
                     .doubleValue();
-            Assert.assertEquals(testResult[i], result, 0.001);
+            Assertions.assertEquals(testResult[i], result, 0.001);
         }
     }
 
@@ -229,7 +228,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
      *  @cdk.inchi  InChI=1/CH3Br/c1-2/h1H3
      */
     @Test
-    public void testPartialSigmaChargeDescriptor_Methyl_bromide() throws ClassNotFoundException, CDKException,
+    void testPartialSigmaChargeDescriptor_Methyl_bromide() throws
             java.lang.Exception {
         double[] testResult = {0.021, -0.1448, 0.0413, 0.0413, 0.0413};/*
                                                                         * from
@@ -262,7 +261,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
         for (int i = 0; i < molecule.getAtomCount(); i++) {
             double result = ((DoubleResult) descriptor.calculate(molecule.getAtom(i), molecule).getValue())
                     .doubleValue();
-            Assert.assertEquals(testResult[i], result, 0.01);
+            Assertions.assertEquals(testResult[i], result, 0.01);
         }
     }
 
@@ -272,7 +271,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
      *  @cdk.inchi
      */
     @Test
-    public void testPartialSigmaChargeDescriptor_Methyl_iodide() throws ClassNotFoundException, CDKException,
+    void testPartialSigmaChargeDescriptor_Methyl_iodide() throws
             java.lang.Exception {
         double[] testResult = {-0.0116, -0.0892, 0.0336, 0.0336, 0.0336};/*
                                                                           * from
@@ -309,7 +308,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
         for (int i = 0; i < molecule.getAtomCount(); i++) {
             double result = ((DoubleResult) descriptor.calculate(molecule.getAtom(i), molecule).getValue())
                     .doubleValue();
-            Assert.assertEquals(testResult[i], result, 0.001);
+            Assertions.assertEquals(testResult[i], result, 0.001);
         }
     }
 
@@ -319,7 +318,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
      *  @cdk.inchi  InChI=1/C3H5Br/c1-2-3-4/h2H,1,3H2
      */
     @Test
-    public void testPartialSigmaChargeDescriptor_Allyl_bromide() throws ClassNotFoundException, CDKException,
+    void testPartialSigmaChargeDescriptor_Allyl_bromide() throws
             java.lang.Exception {
         double testResult = -0.1366;/*
                                      * from Petra online:
@@ -341,7 +340,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
         lpcheck.saturate(molecule);
 
         double result = ((DoubleResult) descriptor.calculate(molecule.getAtom(3), molecule).getValue()).doubleValue();
-        Assert.assertEquals(testResult, result, 0.01);
+        Assertions.assertEquals(testResult, result, 0.01);
     }
 
     /**
@@ -350,7 +349,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
      *  @cdk.inchi  InChI=1/C5H11I/c1-5(2)3-4-6/h5H,3-4H2,1-2H3
      */
     @Test
-    public void testPartialSigmaChargeDescriptor_Isopentyl_iodide() throws ClassNotFoundException, CDKException,
+    void testPartialSigmaChargeDescriptor_Isopentyl_iodide() throws
             java.lang.Exception {
         double[] testResult = {-0.0458, -0.0623, -0.0623, -0.0415, 0.0003, -0.0855}; /*
                                                                                       * from
@@ -387,7 +386,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
 
         for (int i = 0; i < 6; i++) {
             double result = ((DoubleResult) descriptor.calculate(mol.getAtom(i), mol).getValue()).doubleValue();
-            Assert.assertEquals(testResult[i], result, 0.001);
+            Assertions.assertEquals(testResult[i], result, 0.001);
         }
     }
 
@@ -397,7 +396,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
      *  @cdk.inchi  InChI=1/C4H10O/c1-3-5-4-2/h3-4H2,1-2H3
      */
     @Test
-    public void testPartialSigmaChargeDescriptor_Ethoxy_ethane() throws ClassNotFoundException, CDKException,
+    void testPartialSigmaChargeDescriptor_Ethoxy_ethane() throws
             java.lang.Exception {
         double testResult = -0.3809; /*
                                       * from Petra online:
@@ -421,7 +420,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
         lpcheck.saturate(molecule);
 
         double result = ((DoubleResult) descriptor.calculate(molecule.getAtom(2), molecule).getValue()).doubleValue();
-        Assert.assertEquals(testResult, result, 0.01);
+        Assertions.assertEquals(testResult, result, 0.01);
     }
 
     /**
@@ -430,7 +429,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
      *  @cdk.inchi  InChI=1/C2H7NO/c3-1-2-4/h4H,1-3H2
      */
     @Test
-    public void testPartialSigmaChargeDescriptor_Ethanolamine() throws ClassNotFoundException, CDKException,
+    void testPartialSigmaChargeDescriptor_Ethanolamine() throws
             java.lang.Exception {
         double[] testResult = {-0.3293, 0.017, 0.057, -0.3943}; /*
                                                                  * from Petra
@@ -460,7 +459,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
         for (int i = 0; i < 4; i++) {
             double result = ((DoubleResult) descriptor.calculate(molecule.getAtom(i), molecule).getValue())
                     .doubleValue();
-            Assert.assertEquals(testResult[i], result, 0.01);
+            Assertions.assertEquals(testResult[i], result, 0.01);
         }
     }
 
@@ -470,7 +469,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
      *  @cdk.inchi  InChI=1/C3H6S/c1-2-3-4/h2,4H,1,3H2
      */
     @Test
-    public void testPartialSigmaChargeDescriptor_Allyl_mercaptan() throws ClassNotFoundException, CDKException,
+    void testPartialSigmaChargeDescriptor_Allyl_mercaptan() throws
             java.lang.Exception {
         double[] testResult = {-0.1031, -0.0828, 0.0093, -0.1742}; /*
                                                                     * from Petra
@@ -503,7 +502,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
         for (int i = 0; i < 4; i++) {
             double result = ((DoubleResult) descriptor.calculate(molecule.getAtom(i), molecule).getValue())
                     .doubleValue();
-            Assert.assertEquals(testResult[i], result, 0.01);
+            Assertions.assertEquals(testResult[i], result, 0.01);
         }
     }
 
@@ -511,7 +510,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
      *  A unit test for JUnit with
      */
     @Test
-    public void testPartialSigmaChargeDescriptor1() throws ClassNotFoundException, CDKException, java.lang.Exception {
+    void testPartialSigmaChargeDescriptor1() throws java.lang.Exception {
         double[] testResult = {-0.2138, 0.079, 0.0942, -0.072, 0.0563, 0.0563}; /*
                                                                                  * from
                                                                                  * Petra
@@ -544,7 +543,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
 
         for (int i = 0; i < mol.getAtomCount(); i++) {
             double result = ((DoubleResult) descriptor.calculate(mol.getAtom(i), mol).getValue()).doubleValue();
-            Assert.assertEquals(testResult[i], result, 0.003);
+            Assertions.assertEquals(testResult[i], result, 0.003);
         }
     }
 
@@ -552,7 +551,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
      *  A unit test for JUnit with
      */
     @Test
-    public void testPartialSigmaChargeDescriptor2() throws ClassNotFoundException, CDKException, java.lang.Exception {
+    void testPartialSigmaChargeDescriptor2() throws java.lang.Exception {
         double[] testResult = {-0.3855, -0.0454, 0.0634, -0.0544, -0.0391, -0.0391}; /*
                                                                                       * from
                                                                                       * Petra
@@ -586,7 +585,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
         descriptor.setParameters(object);
         for (int i = 0; i < mol.getAtomCount(); i++) {
             double result = ((DoubleResult) descriptor.calculate(mol.getAtom(i), mol).getValue()).doubleValue();
-            Assert.assertEquals(testResult[i], result, 0.2);
+            Assertions.assertEquals(testResult[i], result, 0.2);
         }
     }
 
@@ -594,7 +593,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
      *  A unit test for JUnit with
      */
     @Test
-    public void testPartialSigmaChargeDescriptor3() throws ClassNotFoundException, CDKException, java.lang.Exception {
+    void testPartialSigmaChargeDescriptor3() throws java.lang.Exception {
         double[] testResult = {-0.3855, -0.0454, 0.0634, -0.0544, -0.0391, -0.0391}; /*
                                                                                       * from
                                                                                       * Petra
@@ -627,7 +626,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
 
         for (int i = 0; i < mol.getAtomCount(); i++) {
             double result = ((DoubleResult) descriptor.calculate(mol.getAtom(i), mol).getValue()).doubleValue();
-            Assert.assertEquals(testResult[i], result, 0.2);
+            Assertions.assertEquals(testResult[i], result, 0.2);
         }
     }
 
@@ -637,7 +636,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
      *  @cdk.inchi  InChI=1/CH2O/c1-2/h1H2
      */
     @Test
-    public void testPartialSigmaChargeDescriptor4() throws ClassNotFoundException, CDKException, java.lang.Exception {
+    void testPartialSigmaChargeDescriptor4() throws java.lang.Exception {
         double[] testResult = {-0.3041, 0.1055, 0.0993, 0.0993}; /*
                                                                   * from Petra
                                                                   * online:
@@ -668,7 +667,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
         for (int i = 0; i < molecule.getAtomCount(); i++) {
             double result = ((DoubleResult) descriptor.calculate(molecule.getAtom(i), molecule).getValue())
                     .doubleValue();
-            Assert.assertEquals(testResult[i], result, 0.003);
+            Assertions.assertEquals(testResult[i], result, 0.003);
         }
     }
 
@@ -678,7 +677,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
      *  @cdk.inchi InChI=1/C2H4O/c1-2-3/h2H,1H3
      */
     @Test
-    public void testPartialSigmaChargeDescriptor5() throws ClassNotFoundException, CDKException, java.lang.Exception {
+    void testPartialSigmaChargeDescriptor5() throws java.lang.Exception {
         double[] testResult = {-0.3291, 0.144, 0.1028, -0.0084, 0.0303, 0.0303, 0.0303}; /*
                                                                                           * from
                                                                                           * Petra
@@ -730,7 +729,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
         for (int i = 0; i < molecule.getAtomCount(); i++) {
             double result = ((DoubleResult) descriptor.calculate(molecule.getAtom(i), molecule).getValue())
                     .doubleValue();
-            Assert.assertEquals(testResult[i], result, 0.03);
+            Assertions.assertEquals(testResult[i], result, 0.03);
         }
     }
 
@@ -738,7 +737,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
      *  A unit test for JUnit with
      */
     @Test
-    public void testPartialSigmaChargeDescriptor6() throws ClassNotFoundException, CDKException, java.lang.Exception {
+    void testPartialSigmaChargeDescriptor6() throws java.lang.Exception {
         double[] testResult = {-0.4331, -0.1067, 0.0133, 0.0133, 0.0133}; /*
                                                                            * from
                                                                            * Petra
@@ -770,7 +769,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
         for (int i = 0; i < mol.getAtomCount(); i++) {
             double result = ((DoubleResult) descriptor.calculate(mol.getAtom(i), mol).getValue()).doubleValue();
             //			logger.debug(mol.getAtom(i).getSymbol()+",result: "+result);
-            Assert.assertEquals(testResult[i], result, 0.3);
+            Assertions.assertEquals(testResult[i], result, 0.3);
         }
     }
 
@@ -778,7 +777,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
      *  A unit test for JUnit with [H]c1[n-][c+]([H])c([H])c([H])c1([H])
      */
     @Test
-    public void testPartialSigmaChargeDescriptor7() throws ClassNotFoundException, CDKException, java.lang.Exception {
+    void testPartialSigmaChargeDescriptor7() throws java.lang.Exception {
         /*
          * from Petra online: http://www2.chemi.uni.erlange.de/services/petra/smiles.pthml
          */
@@ -792,7 +791,7 @@ public class PartialSigmaChargeDescriptorTest extends AtomicDescriptorTest {
         for (int i = 0; i < mol.getAtomCount(); i++) {
             double result = ((DoubleResult) descriptor.calculate(mol.getAtom(i), mol).getValue()).doubleValue();
             //			logger.debug(mol.getAtom(i).getSymbol()+",result: "+result);
-            Assert.assertEquals(testResult[i], result, 0.05);
+            Assertions.assertEquals(testResult[i], result, 0.05);
         }
     }
 }
