@@ -18,11 +18,10 @@
  */
 package org.openscience.cdk.qsar.descriptors.atomic;
 
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
-import org.junit.experimental.categories.Category;
-import org.openscience.cdk.test.SlowTest;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Tag;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
@@ -38,17 +37,17 @@ import org.openscience.cdk.tools.manipulator.AtomContainerManipulator;
  *
  * @cdk.module test-qsaratomic
  */
-public class StabilizationPlusChargeDescriptorTest extends AtomicDescriptorTest {
+class StabilizationPlusChargeDescriptorTest extends AtomicDescriptorTest {
 
     private final static IChemObjectBuilder builder = SilentChemObjectBuilder.getInstance();
-    LonePairElectronChecker                 lpcheck = new LonePairElectronChecker();
+    private final LonePairElectronChecker                 lpcheck = new LonePairElectronChecker();
 
-    public StabilizationPlusChargeDescriptorTest() {
+    StabilizationPlusChargeDescriptorTest() {
         descriptor = new StabilizationPlusChargeDescriptor();
     }
 
-    @Before
-    public void setUp() throws Exception {
+    @BeforeEach
+    void setUp() throws Exception {
         setDescriptor(StabilizationPlusChargeDescriptor.class);
     }
 
@@ -58,8 +57,8 @@ public class StabilizationPlusChargeDescriptorTest extends AtomicDescriptorTest
      * @throws Exception
      */
     @Test
-    @Category(SlowTest.class)
-    public void testStabilizationPlusChargeDescriptor() throws Exception {
+    @Tag("SlowTest")
+    void testStabilizationPlusChargeDescriptor() throws Exception {
 
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         mol.addAtom(builder.newInstance(IAtom.class, "C"));
@@ -76,15 +75,15 @@ public class StabilizationPlusChargeDescriptorTest extends AtomicDescriptorTest
 
         DoubleResult result = ((DoubleResult) descriptor.calculate(mol.getAtom(1), mol).getValue());
 
-        Assert.assertNotSame(0.0, result.doubleValue());
+        Assertions.assertNotSame(0.0, result.doubleValue());
     }
 
     /**
      *
      */
     @Test
-    @Category(SlowTest.class)
-    public void testNotCharged() throws Exception {
+    @Tag("SlowTest")
+    void testNotCharged() throws Exception {
 
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         mol.addAtom(builder.newInstance(IAtom.class, "C"));
@@ -100,7 +99,7 @@ public class StabilizationPlusChargeDescriptorTest extends AtomicDescriptorTest
 
         DoubleResult result = ((DoubleResult) descriptor.calculate(mol.getAtom(0), mol).getValue());
 
-        Assert.assertEquals(0.0, result.doubleValue(), 0.00001);
+        Assertions.assertEquals(0.0, result.doubleValue(), 0.00001);
 
     }
 
@@ -110,8 +109,8 @@ public class StabilizationPlusChargeDescriptorTest extends AtomicDescriptorTest
      * @throws Exception
      */
     @Test
-    @Category(SlowTest.class)
-    public void testStabilizationPlusChargeDescriptor2() throws Exception {
+    @Tag("SlowTest")
+    void testStabilizationPlusChargeDescriptor2() throws Exception {
 
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         mol.addAtom(builder.newInstance(IAtom.class, "C"));
@@ -128,7 +127,7 @@ public class StabilizationPlusChargeDescriptorTest extends AtomicDescriptorTest
 
         DoubleResult result = ((DoubleResult) descriptor.calculate(mol.getAtom(1), mol).getValue());
 
-        Assert.assertNotSame(0.0, result.doubleValue());
+        Assertions.assertNotSame(0.0, result.doubleValue());
 
     }
 
@@ -138,8 +137,8 @@ public class StabilizationPlusChargeDescriptorTest extends AtomicDescriptorTest
      * @throws Exception
      */
     @Test
-    @Category(SlowTest.class)
-    public void testStabilizationComparative() throws Exception {
+    @Tag("SlowTest")
+    void testStabilizationComparative() throws Exception {
 
         IAtomContainer mol1 = builder.newInstance(IAtomContainer.class);
         mol1.addAtom(builder.newInstance(IAtom.class, "C"));
@@ -182,8 +181,8 @@ public class StabilizationPlusChargeDescriptorTest extends AtomicDescriptorTest
 
         DoubleResult result3 = ((DoubleResult) descriptor.calculate(mol3.getAtom(1), mol3).getValue());
 
-        Assert.assertTrue(result3.doubleValue() < result2.doubleValue());
-        Assert.assertTrue(result2.doubleValue() < result1.doubleValue());
+        Assertions.assertTrue(result3.doubleValue() < result2.doubleValue());
+        Assertions.assertTrue(result2.doubleValue() < result1.doubleValue());
     }
 
     /**
@@ -192,8 +191,8 @@ public class StabilizationPlusChargeDescriptorTest extends AtomicDescriptorTest
      *  @cdk.inchi InChI=1/C3H7Cl/c1-2-3-4/h2-3H2,1H3
      */
     @Test
-    @Category(SlowTest.class)
-    public void testCompareIonized() throws Exception {
+    @Tag("SlowTest")
+    void testCompareIonized() throws Exception {
 
         IAtomContainer molA = builder.newInstance(IAtomContainer.class);
         molA.addAtom(builder.newInstance(IAtom.class, "C"));
@@ -227,13 +226,13 @@ public class StabilizationPlusChargeDescriptorTest extends AtomicDescriptorTest
         addExplicitHydrogens(molB);
         lpcheck.saturate(molB);
 
-        Assert.assertEquals(1, molB.getAtom(3).getFormalCharge(), 0.00001);
-        Assert.assertEquals(1, molB.getSingleElectronCount(), 0.00001);
-        Assert.assertEquals(2, molB.getLonePairCount(), 0.00001);
+        Assertions.assertEquals(1, molB.getAtom(3).getFormalCharge(), 0.00001);
+        Assertions.assertEquals(1, molB.getSingleElectronCount(), 0.00001);
+        Assertions.assertEquals(2, molB.getLonePairCount(), 0.00001);
 
         double resultB = ((DoubleResult) descriptor.calculate(molB.getAtom(3), molB).getValue()).doubleValue();
 
-        Assert.assertNotSame(resultA, resultB);
+        Assertions.assertNotSame(resultA, resultB);
     }
 
 }
