@@ -4,7 +4,7 @@ import java.io.InputStream;
 
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeEach;
-import org.openscience.cdk.AtomContainer;
+import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.io.MDLV2000Reader;
 import org.openscience.cdk.qsar.DescriptorValue;
@@ -28,7 +28,7 @@ class AutocorrelationDescriptorPolarizabilityTest extends MolecularDescriptorTes
         String filename = "data/mdl/chlorobenzene.mol";
         InputStream ins = this.getClass().getClassLoader().getResourceAsStream(filename);
         MDLV2000Reader reader = new MDLV2000Reader(ins);
-        IAtomContainer container = reader.read(new AtomContainer());
+        IAtomContainer container = reader.read(DefaultChemObjectBuilder.getInstance().newAtomContainer());
         DescriptorValue count = descriptor.calculate(container);
         System.out.println(count.getValue());
 
