@@ -35,6 +35,7 @@ import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IAtomContainerSet;
 import org.openscience.cdk.interfaces.IBond;
+import org.openscience.cdk.interfaces.IElement;
 import org.openscience.cdk.interfaces.IRing;
 import org.openscience.cdk.interfaces.IRingSet;
 import org.openscience.cdk.renderer.RendererModel;
@@ -75,7 +76,7 @@ public class BasicBondGenerator implements IGenerator<IAtomContainer> {
         }
     }
 
-    private IGeneratorParameter<Double> bondWidth = new BondWidth();
+    private final IGeneratorParameter<Double> bondWidth = new BondWidth();
 
     /**
      * The gap between double and triple bond lines on the screen.
@@ -90,7 +91,7 @@ public class BasicBondGenerator implements IGenerator<IAtomContainer> {
         }
     }
 
-    private IGeneratorParameter<Double> bondDistance = new BondDistance();
+    private final IGeneratorParameter<Double> bondDistance = new BondDistance();
 
     /**
      * The color to draw bonds if not other color is given.
@@ -105,7 +106,7 @@ public class BasicBondGenerator implements IGenerator<IAtomContainer> {
         }
     }
 
-    private IGeneratorParameter<Color> defaultBondColor = new DefaultBondColor();
+    private final IGeneratorParameter<Color> defaultBondColor = new DefaultBondColor();
 
     /**
      * The width on screen of the fat end of a wedge bond.
@@ -120,7 +121,7 @@ public class BasicBondGenerator implements IGenerator<IAtomContainer> {
         }
     }
 
-    private IGeneratorParameter<Double> wedgeWidth = new WedgeWidth();
+    private final IGeneratorParameter<Double> wedgeWidth = new WedgeWidth();
 
     /**
      * The proportion to move in towards the ring center.
@@ -135,9 +136,9 @@ public class BasicBondGenerator implements IGenerator<IAtomContainer> {
         }
     }
 
-    private IGeneratorParameter<Double> ringCenterProportion = new TowardsRingCenterProportion();
+    private final IGeneratorParameter<Double> ringCenterProportion = new TowardsRingCenterProportion();
 
-    private ILoggingTool                logger               = LoggingToolFactory
+    private final ILoggingTool                logger               = LoggingToolFactory
                                                                      .createLoggingTool(BasicBondGenerator.class);
 
     /**
@@ -159,12 +160,12 @@ public class BasicBondGenerator implements IGenerator<IAtomContainer> {
     /**
      * The ideal ring size for the given center proportion.
      */
-    private int                         IDEAL_RINGSIZE       = 6;
+    private final int                         IDEAL_RINGSIZE       = 6;
 
     /**
      * The minimum ring size factor to ensure a minimum gap.
      */
-    private double                      MIN_RINGSIZE_FACTOR  = 2.5;
+    private final double                      MIN_RINGSIZE_FACTOR  = 2.5;
 
     /**
      * An empty constructor necessary for reflection.
@@ -315,7 +316,7 @@ public class BasicBondGenerator implements IGenerator<IAtomContainer> {
         Point2d point2 = bond.getEnd().getPoint2d();
         Color color = this.getColorForBond(bond, model);
         double bondWidth = this.getWidthForBond(bond, model);
-        double bondDistance = (Double) model.get(BondDistance.class) / model.getParameter(Scale.class).getValue();
+        double bondDistance = model.get(BondDistance.class) / model.getParameter(Scale.class).getValue();
         if (type == IBond.Order.SINGLE) {
             return new LineElement(point1.x, point1.y, point2.x, point2.y, bondWidth, color);
         } else {
@@ -465,7 +466,7 @@ public class BasicBondGenerator implements IGenerator<IAtomContainer> {
      * @return true if the bond has stero information
      */
     private boolean isStereoBond(IBond bond) {
-        return bond.getStereo() != IBond.Stereo.NONE && bond.getStereo() != (IBond.Stereo) CDKConstants.UNSET
+        return bond.getStereo() != IBond.Stereo.NONE && bond.getStereo() != CDKConstants.UNSET
                 && bond.getStereo() != IBond.Stereo.E_Z_BY_COORDINATES;
     }
 
@@ -478,7 +479,7 @@ public class BasicBondGenerator implements IGenerator<IAtomContainer> {
     protected boolean bindsHydrogen(IBond bond) {
         for (int i = 0; i < bond.getAtomCount(); i++) {
             IAtom atom = bond.getAtom(i);
-            if ("H".equals(atom.getSymbol())) return true;
+            if (atom.getAtomicNumber() == IElement.H) return true;
         }
         return false;
     }
