@@ -24,12 +24,12 @@
 
 package org.openscience.cdk.isomorphism.matchers.smarts;
 
-import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.graph.Cycles;
 import org.openscience.cdk.graph.GraphUtil;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
+import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.ringsearch.RingSearch;
 
 import java.util.Arrays;
@@ -203,7 +203,7 @@ final class SMARTSAtomInvariants {
     /**
      * Computes {@link SMARTSAtomInvariants} and stores on the {@link #KEY} or
      * each {@link IAtom} in the {@code container}. The {@link
-     * CDKConstants#ISINRING} is also set for each bond. This configuration does
+     * org.openscience.cdk.interfaces.IChemObject#IN_RING} is also set for each bond. This configuration does
      * not include ring information and values are left as unset.
      * Ring membership is still configured but not ring size.
      *
@@ -226,7 +226,7 @@ final class SMARTSAtomInvariants {
     /**
      * Computes {@link SMARTSAtomInvariants} and stores on the {@link #KEY} or
      * each {@link IAtom} in the {@code container}. The {@link
-     * CDKConstants#ISINRING} is also set for each bond. This configuration
+     * org.openscience.cdk.interfaces.IChemObject#IN_RING} is also set for each bond. This configuration
      * includes the ring information as used by the Daylight implementation.
      * That is the Smallest Set of Smallest Rings (SSSR) is used and only the
      * smallest ring is stored for the {@link #ringSize()}.
@@ -276,13 +276,13 @@ final class SMARTSAtomInvariants {
                     int v = cycle[i];
                     if (size < ringSize[v]) ringSize[v] = size;
                     ringNumber[v]++;
-                    bondMap.get(cycle[i], cycle[i - 1]).setFlag(CDKConstants.ISINRING, true);
+                    bondMap.get(cycle[i], cycle[i - 1]).setFlag(IChemObject.IN_RING, true);
                 }
             }
         } else {
             // ring membership is super cheap
             for (IBond bond : new RingSearch(container, graph).ringFragments().bonds()) {
-                bond.setFlag(CDKConstants.ISINRING, true);
+                bond.setFlag(IChemObject.IN_RING, true);
             }
         }
 
@@ -309,7 +309,7 @@ final class SMARTSAtomInvariants {
 
                 degree++;
 
-                if (bond.getFlag(CDKConstants.ISINRING)) {
+                if (bond.getFlag(IChemObject.IN_RING)) {
                     ringConnections++;
                 }
 
