@@ -22,7 +22,6 @@
 package org.openscience.cdk.iupac.parser;
 
 import org.openscience.cdk.Atom;
-import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.aromaticity.Aromaticity;
 import org.openscience.cdk.atomtype.CDKAtomTypeMatcher;
@@ -449,7 +448,7 @@ public class MoleculeBuilder {
     }
 
     private static IAtomContainer makeBenzene() {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         mol.addAtom(new Atom("C")); // 0
         mol.addAtom(new Atom("C")); // 1
         mol.addAtom(new Atom("C")); // 2
@@ -477,7 +476,7 @@ public class MoleculeBuilder {
      * @cdk.created 2003-08-15
      */
     private static IAtomContainer makeAlkane(int chainLength) {
-        IAtomContainer currentChain = new AtomContainer();
+        IAtomContainer currentChain = DefaultChemObjectBuilder.getInstance().newAtomContainer();
 
         //Add the initial atom
         currentChain.addAtom(new Atom("C"));
