@@ -112,7 +112,7 @@ import java.util.stream.StreamSupport;
 @Deprecated
 public class SMARTSQueryTool {
 
-    private static ILoggingTool logger        = LoggingToolFactory.createLoggingTool(SMARTSQueryTool.class);
+    private static final ILoggingTool logger        = LoggingToolFactory.createLoggingTool(SMARTSQueryTool.class);
     private String              smarts;
     private IAtomContainer      atomContainer = null;
     private QueryAtomContainer  query         = null;
@@ -188,11 +188,11 @@ public class SMARTSQueryTool {
      * the molecules being tests are known to all have the same aromaticity
      * model.
      */
-    private boolean                  skipAromaticity = false;
+    private final boolean                  skipAromaticity = false;
 
     // a simplistic cache to store parsed SMARTS queries
     private int                      MAX_ENTRIES     = 20;
-    Map<String, QueryAtomContainer>  cache           = new LinkedHashMap<String, QueryAtomContainer>(MAX_ENTRIES + 1,
+    final Map<String, QueryAtomContainer>  cache           = new LinkedHashMap<String, QueryAtomContainer>(MAX_ENTRIES + 1,
                                                              .75F, true) {
 
                                                          @Override
@@ -214,9 +214,7 @@ public class SMARTSQueryTool {
         this.smarts = smarts;
         try {
             initializeQuery();
-        } catch (TokenMgrError error) {
-            throw new IllegalArgumentException("Error parsing SMARTS", error);
-        } catch (CDKException error) {
+        } catch (TokenMgrError | CDKException error) {
             throw new IllegalArgumentException("Error parsing SMARTS", error);
         }
     }
@@ -358,7 +356,7 @@ public class SMARTSQueryTool {
             // lets get the query atom
             IQueryAtom queryAtom = (IQueryAtom) query.getAtom(0);
 
-            mappings = new ArrayList<int[]>();
+            mappings = new ArrayList<>();
             for (int i = 0; i < atomContainer.getAtomCount(); i++) {
                 if (queryAtom.matches(atomContainer.getAtom(i))) {
                     mappings.add(new int[]{i});
@@ -396,7 +394,7 @@ public class SMARTSQueryTool {
      * @return A List of List of atom indices in the target molecule
      */
     public List<List<Integer>> getMatchingAtoms() {
-        List<List<Integer>> matched = new ArrayList<List<Integer>>(mappings.size());
+        List<List<Integer>> matched = new ArrayList<>(mappings.size());
         for (int[] mapping : mappings)
             matched.add(toList(mapping));
         return matched;
@@ -410,7 +408,7 @@ public class SMARTSQueryTool {
      * @return A List of List of atom indices in the target molecule
      */
     public List<List<Integer>> getUniqueMatchingAtoms() {
-        List<List<Integer>> matched = new ArrayList<List<Integer>>(mappings.size());
+        List<List<Integer>> matched = new ArrayList<>(mappings.size());
         Set<BitSet> atomSets = new HashSet<>(2*mappings.size());
         for (int[] mapping : mappings) {
             BitSet atomSet = new BitSet();
@@ -459,11 +457,11 @@ public class SMARTSQueryTool {
 
     private List<Set<Integer>> matchedAtoms(List<List<RMap>> bondMapping, IAtomContainer atomContainer) {
 
-        List<Set<Integer>> atomMapping = new ArrayList<Set<Integer>>();
+        List<Set<Integer>> atomMapping = new ArrayList<>();
         // loop over each mapping
         for (List<RMap> mapping : bondMapping) {
 
-            Set<Integer> tmp = new TreeSet<Integer>();
+            Set<Integer> tmp = new TreeSet<>();
             IAtom atom1 = null;
             IAtom atom2 = null;
             // loop over this mapping
@@ -485,8 +483,9 @@ public class SMARTSQueryTool {
             if (tmp.size() == query.getAtomCount()) atomMapping.add(tmp);
 
             // If there is only one bond, check if it matches both ways.
-            if (mapping.size() == 1 && atom1.getAtomicNumber().equals(atom2.getAtomicNumber())) {
-                atomMapping.add(new TreeSet<Integer>(tmp));
+            if (mapping.size() == 1 && atom1 != null && atom2 != null &&
+                    Objects.equals(atom1.getAtomicNumber(), atom2.getAtomicNumber())) {
+                atomMapping.add(new TreeSet<>(tmp));
             }
         }
 
