@@ -27,8 +27,7 @@ import javax.vecmath.Point2d;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
-import org.openscience.cdk.AtomContainer;
-import org.openscience.cdk.CDKConstants;
+import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.interfaces.IElement;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.DefaultChemObjectBuilder;
@@ -74,13 +73,13 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
 
         int numberOfAromaticAtoms = 0;
         for (int i = 0; i < mol.getAtomCount(); i++) {
-            if (mol.getAtom(i).getFlag(CDKConstants.ISAROMATIC)) numberOfAromaticAtoms++;
+            if (mol.getAtom(i).getFlag(IChemObject.AROMATIC)) numberOfAromaticAtoms++;
         }
         Assertions.assertEquals(6, numberOfAromaticAtoms);
 
         int numberOfAromaticBonds = 0;
         for (int i = 0; i < mol.getBondCount(); i++) {
-            if (mol.getBond(i).getFlag(CDKConstants.ISAROMATIC)) numberOfAromaticBonds++;
+            if (mol.getBond(i).getFlag(IChemObject.AROMATIC)) numberOfAromaticBonds++;
         }
         Assertions.assertEquals(6, numberOfAromaticBonds);
 
@@ -105,14 +104,14 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         int numberOfAromaticRings = 0;
         RingSetManipulator.markAromaticRings(ringset);
         for (int i = 0; i < ringset.getAtomContainerCount(); i++) {
-            if (ringset.getAtomContainer(i).getFlag(CDKConstants.ISAROMATIC)) numberOfAromaticRings++;
+            if (ringset.getAtomContainer(i).getFlag(IChemObject.AROMATIC)) numberOfAromaticRings++;
         }
         Assertions.assertEquals(1, numberOfAromaticRings);
     }
 
     @Test
     void testPyridine() throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         mol.addAtom(new Atom("N"));
         mol.addAtom(new Atom("C"));
         mol.addBond(0, 1, IBond.Order.SINGLE);
@@ -129,21 +128,21 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         Assertions.assertTrue(Aromaticity.cdkLegacy().apply(mol), "Expected the molecule to be aromatic.");
 
         for (IAtom iAtom : mol.atoms()) {
-            Assertions.assertTrue(iAtom.getFlag(CDKConstants.ISAROMATIC));
+            Assertions.assertTrue(iAtom.getFlag(IChemObject.AROMATIC));
         }
 
         IRingSet ringset = (new SSSRFinder(mol)).findSSSR();
         int numberOfAromaticRings = 0;
         RingSetManipulator.markAromaticRings(ringset);
         for (int i = 0; i < ringset.getAtomContainerCount(); i++) {
-            if (ringset.getAtomContainer(i).getFlag(CDKConstants.ISAROMATIC)) numberOfAromaticRings++;
+            if (ringset.getAtomContainer(i).getFlag(IChemObject.AROMATIC)) numberOfAromaticRings++;
         }
         Assertions.assertEquals(1, numberOfAromaticRings);
     }
 
     @Test
     void testCyclopentadienyl() throws Exception {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         mol.addAtom(new Atom("C"));
         mol.getAtom(0).setFormalCharge(-1);
         for (int i = 1; i < 5; i++) {
@@ -156,7 +155,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         Assertions.assertTrue(Aromaticity.cdkLegacy().apply(mol), "Expected the molecule to be aromatic.");
 
         for (IAtom iAtom : mol.atoms()) {
-            Assertions.assertTrue(iAtom.getFlag(CDKConstants.ISAROMATIC));
+            Assertions.assertTrue(iAtom.getFlag(IChemObject.AROMATIC));
         }
     }
 
@@ -190,7 +189,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         int numberOfAromaticRings = 0;
         RingSetManipulator.markAromaticRings(ringset);
         for (int i = 0; i < ringset.getAtomContainerCount(); i++) {
-            if (ringset.getAtomContainer(i).getFlag(CDKConstants.ISAROMATIC)) numberOfAromaticRings++;
+            if (ringset.getAtomContainer(i).getFlag(IChemObject.AROMATIC)) numberOfAromaticRings++;
         }
         Assertions.assertEquals(1, numberOfAromaticRings);
     }
@@ -206,7 +205,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         Assertions.assertTrue(Aromaticity.cdkLegacy().apply(mol), "Molecule is not detected aromatic");
         for (IAtom atom : mol.atoms())
-            Assertions.assertTrue(atom.getFlag(CDKConstants.ISAROMATIC));
+            Assertions.assertTrue(atom.getFlag(IChemObject.AROMATIC));
     }
 
     /**
@@ -220,7 +219,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         Assertions.assertTrue(Aromaticity.cdkLegacy().apply(mol), "Molecule is not detected aromatic");
         for (IAtom atom : mol.atoms())
-            Assertions.assertTrue(atom.getFlag(CDKConstants.ISAROMATIC));
+            Assertions.assertTrue(atom.getFlag(IChemObject.AROMATIC));
     }
 
     /**
@@ -234,7 +233,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(molecule);
         Assertions.assertTrue(Aromaticity.cdkLegacy().apply(molecule), "Expected the molecule to be aromatic.");
         for (int f = 0; f < molecule.getAtomCount(); f++) {
-            Assertions.assertEquals(testResults[f], molecule.getAtom(f).getFlag(CDKConstants.ISAROMATIC), "Atom " + f + " is not correctly marked");
+            Assertions.assertEquals(testResults[f], molecule.getAtom(f).getFlag(IChemObject.AROMATIC), "Atom " + f + " is not correctly marked");
         }
     }
 
@@ -249,7 +248,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(molecule);
         Assertions.assertTrue(Aromaticity.cdkLegacy().apply(molecule), "Expected the molecule to be aromatic.");
         for (int f = 0; f < molecule.getAtomCount(); f++) {
-            Assertions.assertEquals(testResults[f], molecule.getAtom(f).getFlag(CDKConstants.ISAROMATIC), "Atom " + f + " is not correctly marked");
+            Assertions.assertEquals(testResults[f], molecule.getAtom(f).getFlag(IChemObject.AROMATIC), "Atom " + f + " is not correctly marked");
         }
     }
 
@@ -263,7 +262,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(molecule);
         Assertions.assertTrue(Aromaticity.cdkLegacy().apply(molecule), "Expected the molecule to be aromatic.");
         for (int f = 0; f < molecule.getAtomCount(); f++) {
-            Assertions.assertEquals(testResults[f], molecule.getAtom(f).getFlag(CDKConstants.ISAROMATIC), "Atom " + f + " is not correctly marked");
+            Assertions.assertEquals(testResults[f], molecule.getAtom(f).getFlag(IChemObject.AROMATIC), "Atom " + f + " is not correctly marked");
         }
     }
 
@@ -277,7 +276,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         Assertions.assertTrue(Aromaticity.cdkLegacy().apply(molecule), "Molecule is not detected as aromatic");
 
         for (int f = 0; f < molecule.getAtomCount(); f++) {
-            Assertions.assertTrue(molecule.getAtom(f).getFlag(CDKConstants.ISAROMATIC), "Atom " + f + " is not correctly marked");
+            Assertions.assertTrue(molecule.getAtom(f).getFlag(IChemObject.AROMATIC), "Atom " + f + " is not correctly marked");
         }
     }
 
@@ -299,7 +298,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         int aromacount = 0;
         for (IAtomContainer container : rs.atomContainers()) {
             r = (IRing) container;
-            isAromatic = r.getFlag(CDKConstants.ISAROMATIC);
+            isAromatic = r.getFlag(IChemObject.AROMATIC);
 
             if (isAromatic) aromacount++;
         }
@@ -325,7 +324,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         Assertions.assertEquals(7, mol.getAtomCount());
         for (int f = 0; f < mol.getAtomCount(); f++) {
             Assertions.assertNotNull(mol.getAtom(f));
-            Assertions.assertTrue(mol.getAtom(f).getFlag(CDKConstants.ISAROMATIC));
+            Assertions.assertTrue(mol.getAtom(f).getFlag(IChemObject.AROMATIC));
         }
     }
 
@@ -344,7 +343,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         Assertions.assertFalse(Aromaticity.cdkLegacy().apply(mol));
         Assertions.assertEquals(testResults.length, mol.getAtomCount());
         for (int f = 0; f < mol.getAtomCount(); f++) {
-            Assertions.assertEquals(testResults[f], mol.getAtom(f).getFlag(CDKConstants.ISAROMATIC));
+            Assertions.assertEquals(testResults[f], mol.getAtom(f).getFlag(IChemObject.AROMATIC));
         }
     }
 
@@ -376,7 +375,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(molecule);
         isAromatic = Aromaticity.cdkLegacy().apply(molecule);
         for (int f = 0; f < molecule.getAtomCount(); f++) {
-            Assertions.assertEquals(testResults[f], molecule.getAtom(f).getFlag(CDKConstants.ISAROMATIC));
+            Assertions.assertEquals(testResults[f], molecule.getAtom(f).getFlag(IChemObject.AROMATIC));
         }
         Assertions.assertTrue(isAromatic);
     }
@@ -402,7 +401,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(molecule);
         Aromaticity.cdkLegacy().apply(molecule);
         for (int f = 0; f < molecule.getAtomCount(); f++) {
-            Assertions.assertEquals(testResults[f], molecule.getAtom(f).getFlag(CDKConstants.ISAROMATIC));
+            Assertions.assertEquals(testResults[f], molecule.getAtom(f).getFlag(IChemObject.AROMATIC));
         }
     }
 
@@ -429,7 +428,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(molecule);
         Aromaticity.cdkLegacy().apply(molecule);
         for (int f = 0; f < molecule.getAtomCount(); f++) {
-            Assertions.assertEquals(testResults[f], molecule.getAtom(f).getFlag(CDKConstants.ISAROMATIC));
+            Assertions.assertEquals(testResults[f], molecule.getAtom(f).getFlag(IChemObject.AROMATIC));
         }
 
     }
@@ -445,7 +444,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(molecule);
         Aromaticity.cdkLegacy().apply(molecule);
         for (int f = 0; f < molecule.getAtomCount(); f++) {
-            Assertions.assertEquals(testResults[f], molecule.getAtom(f).getFlag(CDKConstants.ISAROMATIC));
+            Assertions.assertEquals(testResults[f], molecule.getAtom(f).getFlag(IChemObject.AROMATIC));
         }
 
     }
@@ -466,12 +465,12 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         Aromaticity.cdkLegacy().apply(molecule);
 
         Assertions.assertEquals(15, molecule.getBondCount());
-        Assertions.assertTrue(molecule.getBond(0).getFlag(CDKConstants.ISAROMATIC));
-        Assertions.assertTrue(molecule.getBond(1).getFlag(CDKConstants.ISAROMATIC));
-        Assertions.assertTrue(molecule.getBond(2).getFlag(CDKConstants.ISAROMATIC));
-        Assertions.assertTrue(molecule.getBond(3).getFlag(CDKConstants.ISAROMATIC));
-        Assertions.assertTrue(molecule.getBond(4).getFlag(CDKConstants.ISAROMATIC));
-        Assertions.assertTrue(molecule.getBond(6).getFlag(CDKConstants.ISAROMATIC));
+        Assertions.assertTrue(molecule.getBond(0).getFlag(IChemObject.AROMATIC));
+        Assertions.assertTrue(molecule.getBond(1).getFlag(IChemObject.AROMATIC));
+        Assertions.assertTrue(molecule.getBond(2).getFlag(IChemObject.AROMATIC));
+        Assertions.assertTrue(molecule.getBond(3).getFlag(IChemObject.AROMATIC));
+        Assertions.assertTrue(molecule.getBond(4).getFlag(IChemObject.AROMATIC));
+        Assertions.assertTrue(molecule.getBond(6).getFlag(IChemObject.AROMATIC));
     }
 
     /**
@@ -483,7 +482,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(molecule);
         Aromaticity.cdkLegacy().apply(molecule);
         for (int f = 0; f < molecule.getAtomCount(); f++) {
-            Assertions.assertTrue(molecule.getAtom(f).getFlag(CDKConstants.ISAROMATIC));
+            Assertions.assertTrue(molecule.getAtom(f).getFlag(IChemObject.AROMATIC));
         }
     }
 
@@ -495,7 +494,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
 
         Assertions.assertFalse(Aromaticity.cdkLegacy().apply(molecule));
         for (int f = 0; f < molecule.getAtomCount(); f++) {
-            Assertions.assertFalse(molecule.getAtom(f).getFlag(CDKConstants.ISAROMATIC));
+            Assertions.assertFalse(molecule.getAtom(f).getFlag(IChemObject.AROMATIC));
         }
     }
 
@@ -562,7 +561,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
     @Test
     void test3Amino2MethylPyridine() throws Exception {
 
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         IAtom a1 = mol.getBuilder().newInstance(IAtom.class, "N");
         a1.setPoint2d(new Point2d(3.7321, 1.345));
         mol.addAtom(a1);
@@ -656,12 +655,12 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         while (atoms.hasNext()) {
             IAtom atom = atoms.next();
             if (atom.getAtomicNumber() == IElement.C) {
-                if (atom.getFlag(CDKConstants.ISAROMATIC))
+                if (atom.getFlag(IChemObject.AROMATIC))
                     nCarom++;
                 else
                     nCalip++;
             } else if (atom.getAtomicNumber() == IElement.N) {
-                if (atom.getFlag(CDKConstants.ISAROMATIC))
+                if (atom.getFlag(IChemObject.AROMATIC))
                     nNarom++;
                 else
                     nNaliph++;
@@ -704,13 +703,13 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         for (IAtom atom : aromaticForm.atoms()) {
             if (atom.getAtomicNumber() == IElement.C) {
                 Assertions.assertEquals("C.sp2", atom.getAtomTypeName());
-                Assertions.assertTrue(atom.getFlag(CDKConstants.ISAROMATIC));
+                Assertions.assertTrue(atom.getFlag(IChemObject.AROMATIC));
             }
         }
         for (IAtom atom : kekuleForm.atoms()) {
             if (atom.getAtomicNumber() == IElement.C) {
                 Assertions.assertEquals("C.sp2", atom.getAtomTypeName());
-                Assertions.assertTrue(atom.getFlag(CDKConstants.ISAROMATIC));
+                Assertions.assertTrue(atom.getFlag(IChemObject.AROMATIC));
             }
         }
     }
@@ -728,7 +727,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
 
         // all atoms are supposed to be aromatic
         for (IAtom atom : aromaticForm.atoms()) {
-            Assertions.assertTrue(atom.getFlag(CDKConstants.ISAROMATIC), atom.toString() + " should be aromatic");
+            Assertions.assertTrue(atom.getFlag(IChemObject.AROMATIC), atom.toString() + " should be aromatic");
         }
     }
 
@@ -742,7 +741,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         Assertions.assertTrue(Aromaticity.cdkLegacy().apply(mol));
         for (IAtom atom : mol.atoms())
-            Assertions.assertTrue(atom.getFlag(CDKConstants.ISAROMATIC));
+            Assertions.assertTrue(atom.getFlag(IChemObject.AROMATIC));
     }
 
     /**
@@ -758,7 +757,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         Assertions.assertTrue(Aromaticity.cdkLegacy().apply(mol));
         for (IAtom atom : mol.atoms()) {
             if (atom.getAtomicNumber() == IElement.O) continue;
-            Assertions.assertTrue(atom.getFlag(CDKConstants.ISAROMATIC), atom.getSymbol() + " was not aromatic but should have been");
+            Assertions.assertTrue(atom.getFlag(IChemObject.AROMATIC), atom.getSymbol() + " was not aromatic but should have been");
         }
     }
 
@@ -775,7 +774,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         Assertions.assertTrue(Aromaticity.cdkLegacy().apply(mol));
         for (IAtom atom : mol.atoms()) {
             if (atom.getAtomicNumber() == IElement.O) continue;
-            Assertions.assertTrue(atom.getFlag(CDKConstants.ISAROMATIC), atom.getSymbol() + " was not aromatic but should have been");
+            Assertions.assertTrue(atom.getFlag(IChemObject.AROMATIC), atom.getSymbol() + " was not aromatic but should have been");
         }
     }
 
@@ -786,7 +785,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         Assertions.assertTrue(Aromaticity.cdkLegacy().apply(mol));
         for (IAtom atom : mol.atoms())
-            Assertions.assertTrue(atom.getFlag(CDKConstants.ISAROMATIC), "Atom is expected to be aromatic: " + atom);
+            Assertions.assertTrue(atom.getFlag(IChemObject.AROMATIC), "Atom is expected to be aromatic: " + atom);
     }
 
     @Test
@@ -797,7 +796,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         Assertions.assertTrue(Aromaticity.cdkLegacy().apply(mol));
         for (int i = 2; i <= 6; i++) {
             IAtom atom = mol.getAtom(i);
-            Assertions.assertTrue(atom.getFlag(CDKConstants.ISAROMATIC), "Atom is expected to be aromatic: " + atom);
+            Assertions.assertTrue(atom.getFlag(IChemObject.AROMATIC), "Atom is expected to be aromatic: " + atom);
         }
     }
 
@@ -809,7 +808,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         Assertions.assertTrue(Aromaticity.cdkLegacy().apply(mol));
         for (int i = 3; i <= 7; i++) {
             IAtom atom = mol.getAtom(i);
-            Assertions.assertTrue(atom.getFlag(CDKConstants.ISAROMATIC), "Atom is expected to be aromatic: " + atom);
+            Assertions.assertTrue(atom.getFlag(IChemObject.AROMATIC), "Atom is expected to be aromatic: " + atom);
         }
     }
 
@@ -824,15 +823,15 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         Assertions.assertTrue(Aromaticity.cdkLegacy().apply(mol));
         for (IAtom atom : mol.atoms()) {
             if (atom.getAtomicNumber() == IElement.N) {
-                Assertions.assertTrue(atom.getFlag(CDKConstants.ISAROMATIC));
+                Assertions.assertTrue(atom.getFlag(IChemObject.AROMATIC));
                 List<IBond> conbonds = mol.getConnectedBondsList(atom);
                 if (conbonds.size() == 2) {
-                    Assertions.assertTrue(conbonds.get(0).getFlag(CDKConstants.ISAROMATIC));
-                    Assertions.assertTrue(conbonds.get(1).getFlag(CDKConstants.ISAROMATIC));
+                    Assertions.assertTrue(conbonds.get(0).getFlag(IChemObject.AROMATIC));
+                    Assertions.assertTrue(conbonds.get(1).getFlag(IChemObject.AROMATIC));
                 } else if (conbonds.size() == 3) {
                     for (IBond bond : conbonds) {
                         if (bond.getOrder().equals(IBond.Order.SINGLE)) continue;
-                        Assertions.assertTrue(bond.getFlag(CDKConstants.ISAROMATIC));
+                        Assertions.assertTrue(bond.getFlag(IChemObject.AROMATIC));
                     }
                 }
             }
@@ -841,7 +840,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         IRingSet ringSet = st.getAllRings();
         for (IAtomContainer ring : ringSet.atomContainers()) {
             for (IBond bond : ring.bonds()) {
-                Assertions.assertTrue(bond.getFlag(CDKConstants.ISAROMATIC));
+                Assertions.assertTrue(bond.getFlag(IChemObject.AROMATIC));
             }
         }
     }
@@ -857,11 +856,11 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         Assertions.assertTrue(Aromaticity.cdkLegacy().apply(mol));
         for (IAtom atom : mol.atoms()) {
             if (atom.getAtomicNumber() == IElement.N) {
-                Assertions.assertTrue(atom.getFlag(CDKConstants.ISAROMATIC));
+                Assertions.assertTrue(atom.getFlag(IChemObject.AROMATIC));
                 List<IBond> conbonds = mol.getConnectedBondsList(atom);
                 for (IBond bond : conbonds) {
                     if (bond.getOrder().equals(IBond.Order.SINGLE)) continue;
-                    Assertions.assertTrue(bond.getFlag(CDKConstants.ISAROMATIC));
+                    Assertions.assertTrue(bond.getFlag(IChemObject.AROMATIC));
                 }
             }
         }
@@ -869,7 +868,7 @@ class CDKHueckelAromaticityDetectorTest extends CDKTestCase {
         IRingSet ringSet = st.getAllRings();
         for (IAtomContainer ring : ringSet.atomContainers()) {
             for (IBond bond : ring.bonds()) {
-                Assertions.assertTrue(bond.getFlag(CDKConstants.ISAROMATIC));
+                Assertions.assertTrue(bond.getFlag(IChemObject.AROMATIC));
             }
         }
     }
