@@ -29,7 +29,6 @@ import javax.vecmath.Point3d;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
-import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.Bond;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.DefaultChemObjectBuilder;
@@ -70,7 +69,7 @@ class GeometryToolsTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(1, 1));
         Atom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(1, 0));
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
         Assertions.assertTrue(GeometryTools.has2DCoordinates(container));
@@ -79,7 +78,7 @@ class GeometryToolsTest extends CDKTestCase {
         atom1.setPoint3d(new Point3d(1, 1, 1));
         atom2 = new Atom("C");
         atom2.setPoint3d(new Point3d(1, 0, 5));
-        container = new AtomContainer();
+        container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
         Assertions.assertFalse(GeometryTools.has2DCoordinates(container));
@@ -87,14 +86,14 @@ class GeometryToolsTest extends CDKTestCase {
 
     @Test
     void testHas2DCoordinates_EmptyAtomContainer() {
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         Assertions.assertFalse(GeometryTools.has2DCoordinates(container));
         Assertions.assertFalse(GeometryTools.has2DCoordinates((IAtomContainer) null));
     }
 
     @Test
     void testHas2DCoordinates_Partial() {
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         Atom atom1 = new Atom("C");
         Atom atom2 = new Atom("C");
         atom1.setPoint2d(new Point2d(1, 1));
@@ -113,13 +112,13 @@ class GeometryToolsTest extends CDKTestCase {
         InputStream ins = this.getClass().getResourceAsStream(filenameMol);
         IAtomContainer molOne;
         MDLV2000Reader reader = new MDLV2000Reader(ins, Mode.STRICT);
-        molOne = reader.read(new AtomContainer());
+        molOne = reader.read(DefaultChemObjectBuilder.getInstance().newAtomContainer());
         Assertions.assertTrue(GeometryTools.has2DCoordinates(molOne));
     }
 
     @Test
     void get2DCoordinateCoverage_EmptyAtomContainer() {
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         Assertions.assertEquals(GeometryTools.CoordinateCoverage.NONE, GeometryTools.get2DCoordinateCoverage(container));
         Assertions.assertEquals(GeometryTools.CoordinateCoverage.NONE, GeometryTools.get2DCoordinateCoverage(null));
     }
@@ -127,7 +126,7 @@ class GeometryToolsTest extends CDKTestCase {
     @Test
     void get2DCoordinateCoverage_Partial() {
 
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
 
         IAtom atom1 = new Atom("C");
         IAtom atom2 = new Atom("C");
@@ -147,7 +146,7 @@ class GeometryToolsTest extends CDKTestCase {
     @Test
     void get2DCoordinateCoverage_Full() {
 
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
 
         IAtom atom1 = new Atom("C");
         IAtom atom2 = new Atom("C");
@@ -168,7 +167,7 @@ class GeometryToolsTest extends CDKTestCase {
     @Test
     void get2DCoordinateCoverage_None_3D() {
 
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
 
         IAtom atom1 = new Atom("C");
         IAtom atom2 = new Atom("C");
@@ -188,7 +187,7 @@ class GeometryToolsTest extends CDKTestCase {
 
     @Test
     void testTranslateAllPositive_IAtomContainer() {
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         IAtom atom = new Atom(Elements.CARBON);
         atom.setPoint2d(new Point2d(-3, -2));
         container.addAtom(atom);
@@ -216,11 +215,11 @@ class GeometryToolsTest extends CDKTestCase {
         IAtomContainer molTwo;
         Map<Integer, Integer> mappedAtoms = new HashMap<>();
         MDLV2000Reader reader = new MDLV2000Reader(ins, Mode.STRICT);
-        molOne = reader.read(new AtomContainer());
+        molOne = reader.read(DefaultChemObjectBuilder.getInstance().newAtomContainer());
 
         ins = this.getClass().getResourceAsStream(filenameMolTwo);
         reader = new MDLV2000Reader(ins, Mode.STRICT);
-        molTwo = reader.read(new AtomContainer());
+        molTwo = reader.read(DefaultChemObjectBuilder.getInstance().newAtomContainer());
 
         mappedAtoms = AtomMappingTools.mapAtomsOfAlignedStructures(molOne, molTwo, mappedAtoms);
         //logger.debug("mappedAtoms:"+mappedAtoms.toString());
@@ -300,7 +299,7 @@ class GeometryToolsTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(2, 2));
         Atom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(5, 1));
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
         Rectangle2D rectangle = GeometryTools.getRectangle2D(container);
@@ -360,7 +359,7 @@ class GeometryToolsTest extends CDKTestCase {
 
     @Test
     void testGet2DCenter_arrayIAtom() {
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         Atom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(1, 1));
         Atom atom2 = new Atom("C");
@@ -436,7 +435,7 @@ class GeometryToolsTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(1, 1));
         Atom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(1, 0));
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
         Assertions.assertEquals(2, GeometryTools.has2DCoordinatesNew(container));
@@ -445,7 +444,7 @@ class GeometryToolsTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(1, 1));
         atom2 = new Atom("C");
         atom2.setPoint3d(new Point3d(1, 0, 1));
-        container = new AtomContainer();
+        container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
         Assertions.assertEquals(1, GeometryTools.has2DCoordinatesNew(container));
@@ -454,7 +453,7 @@ class GeometryToolsTest extends CDKTestCase {
         atom1.setPoint3d(new Point3d(1, 1, 1));
         atom2 = new Atom("C");
         atom2.setPoint3d(new Point3d(1, 0, 5));
-        container = new AtomContainer();
+        container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
         Assertions.assertEquals(0, GeometryTools.has2DCoordinatesNew(container));
@@ -466,7 +465,7 @@ class GeometryToolsTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(1, 1));
         Atom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(1, 0));
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
         Assertions.assertFalse(GeometryTools.has3DCoordinates(container));
@@ -475,7 +474,7 @@ class GeometryToolsTest extends CDKTestCase {
         atom1.setPoint3d(new Point3d(1, 1, 1));
         atom2 = new Atom("C");
         atom2.setPoint3d(new Point3d(1, 0, 5));
-        container = new AtomContainer();
+        container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
         Assertions.assertTrue(GeometryTools.has3DCoordinates(container));
@@ -483,14 +482,14 @@ class GeometryToolsTest extends CDKTestCase {
 
     @Test
     void testHas3DCoordinates_EmptyAtomContainer() {
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         Assertions.assertFalse(GeometryTools.has3DCoordinates(container));
         Assertions.assertFalse(GeometryTools.has3DCoordinates((IAtomContainer) null));
     }
 
     @Test
     void get3DCoordinateCoverage_EmptyAtomContainer() {
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         Assertions.assertEquals(GeometryTools.CoordinateCoverage.NONE, GeometryTools.get3DCoordinateCoverage(container));
         Assertions.assertEquals(GeometryTools.CoordinateCoverage.NONE, GeometryTools.get3DCoordinateCoverage(null));
     }
@@ -498,7 +497,7 @@ class GeometryToolsTest extends CDKTestCase {
     @Test
     void get3DCoordinateCoverage_Partial() {
 
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
 
         IAtom atom1 = new Atom("C");
         IAtom atom2 = new Atom("C");
@@ -518,7 +517,7 @@ class GeometryToolsTest extends CDKTestCase {
     @Test
     void get3DCoordinateCoverage_Full() {
 
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
 
         IAtom atom1 = new Atom("C");
         IAtom atom2 = new Atom("C");
@@ -539,7 +538,7 @@ class GeometryToolsTest extends CDKTestCase {
     @Test
     void get3DCoordinateCoverage_None_2D() {
 
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
 
         IAtom atom1 = new Atom("C");
         IAtom atom2 = new Atom("C");
@@ -594,7 +593,7 @@ class GeometryToolsTest extends CDKTestCase {
         atom2.setPoint2d(new Point2d(1, 0));
         IAtom atom3 = new Atom("C");
         atom3.setPoint2d(new Point2d(5, 0));
-        IAtomContainer acont = new AtomContainer();
+        IAtomContainer acont = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         acont.addAtom(atom1);
         acont.addAtom(atom2);
         acont.addAtom(atom3);
@@ -609,7 +608,7 @@ class GeometryToolsTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(1, 0));
         IAtom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(5, 0));
-        IAtomContainer acont = new AtomContainer();
+        IAtomContainer acont = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         acont.addAtom(atom1);
         acont.addAtom(atom2);
         Assertions.assertEquals(atom2, GeometryTools.getClosestAtom(1.0, 0.0, acont, atom1));
@@ -625,7 +624,7 @@ class GeometryToolsTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(-1, -1));
         IAtom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(1, 0));
-        IAtomContainer acont = new AtomContainer();
+        IAtomContainer acont = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         acont.addAtom(atom1);
         acont.addAtom(atom2);
         Assertions.assertEquals(atom2, GeometryTools.getClosestAtom(acont, atom1));
@@ -638,7 +637,7 @@ class GeometryToolsTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(0, 1));
         IAtom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(1, 0));
-        IAtomContainer react1 = new AtomContainer();
+        IAtomContainer react1 = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         react1.addAtom(atom1);
         react1.addAtom(atom2);
         IAtomContainer react2 = react1.clone();
@@ -670,7 +669,7 @@ class GeometryToolsTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(0, 0));
         IAtom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(0, 1));
-        IAtomContainer react1 = new AtomContainer();
+        IAtomContainer react1 = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         react1.addAtom(atom1);
         react1.addAtom(atom2);
         IAtomContainer react2 = react1.clone();
@@ -696,7 +695,7 @@ class GeometryToolsTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(0, 0));
         IAtom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(1, 0));
-        IAtomContainer acont = new AtomContainer();
+        IAtomContainer acont = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         IReaction reaction = new Reaction();
         reaction.addReactant(acont);
         acont.addAtom(atom1);
@@ -718,7 +717,7 @@ class GeometryToolsTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(0, 0));
         IAtom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(1, 0));
-        IAtomContainer acont = new AtomContainer();
+        IAtomContainer acont = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         reaction.addReactant(acont);
         acont.addAtom(atom1);
         acont.addAtom(atom2);
@@ -729,7 +728,7 @@ class GeometryToolsTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(0, 0));
         atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(3, 0));
-        acont = new AtomContainer();
+        acont = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         reaction.addProduct(acont);
         acont.addAtom(atom1);
         acont.addAtom(atom2);
@@ -744,7 +743,7 @@ class GeometryToolsTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(0, 1));
         IAtom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(1, 0));
-        IAtomContainer react1 = new AtomContainer();
+        IAtomContainer react1 = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         IReaction reaction = new Reaction();
         reaction.addReactant(react1);
         react1.addAtom(atom1);
@@ -782,7 +781,7 @@ class GeometryToolsTest extends CDKTestCase {
         atom1.setPoint2d(new Point2d(0, 0));
         IAtom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(1, 0));
-        IAtomContainer react1 = new AtomContainer();
+        IAtomContainer react1 = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         IReaction reaction = new Reaction();
         reaction.addReactant(react1);
         react1.addAtom(atom1);
@@ -832,7 +831,7 @@ class GeometryToolsTest extends CDKTestCase {
 
     @Test
     void medianBondLength() {
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atomAt(new Point2d(0, 0)));
         container.addAtom(atomAt(new Point2d(0, 1.5)));
         container.addAtom(atomAt(new Point2d(0, -1.5)));
@@ -845,7 +844,7 @@ class GeometryToolsTest extends CDKTestCase {
 
     @Test
     void medianBondLengthNoBonds() {
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atomAt(new Point2d(0, 0)));
         container.addAtom(atomAt(new Point2d(0, 1.5)));
         container.addAtom(atomAt(new Point2d(0, -1.5)));
@@ -857,7 +856,7 @@ class GeometryToolsTest extends CDKTestCase {
 
     @Test
     void medianBondLengthNoPoints() {
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atomAt(new Point2d(0, 0)));
         container.addAtom(atomAt(new Point2d(0, 1.5)));
         container.addAtom(atomAt(null));
@@ -872,7 +871,7 @@ class GeometryToolsTest extends CDKTestCase {
 
     @Test
     void medianBondLengthOneBond() {
-        IAtomContainer container = new AtomContainer();
+        IAtomContainer container = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         container.addAtom(atomAt(new Point2d(0, 0)));
         container.addAtom(atomAt(new Point2d(0, 1.5)));
         container.addBond(0, 1, IBond.Order.SINGLE);
@@ -886,7 +885,7 @@ class GeometryToolsTest extends CDKTestCase {
     }
 
     private int alignmentTestHelper(IAtom zero, IAtom... pos) {
-        IAtomContainer mol = new AtomContainer();
+        IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         mol.addAtom(zero);
         for (IAtom atom : pos) {
             mol.addAtom(atom);
