@@ -26,8 +26,6 @@ import java.util.List;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.Tag;
-import org.openscience.cdk.AtomContainer;
-import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.interfaces.IAtom;
@@ -91,7 +89,7 @@ class SSSRFinderTest extends CDKTestCase {
 
         int count = 0;
         for (IAtom atom : molecule.atoms()) {
-            if (atom.getFlag(CDKConstants.ISINRING)) count++;
+            if (atom.getFlag(IChemObject.IN_RING)) count++;
         }
         Assertions.assertEquals(6, count, "All atoms in benzene were not marked as being in a ring");
     }
@@ -104,7 +102,7 @@ class SSSRFinderTest extends CDKTestCase {
 
         int count = 0;
         for (IAtom atom : molecule.atoms()) {
-            if (atom.getFlag(CDKConstants.ISINRING)) count++;
+            if (atom.getFlag(IChemObject.IN_RING)) count++;
         }
         Assertions.assertEquals(5, count, "All ring atoms in 2-ethyl cyclopentane were not marked as being in a ring");
     }
@@ -135,7 +133,7 @@ class SSSRFinderTest extends CDKTestCase {
         String filename = "figueras-test-sep3D.mol";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         MDLV2000Reader reader = new MDLV2000Reader(ins, Mode.STRICT);
-        molecule = (IAtomContainer) reader.read((IChemObject) new AtomContainer());
+        molecule = (IAtomContainer) reader.read((IChemObject) DefaultChemObjectBuilder.getInstance().newAtomContainer());
         reader.close();
         logger.debug("Testing " + filename);
 
@@ -153,7 +151,7 @@ class SSSRFinderTest extends CDKTestCase {
         String filename = "ring_03419.mol";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         MDLV2000Reader reader = new MDLV2000Reader(ins, Mode.STRICT);
-        IAtomContainer molecule = (IAtomContainer) reader.read((IChemObject) new AtomContainer());
+        IAtomContainer molecule = (IAtomContainer) reader.read((IChemObject) DefaultChemObjectBuilder.getInstance().newAtomContainer());
         reader.close();
         logger.debug("Testing " + filename);
 
@@ -173,7 +171,7 @@ class SSSRFinderTest extends CDKTestCase {
         String filename = "figueras-test-buried.mol";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         MDLV2000Reader reader = new MDLV2000Reader(ins, Mode.STRICT);
-        molecule = (IAtomContainer) reader.read((IChemObject) new AtomContainer());
+        molecule = (IAtomContainer) reader.read((IChemObject) DefaultChemObjectBuilder.getInstance().newAtomContainer());
         reader.close();
         logger.debug("Testing " + filename);
 
@@ -193,7 +191,7 @@ class SSSRFinderTest extends CDKTestCase {
         String filename = "figueras-test-inring.mol";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         MDLV2000Reader reader = new MDLV2000Reader(ins, Mode.STRICT);
-        molecule = (IAtomContainer) reader.read((IChemObject) new AtomContainer());
+        molecule = (IAtomContainer) reader.read((IChemObject) DefaultChemObjectBuilder.getInstance().newAtomContainer());
         reader.close();
         logger.debug("Testing " + filename);
 
@@ -215,7 +213,7 @@ class SSSRFinderTest extends CDKTestCase {
         String filename = "too.many.rings.mol";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         MDLV2000Reader reader = new MDLV2000Reader(ins, Mode.STRICT);
-        molecule = (IAtomContainer) reader.read((IChemObject) new AtomContainer());
+        molecule = (IAtomContainer) reader.read((IChemObject) DefaultChemObjectBuilder.getInstance().newAtomContainer());
         reader.close();
         logger.debug("Testing " + filename);
 
@@ -293,7 +291,7 @@ class SSSRFinderTest extends CDKTestCase {
         String filename = "buckyball.mol";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         MDLV2000Reader reader = new MDLV2000Reader(ins, Mode.STRICT);
-        molecule = reader.read(new AtomContainer());
+        molecule = reader.read(DefaultChemObjectBuilder.getInstance().newAtomContainer());
         reader.close();
         Assertions.assertTrue(molecule.getAtomCount() == 60, "Atom count is 60 ");
         Assertions.assertTrue(molecule.getBondCount() == 90, "Bond count is 90 ");
