@@ -18,46 +18,46 @@
  */
 package org.openscience.cdk.tools.diff.tree;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 /**
  * @cdk.module test-diff
  */
-public class DoubleDifferenceTest {
+class DoubleDifferenceTest {
 
     @Test
-    public void testDiff() {
+    void testDiff() {
         IDifference result = DoubleDifference.construct("Foo", 1.0, 3.0);
-        Assert.assertNotNull(result);
+        Assertions.assertNotNull(result);
     }
 
     @Test
-    public void testSame() {
+    void testSame() {
         IDifference result = DoubleDifference.construct("Foo", 1.0, 1.0);
-        Assert.assertNull(result);
+        Assertions.assertNull(result);
     }
 
     @Test
-    public void testTwoNull() {
+    void testTwoNull() {
         IDifference result = DoubleDifference.construct("Foo", null, null);
-        Assert.assertNull(result);
+        Assertions.assertNull(result);
     }
 
     @Test
-    public void testOneNull() {
+    void testOneNull() {
         IDifference result = DoubleDifference.construct("Foo", null, 1.0);
-        Assert.assertNotNull(result);
+        Assertions.assertNotNull(result);
 
         result = DoubleDifference.construct("Foo", 3.0, null);
-        Assert.assertNotNull(result);
+        Assertions.assertNotNull(result);
     }
 
     @Test
-    public void testToString() {
+    void testToString() {
         IDifference result = DoubleDifference.construct("Foo", 1.0, 2.0);
         String diffString = result.toString();
-        Assert.assertNotNull(diffString);
+        Assertions.assertNotNull(diffString);
         StringDifferenceTest.assertOneLiner(diffString);
     }
 }
