@@ -18,8 +18,8 @@
  */
 package org.openscience.cdk.reaction;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.interfaces.IChemObjectBuilder;
 import org.openscience.cdk.interfaces.IReaction;
@@ -31,14 +31,14 @@ import org.openscience.cdk.silent.SilentChemObjectBuilder;
  *
  * @cdk.module test-extra
  */
-public class ReactionChainTest extends CDKTestCase {
+class ReactionChainTest extends CDKTestCase {
 
     private final static IChemObjectBuilder builder = SilentChemObjectBuilder.getInstance();
 
     /**
      *  Constructor for the ReactionEngineTest object.
      */
-    public ReactionChainTest() {
+    ReactionChainTest() {
         super();
     }
 
@@ -48,9 +48,9 @@ public class ReactionChainTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testReactionChain() {
+    void testReactionChain() {
         IReactionSet chain = new ReactionChain();
-        Assert.assertNotNull(chain);
+        Assertions.assertNotNull(chain);
     }
 
     /**
@@ -59,7 +59,7 @@ public class ReactionChainTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testAddReaction_IReaction_int() {
+    void testAddReaction_IReaction_int() {
         ReactionChain chain = new ReactionChain();
         IReaction reaction1 = builder.newInstance(IReaction.class);
         reaction1.setID("reaction1");
@@ -71,7 +71,7 @@ public class ReactionChainTest extends CDKTestCase {
         chain.addReaction(reaction2, 1);
         chain.addReaction(reaction3, 2);
 
-        Assert.assertNotNull(chain);
+        Assertions.assertNotNull(chain);
 
     }
 
@@ -81,7 +81,7 @@ public class ReactionChainTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testGetReactionStep_IReaction() {
+    void testGetReactionStep_IReaction() {
         ReactionChain chain = new ReactionChain();
         IReaction reaction1 = builder.newInstance(IReaction.class);
         reaction1.setID("reaction1");
@@ -94,7 +94,7 @@ public class ReactionChainTest extends CDKTestCase {
         chain.addReaction(reaction2, 1);
         chain.addReaction(reaction3, 2);
 
-        Assert.assertEquals(1, chain.getReactionStep(reaction2));
+        Assertions.assertEquals(1, chain.getReactionStep(reaction2));
     }
 
     /**
@@ -103,7 +103,7 @@ public class ReactionChainTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testGetReaction_int() {
+    void testGetReaction_int() {
         ReactionChain chain = new ReactionChain();
         IReaction reaction1 = builder.newInstance(IReaction.class);
         reaction1.setID("reaction1");
@@ -116,7 +116,7 @@ public class ReactionChainTest extends CDKTestCase {
         chain.addReaction(reaction2, 1);
         chain.addReaction(reaction3, 2);
 
-        Assert.assertEquals(reaction2, chain.getReaction(1));
+        Assertions.assertEquals(reaction2, chain.getReaction(1));
 
     }
 }
