@@ -23,6 +23,7 @@
 
 package org.openscience.cdk.io;
 
+import org.openscience.cdk.BondRef;
 import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.config.Elements;
 import org.openscience.cdk.exception.CDKException;
@@ -36,12 +37,18 @@ import org.openscience.cdk.interfaces.ITetrahedralChirality;
 import org.openscience.cdk.interfaces.ITetrahedralChirality.Stereo;
 import org.openscience.cdk.io.formats.IResourceFormat;
 import org.openscience.cdk.io.formats.MDLV3000Format;
+import org.openscience.cdk.io.setting.BooleanIOSetting;
 import org.openscience.cdk.io.setting.IOSetting;
 import org.openscience.cdk.io.setting.StringIOSetting;
+import org.openscience.cdk.isomorphism.matchers.Expr;
+import org.openscience.cdk.isomorphism.matchers.IQueryBond;
+import org.openscience.cdk.isomorphism.matchers.QueryBond;
 import org.openscience.cdk.sgroup.Sgroup;
 import org.openscience.cdk.sgroup.SgroupBracket;
 import org.openscience.cdk.sgroup.SgroupKey;
 import org.openscience.cdk.sgroup.SgroupType;
+import org.openscience.cdk.tools.ILoggingTool;
+import org.openscience.cdk.tools.LoggingToolFactory;
 
 import javax.vecmath.Point2d;
 import javax.vecmath.Point3d;
@@ -55,42 +62,99 @@ import java.nio.charset.StandardCharsets;
 import java.text.DecimalFormat;
 import java.text.DecimalFormatSymbols;
 import java.text.SimpleDateFormat;
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.Collections;
-import java.util.Comparator;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Locale;
-import java.util.Map;
-import java.util.Set;
-import java.util.TreeMap;
+import java.util.*;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
+import java.util.stream.IntStream;
+import java.util.stream.StreamSupport;
 
 import static org.openscience.cdk.CDKConstants.ATOM_ATOM_MAPPING;
 import static org.openscience.cdk.io.MDLV2000Writer.OptProgramName;
+import static org.openscience.cdk.io.MDLV2000Writer.OptTruncateLongData;
+import static org.openscience.cdk.io.MDLV2000Writer.OptWriteData;
 
 /**
  * Ctab V3000 format output. This writer provides output to the more modern (but less widely
  * supported) V3000 format. Unlikely the V2000 format that is limited to 999 atoms or bonds
  * V3000 can write arbitrarily large molecules. Beyond this the format removes some (but not all)
  * ambiguities and simplifies output values with tagging (e.g 'CHG=-1' instead of '5').
- * 
+ * <br><br>
  * Supported Features:
  * <ul>
  *     <li>Atom Block, non-query features</li>
- *     <li>Bond Block, non-query features</li>
+ *     <li>Bond Block, supported are query bond types 4 aromatic, 5 single or double, 6 single or aromatic,
+ *     7 double or aromatic, and 8 any as well as the query property that indicates whether a bond is
+ *     located in a ring or in a chain</li>
  *     <li>Sgroup Block, partial support for all chemical Sgroups, complete support for: Abbreviations,
  *     MultipleGroup, SRUs, (Un)ordered Mixtures</li>
  * </ul>
  * The 3D block and enhanced stereochemistry is not currently supported.
  */
 public final class MDLV3000Writer extends DefaultChemObjectWriter {
+    private static final ILoggingTool logger = LoggingToolFactory.createLoggingTool(MDLV3000Reader.class);
 
-    private static final Pattern         R_GRP_NUM = Pattern.compile("R(\\d+)");
-    private              V30LineWriter   writer;
-    private              StringIOSetting programNameOpt;
+    /**
+     * Enum representing the different types of bonds in MDL format.
+     */
+    enum MDLBondType {
+        SINGLE(1),
+        DOUBLE(2),
+        TRIPLE(3),
+        AROMATIC(4),
+        SINGLE_OR_DOUBLE(5),
+        SINGLE_OR_AROMATIC(6),
+        DOUBLE_OR_AROMATIC(7),
+        ANY(8),
+        COORDINATION(9), // not supported at this time
+        HYDROGEN(10);    // not supported at this time
+
+        private final int value;
+
+        MDLBondType(int value) {
+            this.value = value;
+        }
+
+        int getValue() {
+            return this.value;
+        }
+    }
+
+    /**
+     * Enum representing MDL query property values.
+     */
+    enum MDLQueryProperty {
+        NOT_SPECIFIED(0), // default value, not written if matched
+        RING(1),
+        CHAIN(2);
+
+        private final int value;
+
+        MDLQueryProperty(int value) {
+            this.value = value;
+        }
+
+        /**
+         * Returns the default value for MDLQueryProperty.
+         *
+         * @return the default value for MDLQueryProperty
+         */
+        static MDLQueryProperty getDefaultValue() {
+            return NOT_SPECIFIED;
+        }
+
+        int getValue() {
+            return this.value;
+        }
+    }
+
+    private static final Pattern R_GRP_NUM = Pattern.compile("R(\\d+)");
+    // The explicit valence of an atom is set to this value if connected to a query bond.
+    private static final int ATOM_PART_OF_QUERY_BOND_EXPLICIT_VALENCE = -38271;
+    private V30LineWriter writer;
+    private StringIOSetting programNameOpt;
+    private BooleanIOSetting writeDataOpt;
+    private BooleanIOSetting truncateDataOpt;
+    private Set<String> acceptedSdTags;
 
     /**
      * Create a new V3000 writer, output to the provided JDK writer.
@@ -119,8 +183,12 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
         initIOSettings();
     }
 
+    void setAcceptedSdTags(Set<String> acceptedSdTags) {
+        this.acceptedSdTags = acceptedSdTags;
+    }
+
     /**
-     * Safely access nullable int fields by defaulting to zero.
+     * Safely access nullable Integer fields by defaulting to zero.
      *
      * @param x value
      * @return value, or zero if null
@@ -138,12 +206,21 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
      * @return index or -1 if not found
      */
     private static <T> Integer findIdx(Map<T, Integer> idxs, T obj) {
-        Integer idx = idxs.get(obj);
+        final Integer idx = idxs.get(obj);
         if (idx == null)
             return -1;
         return idx;
     }
 
+    /**
+     * Retrieves the program name string with an exact length of 8 characters.
+     * <p>
+     * If the program name is not set, it returns a string with 8 spaces.
+     * If the program name is set and longer than 8 characters, it returns the first 8 characters of the name.
+     * If the program name is shorter than 8 characters, it returns the name padded with spaces to a length of 8 characters.
+     * </p>
+     * @return the program name for the writer
+     */
     private String getProgName() {
         String progname = programNameOpt.getSetting();
         if (progname == null)
@@ -187,7 +264,7 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
         }
         writer.writeDirect('\n');
 
-        String comment = mol.getProperty(CDKConstants.REMARK);
+        final String comment = mol.getProperty(CDKConstants.REMARK);
         if (comment != null)
             writer.writeDirect(comment.substring(0, Math.min(80, comment.length())));
         writer.writeDirect('\n');
@@ -204,9 +281,13 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
      * @return winding to write to molfile
      */
     private static Stereo getLocalParity(Map<IChemObject, Integer> idxs, ITetrahedralChirality stereo) {
-        IAtom[] neighbours   = stereo.getLigands();
-        int[]   neighbourIdx = new int[neighbours.length];
-        assert neighbours.length == 4;
+        final IAtom[] neighbours = stereo.getLigands();
+        final int[] neighbourIdx = new int[neighbours.length];
+
+        if (neighbours.length != 4) {
+            throw new AssertionError("The number of neighbours must be 4 but is " + neighbours.length + ".");
+        }
+
         for (int i = 0; i < 4; i++) {
             // impl H is last
             if (stereo.getChiralAtom().equals(neighbours[i])) {
@@ -247,6 +328,7 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
                                 Map<IAtom, ITetrahedralChirality> atomToStereo) throws IOException, CDKException {
         if (mol.getAtomCount() == 0)
             return;
+
         final int dim = getNumberOfDimensions(mol);
         writer.write("BEGIN ATOM\n");
         int atomIdx = 0;
@@ -272,13 +354,18 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
 
             int expVal = 0;
             for (IBond bond : mol.getConnectedBondsList(atom)) {
-                if (bond.getOrder() == null)
+                // If atom is part of a query bond we cannot calculate its explicit valence.
+                // The value ATOM_PART_OF_QUERY_BOND_EXPLICIT_VALENCE assigned to its explicit
+                // valence allows for easy identification of such atoms in the code below.
+                if (bond instanceof IQueryBond) {
+                    expVal = ATOM_PART_OF_QUERY_BOND_EXPLICIT_VALENCE;
+                    break;
+                } else if (bond.getOrder() == null)
                     throw new CDKException("Unsupported bond order: " + bond.getOrder());
                 expVal += bond.getOrder().numeric();
             }
 
             String symbol = getSymbol(atom, elem);
-
             int rnum = -1;
             if (symbol.charAt(0) == 'R') {
                 Matcher matcher = R_GRP_NUM.matcher(symbol);
@@ -288,8 +375,6 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
                 }
             }
 
-
-
             writer.write(++atomIdx)
                   .write(' ')
                   .write(symbol)
@@ -332,8 +417,10 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
                 writer.write(" RGROUPS=(1 ").write(rnum).write(")");
 
 
-            // determine if we need to write the valence
-            if (MDLValence.implicitValence(elem, chg, expVal) - expVal != hcnt) {
+            // Determine if we need to write the valence.
+            // Valence is not written if atom is part of a query bond.
+            if (expVal != ATOM_PART_OF_QUERY_BOND_EXPLICIT_VALENCE &&
+                    MDLValence.implicitValence(elem, chg, expVal) - expVal != hcnt) {
                 int val = expVal + hcnt;
                 if (val <= 0 || val > 14)
                     val = -1; // -1 is 0
@@ -360,7 +447,7 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
     }
 
     /**
-     * Access the atom symbol to write.
+     * Return atom symbol to write.
      *
      * @param atom atom
      * @param elem atomic number
@@ -393,8 +480,8 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
             return;
 
         // collect multicenter Sgroups before output
-        List<Sgroup> sgroups = mol.getProperty(CDKConstants.CTAB_SGROUPS);
-        Map<IBond,Sgroup> multicenterSgroups = new HashMap<>();
+        final List<Sgroup> sgroups = mol.getProperty(CDKConstants.CTAB_SGROUPS);
+        final Map<IBond,Sgroup> multicenterSgroups = new HashMap<>();
         if (sgroups != null) {
             for (Sgroup sgroup : sgroups) {
                 if (sgroup.getType() != SgroupType.ExtMulticenter)
@@ -407,17 +494,16 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
         writer.write("BEGIN BOND\n");
         int bondIdx = 0;
         for (IBond bond : mol.bonds()) {
-            IAtom beg = bond.getBegin();
-            IAtom end = bond.getEnd();
+            final IAtom beg = bond.getBegin();
+            final IAtom end = bond.getEnd();
             if (beg == null || end == null)
                 throw new IllegalStateException("Bond " + bondIdx + " had one or more atoms.");
             int begIdx = findIdx(idxs, beg);
             int endIdx = findIdx(idxs, end);
             if (begIdx < 0 || endIdx < 0)
-                throw new IllegalStateException("Bond " + bondIdx + " had atoms not present in the molecule.");
-
-            IBond.Stereo stereo = bond.getStereo();
+                throw new IllegalStateException("Bond " + bondIdx + " has atoms not present in the molecule.");
 
+            final IBond.Stereo stereo = bond.getStereo();
             // swap beg/end if needed
             if (stereo == IBond.Stereo.UP_INVERTED ||
                 stereo == IBond.Stereo.DOWN_INVERTED ||
@@ -427,14 +513,44 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
                 endIdx = tmp;
             }
 
-            final int order = bond.getOrder() == null ? 0 : bond.getOrder().numeric();
+            int order = bond.getOrder() == null ? 0 : bond.getOrder().numeric();
+            int bondType = -1; // initialize to satisfy compiler, this value is not expected to actually being written
+            MDLQueryProperty queryProperty = MDLQueryProperty.getDefaultValue();
 
-            if (order < 1 || order > 3)
+            // If bond is an object of type QueryBond its bond order is set to null, so the variable 'order' ends up being 0.
+            // Aromatic bonds have a (1) bond order of IBond.Order.UNSET (which also yields a value of 0 for 'order') and
+            // (2) the flag IChemObject.AROMATIC set to true.
+            if (order == 0) {
+                if (bond.getOrder() == IBond.Order.UNSET) {
+                    if (bond.getFlag(IChemObject.AROMATIC)) {
+                        bondType = 4;
+                    } else {
+                        throw new CDKException("Bond with bond order " + bond.getOrder() + " that isn't flagged as aromatic cannot be written to V3000");
+                    }
+                } else if (bond instanceof IQueryBond) {
+                    // Bond needs to be dereferenced to assess actual implementing class of bond.
+                    final IQueryBond dereferencedBond = (IQueryBond) BondRef.deref(bond);
+                    // Only query bonds of the class QueryBond are supported as the actual query expression needs to be
+                    // extracted from the bond.
+                    if (!(dereferencedBond instanceof QueryBond)) {
+                        throw new CDKException("Query bond of type " + dereferencedBond.getClass() + " cannot be written to V3000");
+                    }
+
+                    final Expr expression = ((QueryBond) dereferencedBond).getExpression();
+                    final ExpressionConverter converter = new ExpressionConverter(expression);
+                    // Might throw a CDKException if expression cannot be meaningfully converted to MDL bond type.
+                    bondType = converter.toMDLBondType().getValue();
+                    queryProperty = converter.toMDLQueryProperty();
+                }
+            } else if (order > 0 && order <= 3) {
+                bondType = order;
+            } else {
                 throw new CDKException("Bond order " + bond.getOrder() + " cannot be written to V3000");
+            }
 
             writer.write(++bondIdx)
                   .write(' ')
-                  .write(order)
+                  .write(bondType)
                   .write(' ')
                   .write(begIdx)
                   .write(' ')
@@ -461,9 +577,13 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
                     break;
             }
 
-            Sgroup sgroup = multicenterSgroups.get(bond);
+            if (queryProperty != MDLQueryProperty.getDefaultValue()) {
+                writer.write(" TOPO=").write(queryProperty.getValue());
+            }
+
+            final Sgroup sgroup = multicenterSgroups.get(bond);
             if (sgroup != null) {
-                List<IAtom> atoms = new ArrayList<>(sgroup.getAtoms());
+                final List<IAtom> atoms = new ArrayList<>(sgroup.getAtoms());
                 atoms.remove(bond.getBegin());
                 atoms.remove(bond.getEnd());
                 writer.write(" ATTACH=ANY ENDPTS=(").write(atoms, idxs).write(')');
@@ -474,7 +594,6 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
         writer.write("END BOND\n");
     }
 
-
     /**
      * CTfile specification is ambiguous as to how parity values should be written
      * for implicit hydrogens. Old applications (Symyx Draw) seem to push any
@@ -483,33 +602,40 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
      * 
      * To avoid the ambiguity for those who read 0D stereo (bad anyways) we
      * actually do push all hydrogens atoms to the back of the atom list giving
-     * them highest value (4) when writing parity values.
+     * them the highest value (4) when writing parity values.
      *
      * @param mol       molecule
      * @param atomToIdx mapping that will be filled with the output index
      * @return the output order of atoms
      */
     private IAtom[] pushHydrogensToBack(IAtomContainer mol, Map<IChemObject, Integer> atomToIdx) {
-        assert atomToIdx.isEmpty();
-        IAtom[] atoms = new IAtom[mol.getAtomCount()];
-        for (IAtom atom : mol.atoms()) {
-            if (atom.getAtomicNumber() == 1)
-                continue;
-            atoms[atomToIdx.size()] = atom;
-            atomToIdx.put(atom, atomToIdx.size() + 1);
-        }
-        for (IAtom atom : mol.atoms()) {
-            if (atom.getAtomicNumber() != 1)
-                continue;
-            atoms[atomToIdx.size()] = atom;
-            atomToIdx.put(atom, atomToIdx.size() + 1);
+        if (!atomToIdx.isEmpty())
+            throw new AssertionError("Map atomToIdx must be empty.");
+
+        final IAtom[] atoms = new IAtom[mol.getAtomCount()];
+        final int numberOfHydrogenAtoms = (int) StreamSupport.stream(mol.atoms().spliterator(), true)
+                .filter(atom -> atom.getAtomicNumber() == 1)
+                .count();
+        int nonHydrogenIndex = 0;
+        int hydrogenIndex = mol.getAtomCount() - numberOfHydrogenAtoms;
+
+        for (final IAtom atom : mol.atoms()) {
+            if (atom.getAtomicNumber() == 1) {
+                atoms[hydrogenIndex++] = atom;
+            } else {
+                atoms[nonHydrogenIndex++] = atom;
+            }
         }
+
+        // Put all atoms together with their MDL indices (1-based) into map.
+        IntStream.range(0, atoms.length).forEachOrdered(index -> atomToIdx.put(atoms[index], index + 1));
+
         return atoms;
     }
 
     /**
      * Safely access the Sgroups of a molecule retuning an empty list
-     * if none are defined..
+     * if none are defined.
      *
      * @param mol molecule
      * @return the sgroups
@@ -521,6 +647,12 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
         return sgroups;
     }
 
+    /**
+     * Returns the number of dimensions (2D or 3D) of a given molecule.
+     *
+     * @param mol the molecule to determine the number of dimensions for
+     * @return the number of dimensions of the molecule (0 for no dimensions, 2 for 2D, 3 for 3D)
+     */
     private int getNumberOfDimensions(IAtomContainer mol) {
         for (IAtom atom : mol.atoms()) {
             if (atom.getPoint3d() != null)
@@ -539,15 +671,14 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
      * @throws IOException low-level IO error
      * @throws CDKException unsupported format feature or invalid state
      */
-    private void writeSgroupBlock(List<Sgroup> sgroups, Map<IChemObject, Integer> idxs) throws IOException, CDKException {
-
+    private void writeSgroupBlock(final List<Sgroup> sgroups, Map<IChemObject, Integer> idxs) throws IOException, CDKException {
         // going to reorder but keep the originals untouched
-        sgroups = new ArrayList<>(sgroups);
+        List<Sgroup> copyOfSgroups = new ArrayList<>(sgroups);
 
         // remove non-ctab Sgroups
-        sgroups.removeIf(sgroup -> !sgroup.getType().isCtabStandard());
+        copyOfSgroups.removeIf(sgroup -> !sgroup.getType().isCtabStandard());
 
-        if (sgroups.isEmpty())
+        if (copyOfSgroups.isEmpty())
             return;
 
         writer.write("BEGIN SGROUP\n");
@@ -556,24 +687,21 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
         // first, this sort is good for three levels of nesting. Not perfect
         // but really tools should be able to handle output of order parents
         // when reading (we do).
-        sgroups.sort(new Comparator<Sgroup>() {
-            @Override
-            public int compare(Sgroup o1, Sgroup o2) {
-                // empty parents come first
-                int cmp = -Boolean.compare(o1.getParents().isEmpty(), o2.getParents().isEmpty());
-                if (cmp != 0 || o1.getParents().isEmpty()) return cmp;
-                // non-empty parents, if one contains the other we have an ordering
-                if (o1.getParents().contains(o2))
-                    return +1;
-                else if (o2.getParents().contains(o1))
-                    return -1;
-                else
-                    return 0;
-            }
+        copyOfSgroups.sort((o1, o2) -> {
+            // empty parents come first
+            int cmp = -Boolean.compare(o1.getParents().isEmpty(), o2.getParents().isEmpty());
+            if (cmp != 0 || o1.getParents().isEmpty()) return cmp;
+            // non-empty parents, if one contains the other we have an ordering
+            if (o1.getParents().contains(o2))
+                return +1;
+            else if (o2.getParents().contains(o1))
+                return -1;
+            else
+                return 0;
         });
 
         int sgroupIdx = 0;
-        for (Sgroup sgroup : sgroups) {
+        for (Sgroup sgroup : copyOfSgroups) {
             final SgroupType type = sgroup.getType();
             writer.write(++sgroupIdx).write(' ').write(type.getKey()).write(" 0");
 
@@ -597,7 +725,7 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
                 Set<Sgroup> parents = sgroup.getParents();
                 if (parents.size() > 1)
                     throw new CDKException("Cannot write Sgroup with multiple parents");
-                writer.write(" PARENT=").write(1+sgroups.indexOf(parents.iterator().next()));
+                writer.write(" PARENT=").write(1+copyOfSgroups.indexOf(parents.iterator().next()));
             }
 
             for (SgroupKey key : sgroup.getAttributeKeys()) {
@@ -666,14 +794,14 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
     private void writeMol(IAtomContainer mol) throws IOException, CDKException {
         writeHeader(mol);
 
-        List<Sgroup> sgroups = getSgroups(mol);
+        final List<Sgroup> sgroups = getSgroups(mol);
 
         int numSgroups = 0;
         for (Sgroup sgroup : sgroups)
             if (sgroup.getType().isCtabStandard())
                 numSgroups++;
 
-        int chiralFlag = getChiralFlag(mol.stereoElements());
+        final int chiralFlag = getChiralFlag(mol.stereoElements());
 
         writer.write("BEGIN CTAB\n");
         writer.write("COUNTS ")
@@ -687,12 +815,12 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
               .write("\n");
 
         // fast lookup atom indexes, MDL indexing starts at 1
-        Map<IChemObject, Integer> idxs = new HashMap<>();
-        Map<IAtom, ITetrahedralChirality> atomToStereo = new HashMap<>();
+        final Map<IChemObject, Integer> idxs = new HashMap<>();
+        final Map<IAtom, ITetrahedralChirality> atomToStereo = new HashMap<>();
 
         // work around specification ambiguities but reordering atom output
         // order, we also insert the index into a map for lookup
-        IAtom[] atoms = pushHydrogensToBack(mol, idxs);
+        final IAtom[] atoms = pushHydrogensToBack(mol, idxs);
 
         // bonds are in molecule order
         for (IBond bond : mol.bonds())
@@ -712,12 +840,20 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
 
         writer.write("END CTAB\n");
         writer.writeDirect("M  END\n");
+        // write non-structural data (mol properties in our case)
+        if (writeDataOpt.isSet()) {
+            MDLV2000Writer.writeNonStructuralData(writer.writer,
+                                                  mol,
+                                                  MDLV2000Writer.SD_TAGS_TO_IGNORE,
+                                                  acceptedSdTags,
+                                                  truncateDataOpt.isSet());
+        }
         writer.writer.flush();
     }
 
     private void writeEnhancedStereo(IAtomContainer mol, Map<IChemObject, Integer> idxs) throws IOException {
         // group together
-        Map<Integer,List<IAtom>> groups = new TreeMap<>();
+        final Map<Integer,List<IAtom>> groups = new TreeMap<>();
         for (IStereoElement<?,?> se : mol.stereoElements()) {
             if (se.getConfigClass() == IStereoElement.TH) {
                groups.computeIfAbsent(se.getGroupInfo(), e -> new ArrayList<>())
@@ -728,8 +864,8 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
         int numRel = 0;
         int numRac = 0;
         for (Map.Entry<Integer,List<IAtom>> e : groups.entrySet()) {
-            int grpInfo = e.getKey();
-            List<IAtom> atoms = e.getValue();
+            final int grpInfo = e.getKey();
+            final List<IAtom> atoms = e.getValue();
             writer.write("MDLV30/STE");
             switch (grpInfo & IStereoElement.GRP_TYPE_MASK) {
                 case IStereoElement.GRP_ABS:
@@ -766,7 +902,7 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
     @Override
     public void write(IChemObject object) throws CDKException {
         try {
-            if (IAtomContainer.class.isInstance(object))
+            if (object instanceof IAtomContainer)
                 writeMol((IAtomContainer) object);
             else
                 throw new CDKException("Unsupported ChemObject " + object.getClass());
@@ -817,7 +953,7 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
     }
 
     /**
-     * A convenience function for writing V3000 lines that auto
+     * A convenience class for writing V3000 lines that auto
      * wrap when >80 characters. We actually wrap at 78 since
      * the '-\n' takes the final two. We normally only need to wrap
      * for Sgroups but all lines are handled.
@@ -825,18 +961,18 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
     private static final class V30LineWriter implements Closeable {
         // note: non-static
         private final DecimalFormat decimalFmt = new DecimalFormat("#.#####", DecimalFormatSymbols.getInstance(Locale.ROOT));
-        public static final String  PREFIX     = "M  V30 ";
-        public static final int     LIMIT      = 78; // -\n takes two chars (80 total)
+        private static final String PREFIX = "M  V30 ";
+        private static final int LIMIT = 78; // '-\n' takes last two chars (80 total)
 
         // the base writer instance
-        private final Writer writer;
+        private final BufferedWriter writer;
 
         // tracks the current line length
         private int currLength = 0;
 
-        public V30LineWriter(Writer writer) {
+        V30LineWriter(Writer writer) {
             if (writer instanceof BufferedWriter) {
-                this.writer = writer;
+                this.writer = (BufferedWriter)writer;
             } else {
                 this.writer = new BufferedWriter(writer);
             }
@@ -987,15 +1123,19 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
     }
 
     /**
-     * Initializes IO settings.<br>
-     * Please note with regards to "writeAromaticBondTypes": bond type values 4 through 8 are for SSS queries only,
-     * so a 'query file' is created if the container has aromatic bonds and this settings is true.
+     * Initializes IO settings.
      */
     private void initIOSettings() {
         programNameOpt = addSetting(new StringIOSetting(OptProgramName,
                                                         IOSetting.Importance.LOW,
                                                         "Program name to write at the top of the molfile header, should be exactly 8 characters long",
                                                         "CDK"));
+        writeDataOpt = addSetting(new BooleanIOSetting(OptWriteData,
+                                                       IOSetting.Importance.LOW,
+                                                       "Should molecule properties be written as non-structural data", "false"));
+        truncateDataOpt = addSetting(new BooleanIOSetting(OptTruncateLongData,
+                                                          IOSetting.Importance.LOW,
+                                                          "Truncate long data files >200 characters", "false"));
     }
 
     public void customizeJob() {
@@ -1011,8 +1151,8 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
      * @return the chiral status, 0=not chiral, 1=chiral (all abs), 2=enhanced
      */
     static int getChiralFlag(Iterable<? extends IStereoElement> stereo) {
-        boolean init     = false;
-        int     grp      = 0;
+        boolean init = false;
+        int grp = 0;
         for (IStereoElement<?,?> se : stereo) {
             if (se.getConfigClass() == IStereoElement.TH) {
                 if (!init) {
@@ -1029,4 +1169,190 @@ public final class MDLV3000Writer extends DefaultChemObjectWriter {
             return 1;
         return 2;
     }
+
+    /**
+     * Responsible for converting bond {@link Expr expressions} to {@link MDLBondType MDL bond types}
+     * and {@link MDLQueryProperty MDL query properties}.
+     */
+    static final class ExpressionConverter {
+        
+        private static final int UNSPEC_SING  = 0x0001; // 1 << 0  ≅ 0b000000000000001
+        private static final int UNSPEC_DOUB  = 0x0002; // 1 << 1  ≅ 0b000000000000010
+        private static final int UNSPEC_TRIP  = 0x0004; // 1 << 2  ≅ 0b000000000000100
+        private static final int UNSPEC_QUAD  = 0x0008; // 1 << 3  ≅ 0b000000000001000
+        private static final int UNSPEC_AROM  = 0x0010; // 1 << 4  ≅ 0b000000000010000
+        private static final int CHAIN_SING   = 0x0020; // 1 << 5  ≅ 0b000000000100000
+        private static final int CHAIN_DOUB   = 0x0040; // 1 << 6  ≅ 0b000000001000000
+        private static final int CHAIN_TRIP   = 0x0080; // 1 << 7  ≅ 0b000000010000000
+        private static final int CHAIN_QUAD   = 0x0100; // 1 << 8  ≅ 0b000000100000000
+        private static final int CHAIN_AROM   = 0x0200; // 1 << 9  ≅ 0b000001000000000
+        private static final int RING_SING    = 0x0400; // 1 << 10 ≅ 0b000010000000000
+        private static final int RING_DOUB    = 0x0800; // 1 << 11 ≅ 0b000100000000000
+        private static final int RING_TRIP    = 0x1000; // 1 << 12 ≅ 0b001000000000000
+        private static final int RING_QUAD    = 0x2000; // 1 << 13 ≅ 0b010000000000000
+        private static final int RING_AROM    = 0x4000; // 1 << 14 ≅ 0b100000000000000
+
+        private static final int SINGLE_MASK        = 0x0421; // 0b000010000100001
+        private static final int DOUBLE_MASK        = 0x0842; // 0b000100001000010
+        private static final int TRIPLE_MASK        = 0x1084; // 0b001000010000100
+        private static final int QUADRUPLE_MASK     = 0x2108; // 0b010000100001000
+        private static final int UNSPECIFIED_MASK   = 0x001f; // 0b000000000011111
+        private static final int CHAIN_MASK         = 0x03e0; // 0b000001111100000
+        private static final int RING_MASK          = 0x7c00; // 0b111110000000000
+        private static final int AROMATIC_MASK      = 0x4210; // 0b100001000010000
+        private static final int ALIPHATIC_MASK     = 0x3def; // 0b011110111101111
+        private static final int ALL_MASK           = 0x7fff; // 0b111111111111111
+
+        private final Expr expression;
+        private final int bondCode;
+
+        /**
+         * Initializes an instance of the ExpressionConverter class.
+         *
+         * @param expression the expression to be converted
+         */
+        ExpressionConverter(final Expr expression) {
+            this.expression = expression;
+            this.bondCode = getBondCode(expression);
+        }
+
+        /**
+         * Converts the bond code to an {@link MDLBondType} enum.
+         *
+         * @return the MDLBondType enum representing the bond code
+         * @throws CDKException if the expression of the query bond cannot be written to V3000
+         */
+        MDLBondType toMDLBondType() throws CDKException {
+            if ((this.bondCode & ALL_MASK) == ALL_MASK)
+                return MDLBondType.ANY;
+            if ((this.bondCode & SINGLE_MASK) > 0) {
+                if ((this.bondCode & DOUBLE_MASK) > 0) {
+                    return MDLBondType.SINGLE_OR_DOUBLE;
+                }
+                if ((this.bondCode & AROMATIC_MASK) > 0) {
+                    return MDLBondType.SINGLE_OR_AROMATIC;
+                }
+                if ((this.bondCode & TRIPLE_MASK) == 0 && (this.bondCode & QUADRUPLE_MASK) == 0) {
+                    return MDLBondType.SINGLE;
+                }
+            }
+            if ((this.bondCode & DOUBLE_MASK) > 0) {
+                if ((this.bondCode & AROMATIC_MASK) > 0) {
+                    return MDLBondType.DOUBLE_OR_AROMATIC;
+                }
+                if (
+                        (this.bondCode & SINGLE_MASK) == 0 &&
+                        (this.bondCode & TRIPLE_MASK) == 0 &&
+                        (this.bondCode & QUADRUPLE_MASK) == 0
+                ) {
+                    return MDLBondType.DOUBLE;
+                }
+            }
+            if (
+                    (this.bondCode & TRIPLE_MASK) > 0 &&
+                    (this.bondCode & SINGLE_MASK) == 0 &&
+                    (this.bondCode & DOUBLE_MASK) == 0 &&
+                    (this.bondCode & QUADRUPLE_MASK) == 0
+            ) {
+                return MDLBondType.TRIPLE;
+            }
+            if (
+                    (this.bondCode & AROMATIC_MASK) > 0 &&
+                    (this.bondCode & SINGLE_MASK) == 0 &&
+                    (this.bondCode & DOUBLE_MASK) == 0 &&
+                    (this.bondCode & TRIPLE_MASK) == 0 &&
+                    (this.bondCode & QUADRUPLE_MASK) == 0
+            ) {
+                return MDLBondType.AROMATIC;
+            }
+
+            throw new CDKException("Query bond with expression " + this.expression + " cannot be written to V3000");
+        }
+
+        /**
+         * Converts this bondCode to an {@link MDLQueryProperty} enum.
+         *
+         * @return MDLQueryProperty enum representing the bondCode
+         */
+        MDLQueryProperty toMDLQueryProperty() {
+            if ((this.bondCode & UNSPECIFIED_MASK) > 0)
+                return MDLQueryProperty.NOT_SPECIFIED;
+            if ((this.bondCode & CHAIN_MASK) > 0)
+                return MDLQueryProperty.CHAIN;
+            if ((this.bondCode & RING_MASK) > 0)
+                return MDLQueryProperty.RING;
+
+            // This statement can be reached with e.g. and(IS_IN_RING, IS_IN_CHAIN).
+            return MDLQueryProperty.NOT_SPECIFIED;
+        }
+
+        /**
+         * Calculates a bond code based on the given expression.
+         * <br>
+         * This method is package-private instead of private on purpose to allow for testing.
+         *
+         * @param expression the expression to get a bond code for
+         * @return the calculated bond code
+         */
+        static int getBondCode(final Expr expression) {
+            switch (expression.type()) {
+                case NOT:
+                    return ~getBondCode(expression.left());
+                case OR:
+                    return getBondCode(expression.left()) | getBondCode(expression.right());
+                case AND:
+                    return getBondCode(expression.left()) & getBondCode(expression.right());
+                case TRUE:
+                case STEREOCHEMISTRY:
+                    return ALL_MASK;
+                case SINGLE_OR_AROMATIC:
+                    return SINGLE_MASK | AROMATIC_MASK;
+                case DOUBLE_OR_AROMATIC:
+                    return DOUBLE_MASK | AROMATIC_MASK;
+                case SINGLE_OR_DOUBLE:
+                    return SINGLE_MASK | DOUBLE_MASK;
+                case IS_AROMATIC:
+                    return AROMATIC_MASK;
+                case IS_ALIPHATIC:
+                    return ALIPHATIC_MASK;
+                case IS_IN_RING:
+                    return RING_MASK;
+                case IS_IN_CHAIN:
+                    return CHAIN_MASK;
+                case ORDER:
+                    switch (expression.value()) {
+                        case 1:
+                            return SINGLE_MASK;
+                        case 2:
+                            return DOUBLE_MASK;
+                        case 3:
+                            return TRIPLE_MASK;
+                        case 4:
+                            return QUADRUPLE_MASK;
+                        default:
+                            logger.warn("Unexpected bond order expression value: " + expression.value());
+                            return 0; // error
+                    }
+                case ALIPHATIC_ORDER:
+                    switch (expression.value()) {
+                        case 1:
+                            return SINGLE_MASK & ALIPHATIC_MASK;
+                        case 2:
+                            return DOUBLE_MASK & ALIPHATIC_MASK;
+                        case 3:
+                            return TRIPLE_MASK & ALIPHATIC_MASK;
+                        case 4:
+                            return QUADRUPLE_MASK & ALIPHATIC_MASK;
+                        default:
+                            logger.warn("Unexpected aliphatic bond order expression value: " + expression.value());
+                            return 0; // error
+                    }
+                case FALSE:
+                    return 0;
+                default:
+                    logger.warn("Unexpected expression: " + expression);
+                    return 0; // error
+            }
+        }
+    }
 }
