@@ -27,10 +27,10 @@ package org.openscience.cdk.io;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
 import org.mockito.Mockito;
-import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IBond;
+import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.interfaces.IChemObjectBuilder;
 import org.openscience.cdk.isomorphism.matchers.Expr;
 import org.openscience.cdk.isomorphism.matchers.QueryBond;
@@ -65,8 +65,8 @@ class MDLV2000BondBlockTest {
         IBond bond = reader.readBondFast(input, builder, atoms, new int[atoms.length], 1);
         assertThat(bond.getOrder(), is(IBond.Order.SINGLE));
         assertThat(bond.getStereo(), is(IBond.Stereo.NONE));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.ISAROMATIC));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.SINGLE_OR_DOUBLE));
+        Assertions.assertFalse(bond.getFlag(IChemObject.AROMATIC));
+        Assertions.assertFalse(bond.getFlag(IChemObject.SINGLE_OR_DOUBLE));
     }
 
     @Test
@@ -75,8 +75,8 @@ class MDLV2000BondBlockTest {
         IBond bond = reader.readBondFast(input, builder, atoms, new int[atoms.length], 1);
         assertThat(bond.getOrder(), is(IBond.Order.DOUBLE));
         assertThat(bond.getStereo(), is(IBond.Stereo.E_Z_BY_COORDINATES));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.ISAROMATIC));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.SINGLE_OR_DOUBLE));
+        Assertions.assertFalse(bond.getFlag(IChemObject.AROMATIC));
+        Assertions.assertFalse(bond.getFlag(IChemObject.SINGLE_OR_DOUBLE));
     }
 
     @Test
@@ -85,8 +85,8 @@ class MDLV2000BondBlockTest {
         IBond bond = reader.readBondFast(input, builder, atoms, new int[atoms.length], 1);
         assertThat(bond.getOrder(), is(IBond.Order.TRIPLE));
         assertThat(bond.getStereo(), is(IBond.Stereo.NONE));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.ISAROMATIC));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.SINGLE_OR_DOUBLE));
+        Assertions.assertFalse(bond.getFlag(IChemObject.AROMATIC));
+        Assertions.assertFalse(bond.getFlag(IChemObject.SINGLE_OR_DOUBLE));
     }
 
     @Test
@@ -94,8 +94,8 @@ class MDLV2000BondBlockTest {
         String input = "  1  3  4  0  0  0  0";
         IBond bond = reader.readBondFast(input, builder, atoms, new int[atoms.length], 1);
         assertThat(bond.getStereo(), is(IBond.Stereo.NONE));
-        Assertions.assertTrue(bond.getFlag(CDKConstants.ISAROMATIC));
-        Assertions.assertTrue(bond.getFlag(CDKConstants.SINGLE_OR_DOUBLE));
+        Assertions.assertTrue(bond.getFlag(IChemObject.AROMATIC));
+        Assertions.assertTrue(bond.getFlag(IChemObject.SINGLE_OR_DOUBLE));
     }
 
     @Test
@@ -103,8 +103,8 @@ class MDLV2000BondBlockTest {
         String input = "  1  3  5  0  0  0  0";
         IBond bond = reader.readBondFast(input, builder, atoms, new int[atoms.length], 1);
         assertThat(bond.getStereo(), is(IBond.Stereo.NONE));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.ISAROMATIC));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.SINGLE_OR_DOUBLE));
+        Assertions.assertFalse(bond.getFlag(IChemObject.AROMATIC));
+        Assertions.assertFalse(bond.getFlag(IChemObject.SINGLE_OR_DOUBLE));
         assertThat(bond, is(instanceOf(QueryBond.class)));
         assertThat(((QueryBond) bond).getExpression().type(), is(Expr.Type.SINGLE_OR_DOUBLE));
     }
@@ -114,8 +114,8 @@ class MDLV2000BondBlockTest {
         String input = "  1  3  6  0  0  0  0";
         IBond bond = reader.readBondFast(input, builder, atoms, new int[atoms.length], 1);
         assertThat(bond.getStereo(), is(IBond.Stereo.NONE));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.ISAROMATIC));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.SINGLE_OR_DOUBLE));
+        Assertions.assertFalse(bond.getFlag(IChemObject.AROMATIC));
+        Assertions.assertFalse(bond.getFlag(IChemObject.SINGLE_OR_DOUBLE));
         assertThat(bond, is(instanceOf(QueryBond.class)));
         assertThat(((QueryBond) bond).getExpression().type(), is(Expr.Type.SINGLE_OR_AROMATIC));
     }
@@ -125,8 +125,8 @@ class MDLV2000BondBlockTest {
         String input = "  1  3  7  0  0  0  0";
         IBond bond = reader.readBondFast(input, builder, atoms, new int[atoms.length], 1);
         assertThat(bond.getStereo(), is(IBond.Stereo.NONE));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.ISAROMATIC));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.SINGLE_OR_DOUBLE));
+        Assertions.assertFalse(bond.getFlag(IChemObject.AROMATIC));
+        Assertions.assertFalse(bond.getFlag(IChemObject.SINGLE_OR_DOUBLE));
         assertThat(bond, is(instanceOf(QueryBond.class)));
         assertThat(((QueryBond) bond).getExpression().type(), is(Expr.Type.DOUBLE_OR_AROMATIC));
     }
@@ -136,8 +136,8 @@ class MDLV2000BondBlockTest {
         String input = "  1  3  8  0  0  0  0";
         IBond bond = reader.readBondFast(input, builder, atoms, new int[atoms.length], 1);
         assertThat(bond.getStereo(), is(IBond.Stereo.NONE));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.ISAROMATIC));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.SINGLE_OR_DOUBLE));
+        Assertions.assertFalse(bond.getFlag(IChemObject.AROMATIC));
+        Assertions.assertFalse(bond.getFlag(IChemObject.SINGLE_OR_DOUBLE));
         assertThat(bond, is(instanceOf(QueryBond.class)));
         assertThat(((QueryBond) bond).getExpression().type(), is(Expr.Type.TRUE));
     }
@@ -230,8 +230,8 @@ class MDLV2000BondBlockTest {
         assertThat(bond.getEnd(), is(atoms[2]));
         assertThat(bond.getOrder(), is(IBond.Order.SINGLE));
         assertThat(bond.getStereo(), is(IBond.Stereo.NONE));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.ISAROMATIC));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.SINGLE_OR_DOUBLE));
+        Assertions.assertFalse(bond.getFlag(IChemObject.AROMATIC));
+        Assertions.assertFalse(bond.getFlag(IChemObject.SINGLE_OR_DOUBLE));
     }
 
     @Test
@@ -242,8 +242,8 @@ class MDLV2000BondBlockTest {
         assertThat(bond.getEnd(), is(atoms[2]));
         assertThat(bond.getOrder(), is(IBond.Order.SINGLE));
         assertThat(bond.getStereo(), is(IBond.Stereo.NONE));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.ISAROMATIC));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.SINGLE_OR_DOUBLE));
+        Assertions.assertFalse(bond.getFlag(IChemObject.AROMATIC));
+        Assertions.assertFalse(bond.getFlag(IChemObject.SINGLE_OR_DOUBLE));
     }
 
     @Test
@@ -254,8 +254,8 @@ class MDLV2000BondBlockTest {
         assertThat(bond.getEnd(), is(atoms[2]));
         assertThat(bond.getOrder(), is(IBond.Order.SINGLE));
         assertThat(bond.getStereo(), is(IBond.Stereo.NONE));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.ISAROMATIC));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.SINGLE_OR_DOUBLE));
+        Assertions.assertFalse(bond.getFlag(IChemObject.AROMATIC));
+        Assertions.assertFalse(bond.getFlag(IChemObject.SINGLE_OR_DOUBLE));
     }
 
     @Test
@@ -266,8 +266,8 @@ class MDLV2000BondBlockTest {
         assertThat(bond.getEnd(), is(atoms[2]));
         assertThat(bond.getOrder(), is(IBond.Order.SINGLE));
         assertThat(bond.getStereo(), is(IBond.Stereo.NONE));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.ISAROMATIC));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.SINGLE_OR_DOUBLE));
+        Assertions.assertFalse(bond.getFlag(IChemObject.AROMATIC));
+        Assertions.assertFalse(bond.getFlag(IChemObject.SINGLE_OR_DOUBLE));
     }
 
     @Test
@@ -278,7 +278,7 @@ class MDLV2000BondBlockTest {
         assertThat(bond.getEnd(), is(atoms[2]));
         assertThat(bond.getOrder(), is(IBond.Order.SINGLE));
         assertThat(bond.getStereo(), is(IBond.Stereo.NONE));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.ISAROMATIC));
-        Assertions.assertFalse(bond.getFlag(CDKConstants.SINGLE_OR_DOUBLE));
+        Assertions.assertFalse(bond.getFlag(IChemObject.AROMATIC));
+        Assertions.assertFalse(bond.getFlag(IChemObject.SINGLE_OR_DOUBLE));
     }
 }
