@@ -45,6 +45,7 @@ import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IBond.Order;
 import org.openscience.cdk.interfaces.IChemFile;
 import org.openscience.cdk.interfaces.IChemModel;
+import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.interfaces.IChemSequence;
 import org.openscience.cdk.interfaces.ICrystal;
 import org.openscience.cdk.interfaces.IMonomer;
@@ -700,6 +701,7 @@ public class CMLCoreModule implements ICMLModule {
 
         String cData = currentChars;
         if ("bond".equals(name)) {
+            if (bondCounter > order.size()) order.add(null);
             if (!stereoGiven) bondStereo.add("");
             if (bondCounter > bondDictRefs.size()) bondDictRefs.add(null);
             if (bondCounter > bondAromaticity.size()) bondAromaticity.add(null);
@@ -1437,7 +1439,7 @@ public class CMLCoreModule implements ICMLModule {
             }
 
             if (hasAtomAromaticities) {
-                if (atomAromaticities.get(i) != null) currentAtom.setFlag(CDKConstants.ISAROMATIC, true);
+                if (atomAromaticities.get(i) != null) currentAtom.setFlag(IChemObject.AROMATIC, true);
             }
 
             if (hasPartialCharge) {
@@ -1597,10 +1599,12 @@ public class CMLCoreModule implements ICMLModule {
                     } else if ("A".equals(bondOrder)) {
                         //                        cdo.setObjectProperty("Bond", "order", "1.5");
                         currentBond.setOrder(Order.SINGLE);
-                        currentBond.setFlag(CDKConstants.ISAROMATIC, true);
-                    } else {
+                        currentBond.setFlag(IChemObject.AROMATIC, true);
+                    } else if (bondOrder!=null){
                         //                        cdo.setObjectProperty("Bond", "order", bondOrder);
                         currentBond.setOrder(BondManipulator.createBondOrder(Double.parseDouble(bondOrder)));
+                    } else {
+                    	currentBond.setOrder(null);
                     }
                 }
 
@@ -1620,7 +1624,7 @@ public class CMLCoreModule implements ICMLModule {
                 if (aroms.hasNext()) {
                     Object nextArom = aroms.next();
                     if (nextArom != null && ((boolean) nextArom)) {
-                        currentBond.setFlag(CDKConstants.ISAROMATIC, true);
+                        currentBond.setFlag(IChemObject.AROMATIC, true);
                     }
                 }
 
