@@ -25,8 +25,8 @@ package org.openscience.cdk.io;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.io.ChemObjectIOTest;
 
 /**
@@ -34,20 +34,20 @@ import org.openscience.cdk.test.io.ChemObjectIOTest;
  *
  * @cdk.module test-io
  */
-public abstract class ChemObjectReaderTest extends org.openscience.cdk.test.io.ChemObjectIOTest {
+abstract class ChemObjectReaderTest extends org.openscience.cdk.test.io.ChemObjectIOTest {
 
-    protected static IChemObjectReader chemObjectIO;
-    protected static String            testFile;
+    private static IChemObjectReader chemObjectIO;
+    private static String            testFile;
 
-    public static void setChemObjectReader(IChemObjectReader aChemObjectReader, String testFile) {
+    static void setChemObjectReader(IChemObjectReader aChemObjectReader, String testFile) {
         ChemObjectIOTest.setChemObjectIO(aChemObjectReader);
         org.openscience.cdk.io.ChemObjectReaderTest.chemObjectIO = aChemObjectReader;
         org.openscience.cdk.io.ChemObjectReaderTest.testFile = testFile;
     }
 
     @Test
-    public void testSetReader_InputStream() throws Exception {
-        Assert.assertNotNull("No test file has been set!", testFile);
+    void testSetReader_InputStream() throws Exception {
+        Assertions.assertNotNull(testFile, "No test file has been set!");
         InputStream ins = org.openscience.cdk.test.io.ChemObjectReaderTest.class.getClassLoader().getResourceAsStream(testFile);
         if (ins == null)
             ins = chemObjectIO.getClass().getResourceAsStream(testFile);
@@ -55,8 +55,8 @@ public abstract class ChemObjectReaderTest extends org.openscience.cdk.test.io.C
     }
 
     @Test
-    public void testSetReader_Reader() throws Exception {
-        Assert.assertNotNull("No test file has been set!", testFile);
+    void testSetReader_Reader() throws Exception {
+        Assertions.assertNotNull(testFile, "No test file has been set!");
         InputStream ins = org.openscience.cdk.test.io.ChemObjectReaderTest.class.getClassLoader().getResourceAsStream(testFile);
         if (ins == null)
             ins = chemObjectIO.getClass().getResourceAsStream(testFile);
