@@ -24,8 +24,8 @@ package org.openscience.cdk.io.cml;
 
 import java.io.ByteArrayInputStream;
 
-import org.junit.Assert;
-import org.junit.Ignore;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Disabled;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
@@ -44,10 +44,10 @@ import org.openscience.cdk.silent.ChemFile;
  *
  * @author Egon Willighagen &lt;egonw@sci.kun.nl&gt;
  */
-public class CML25FragmentsTest extends CDKTestCase {
+class CML25FragmentsTest extends CDKTestCase {
 
-    @Ignore("Functionality not yet implemented")
-    public void testIsotopeRef() throws Exception {
+    @Disabled("Functionality not yet implemented")
+    void testIsotopeRef() throws Exception {
         String cmlString = "<cml>" + "  <isotopeList>" + "    <isotope id='H1' number='1' elementType='H'>"
                 + "      <scalar dictRef='bo:relativeAbundance'>99.9885</scalar>"
                 + "      <scalar dictRef='bo:exactMass' errorValue='0.0001E-6'>1.007825032</scalar>" + "    </isotope>"
@@ -58,19 +58,19 @@ public class CML25FragmentsTest extends CDKTestCase {
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(1, mol.getAtomCount());
+        Assertions.assertEquals(1, mol.getAtomCount());
         IAtom atom = mol.getAtom(0);
-        Assert.assertEquals("a1", atom.getID());
-        Assert.assertNotNull(atom.getNaturalAbundance());
-        Assert.assertEquals(99.9885, atom.getNaturalAbundance(), 0.0001);
-        Assert.assertNotNull(atom.getExactMass());
-        Assert.assertEquals(1.007825032, atom.getExactMass(), 0.0000001);
+        Assertions.assertEquals("a1", atom.getID());
+        Assertions.assertNotNull(atom.getNaturalAbundance());
+        Assertions.assertEquals(99.9885, atom.getNaturalAbundance(), 0.0001);
+        Assertions.assertNotNull(atom.getExactMass());
+        Assertions.assertEquals(1.007825032, atom.getExactMass(), 0.0000001);
     }
 
     private IChemFile parseCMLString(String cmlString) throws Exception {
-        IChemFile chemFile = null;
+        IChemFile chemFile;
         CMLReader reader = new CMLReader(new ByteArrayInputStream(cmlString.getBytes()));
-        chemFile = (IChemFile) reader.read(new ChemFile());
+        chemFile = reader.read(new ChemFile());
         reader.close();
         return chemFile;
     }
@@ -83,24 +83,24 @@ public class CML25FragmentsTest extends CDKTestCase {
     }
 
     private IAtomContainer checkForXMoleculeFile(IChemFile chemFile, int numberOfMolecules) {
-        Assert.assertNotNull(chemFile);
+        Assertions.assertNotNull(chemFile);
 
-        Assert.assertEquals(chemFile.getChemSequenceCount(), 1);
+        Assertions.assertEquals(chemFile.getChemSequenceCount(), 1);
         IChemSequence seq = chemFile.getChemSequence(0);
-        Assert.assertNotNull(seq);
+        Assertions.assertNotNull(seq);
 
-        Assert.assertEquals(seq.getChemModelCount(), 1);
+        Assertions.assertEquals(seq.getChemModelCount(), 1);
         IChemModel model = seq.getChemModel(0);
-        Assert.assertNotNull(model);
+        Assertions.assertNotNull(model);
 
         IAtomContainerSet moleculeSet = model.getMoleculeSet();
-        Assert.assertNotNull(moleculeSet);
+        Assertions.assertNotNull(moleculeSet);
 
-        Assert.assertEquals(moleculeSet.getAtomContainerCount(), numberOfMolecules);
+        Assertions.assertEquals(moleculeSet.getAtomContainerCount(), numberOfMolecules);
         IAtomContainer mol = null;
         for (int i = 0; i < numberOfMolecules; i++) {
             mol = moleculeSet.getAtomContainer(i);
-            Assert.assertNotNull(mol);
+            Assertions.assertNotNull(mol);
         }
         return mol;
     }
