@@ -28,7 +28,7 @@ import javax.vecmath.Vector3d;
 
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
-import org.openscience.cdk.CDKConstants;
+import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
@@ -146,7 +146,7 @@ class Jumbo46CMLFragmentsTest extends CDKTestCase {
         Assertions.assertEquals(1, mol.getBondCount());
         org.openscience.cdk.interfaces.IBond bond = mol.getBond(0);
         Assertions.assertEquals(Order.SINGLE, bond.getOrder());
-        Assertions.assertTrue(bond.getFlag(CDKConstants.ISAROMATIC));
+        Assertions.assertTrue(bond.getFlag(IChemObject.AROMATIC));
     }
 
     @Test
