@@ -25,9 +25,9 @@ package org.openscience.cdk.io.formats;
 /**
  * @cdk.module test-ioformats
  */
-public class ADFFormatTest extends ChemFormatMatcherTest {
+class ADFFormatTest extends ChemFormatMatcherTest {
 
-    public ADFFormatTest() {
+    ADFFormatTest() {
         super.setChemFormatMatcher((IChemFormatMatcher) ADFFormat.getInstance());
     }
 
