@@ -25,9 +25,9 @@ package org.openscience.cdk.io.formats;
 /**
  * @cdk.module test-ioformats
  */
-public class AlchemyFormatTest extends ChemFormatTest {
+class AlchemyFormatTest extends ChemFormatTest {
 
-    public AlchemyFormatTest() {
+    AlchemyFormatTest() {
         super.setChemFormat((IChemFormat) AlchemyFormat.getInstance());
     }
 
