@@ -25,9 +25,9 @@ package org.openscience.cdk.io.cml;
 import javax.vecmath.Point2d;
 import javax.vecmath.Point3d;
 
-import org.junit.Assert;
-import org.junit.Ignore;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
@@ -41,25 +41,25 @@ import org.openscience.cdk.tools.diff.AtomDiff;
 /**
  * @cdk.module test-libiocml
  */
-public class CDKRoundTripTest extends CDKTestCase {
+class CDKRoundTripTest extends CDKTestCase {
 
-    private static IChemObjectBuilder builder   = SilentChemObjectBuilder.getInstance();
+    private static final IChemObjectBuilder builder   = SilentChemObjectBuilder.getInstance();
 
-    private static Convertor          convertor = new Convertor(false, "");
+    private static final Convertor          convertor = new Convertor(false, "");
 
     @Test
-    public void testIElement_Symbol() throws Exception {
+    void testIElement_Symbol() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom atom = builder.newInstance(IAtom.class, "C");
         atom.setID("a1");
         mol.addAtom(atom);
         IAtomContainer copy = CMLRoundTripTool.roundTripMolecule(convertor, mol);
         String difference = AtomDiff.diff(atom, copy.getAtom(0));
-        Assert.assertEquals("Found non-zero diff: " + difference, 0, difference.length());
+        Assertions.assertEquals(0, difference.length(), "Found non-zero diff: " + difference);
     }
 
     @Test
-    public void testIElement_AtomicNumber() throws Exception {
+    void testIElement_AtomicNumber() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom atom = builder.newInstance(IAtom.class, "C");
         atom.setID("a1");
@@ -67,12 +67,12 @@ public class CDKRoundTripTest extends CDKTestCase {
         mol.addAtom(atom);
         IAtomContainer copy = CMLRoundTripTool.roundTripMolecule(convertor, mol);
         String difference = AtomDiff.diff(atom, copy.getAtom(0));
-        Assert.assertEquals("Found non-zero diff: " + difference, 0, difference.length());
+        Assertions.assertEquals(0, difference.length(), "Found non-zero diff: " + difference);
     }
 
-    @Ignore
+    @Disabled
     @Test
-    public void testIIsotope_NaturalAbundance() throws Exception {
+    void testIIsotope_NaturalAbundance() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom atom = builder.newInstance(IAtom.class, "C");
         atom.setID("a1");
@@ -80,12 +80,12 @@ public class CDKRoundTripTest extends CDKTestCase {
         mol.addAtom(atom);
         IAtomContainer copy = CMLRoundTripTool.roundTripMolecule(convertor, mol);
         String difference = AtomDiff.diff(atom, copy.getAtom(0));
-        Assert.assertEquals("Found non-zero diff: " + difference, 0, difference.length());
+        Assertions.assertEquals(0, difference.length(), "Found non-zero diff: " + difference);
     }
 
-    @Ignore("exact mass not currently supported in CML implmenetation")
+    @Disabled("exact mass not currently supported in CML implmenetation")
     @Test
-    public void testIIsotope_ExactMass() throws Exception {
+    void testIIsotope_ExactMass() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom atom = builder.newInstance(IAtom.class, "C");
         atom.setID("a1");
@@ -93,11 +93,11 @@ public class CDKRoundTripTest extends CDKTestCase {
         mol.addAtom(atom);
         IAtomContainer copy = CMLRoundTripTool.roundTripMolecule(convertor, mol);
         String difference = AtomDiff.diff(atom, copy.getAtom(0));
-        Assert.assertEquals("Found non-zero diff: " + difference, 0, difference.length());
+        Assertions.assertEquals(0, difference.length(), "Found non-zero diff: " + difference);
     }
 
     @Test
-    public void testIIsotope_MassNumber() throws Exception {
+    void testIIsotope_MassNumber() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom atom = builder.newInstance(IAtom.class, "C");
         atom.setID("a1");
@@ -105,12 +105,12 @@ public class CDKRoundTripTest extends CDKTestCase {
         mol.addAtom(atom);
         IAtomContainer copy = CMLRoundTripTool.roundTripMolecule(convertor, mol);
         String difference = AtomDiff.diff(atom, copy.getAtom(0));
-        Assert.assertEquals("Found non-zero diff: " + difference, 0, difference.length());
+        Assertions.assertEquals(0, difference.length(), "Found non-zero diff: " + difference);
     }
 
-    @Ignore
+    @Disabled
     @Test
-    public void testIAtomType_Name() throws Exception {
+    void testIAtomType_Name() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom atom = builder.newInstance(IAtom.class, "C");
         atom.setID("a1");
@@ -118,12 +118,12 @@ public class CDKRoundTripTest extends CDKTestCase {
         mol.addAtom(atom);
         IAtomContainer copy = CMLRoundTripTool.roundTripMolecule(convertor, mol);
         String difference = AtomDiff.diff(atom, copy.getAtom(0));
-        Assert.assertEquals("Found non-zero diff: " + difference, 0, difference.length());
+        Assertions.assertEquals(0, difference.length(), "Found non-zero diff: " + difference);
     }
 
-    @Ignore
+    @Disabled
     @Test
-    public void testIAtomType_MaxBondOrder() throws Exception {
+    void testIAtomType_MaxBondOrder() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom atom = builder.newInstance(IAtom.class, "C");
         atom.setID("a1");
@@ -131,12 +131,12 @@ public class CDKRoundTripTest extends CDKTestCase {
         mol.addAtom(atom);
         IAtomContainer copy = CMLRoundTripTool.roundTripMolecule(convertor, mol);
         String difference = AtomDiff.diff(atom, copy.getAtom(0));
-        Assert.assertEquals("Found non-zero diff: " + difference, 0, difference.length());
+        Assertions.assertEquals(0, difference.length(), "Found non-zero diff: " + difference);
     }
 
-    @Ignore
+    @Disabled
     @Test
-    public void testIAtomType_BondOrderSum() throws Exception {
+    void testIAtomType_BondOrderSum() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom atom = builder.newInstance(IAtom.class, "C");
         atom.setID("a1");
@@ -144,11 +144,11 @@ public class CDKRoundTripTest extends CDKTestCase {
         mol.addAtom(atom);
         IAtomContainer copy = CMLRoundTripTool.roundTripMolecule(convertor, mol);
         String difference = AtomDiff.diff(atom, copy.getAtom(0));
-        Assert.assertEquals("Found non-zero diff: " + difference, 0, difference.length());
+        Assertions.assertEquals(0, difference.length(), "Found non-zero diff: " + difference);
     }
 
     @Test
-    public void testIAtomType_FormalCharge() throws Exception {
+    void testIAtomType_FormalCharge() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom atom = builder.newInstance(IAtom.class, "C");
         atom.setID("a1");
@@ -156,12 +156,12 @@ public class CDKRoundTripTest extends CDKTestCase {
         mol.addAtom(atom);
         IAtomContainer copy = CMLRoundTripTool.roundTripMolecule(convertor, mol);
         String difference = AtomDiff.diff(atom, copy.getAtom(0));
-        Assert.assertEquals("Found non-zero diff: " + difference, 0, difference.length());
+        Assertions.assertEquals(0, difference.length(), "Found non-zero diff: " + difference);
     }
 
-    @Ignore
+    @Disabled
     @Test
-    public void testIAtomType_FormalNeighborCount() throws Exception {
+    void testIAtomType_FormalNeighborCount() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom atom = builder.newInstance(IAtom.class, "C");
         atom.setID("a1");
@@ -169,12 +169,12 @@ public class CDKRoundTripTest extends CDKTestCase {
         mol.addAtom(atom);
         IAtomContainer copy = CMLRoundTripTool.roundTripMolecule(convertor, mol);
         String difference = AtomDiff.diff(atom, copy.getAtom(0));
-        Assert.assertEquals("Found non-zero diff: " + difference, 0, difference.length());
+        Assertions.assertEquals(0, difference.length(), "Found non-zero diff: " + difference);
     }
 
-    @Ignore
+    @Disabled
     @Test
-    public void testIAtomType_Hybridization() throws Exception {
+    void testIAtomType_Hybridization() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom atom = builder.newInstance(IAtom.class, "C");
         atom.setID("a1");
@@ -182,12 +182,12 @@ public class CDKRoundTripTest extends CDKTestCase {
         mol.addAtom(atom);
         IAtomContainer copy = CMLRoundTripTool.roundTripMolecule(convertor, mol);
         String difference = AtomDiff.diff(atom, copy.getAtom(0));
-        Assert.assertEquals("Found non-zero diff: " + difference, 0, difference.length());
+        Assertions.assertEquals(0, difference.length(), "Found non-zero diff: " + difference);
     }
 
-    @Ignore
+    @Disabled
     @Test
-    public void testIAtomType_CovalentRadius() throws Exception {
+    void testIAtomType_CovalentRadius() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom atom = builder.newInstance(IAtom.class, "C");
         atom.setID("a1");
@@ -195,12 +195,12 @@ public class CDKRoundTripTest extends CDKTestCase {
         mol.addAtom(atom);
         IAtomContainer copy = CMLRoundTripTool.roundTripMolecule(convertor, mol);
         String difference = AtomDiff.diff(atom, copy.getAtom(0));
-        Assert.assertEquals("Found non-zero diff: " + difference, 0, difference.length());
+        Assertions.assertEquals(0, difference.length(), "Found non-zero diff: " + difference);
     }
 
-    @Ignore
+    @Disabled
     @Test
-    public void testIAtomType_Valency() throws Exception {
+    void testIAtomType_Valency() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom atom = builder.newInstance(IAtom.class, "C");
         atom.setID("a1");
@@ -208,11 +208,11 @@ public class CDKRoundTripTest extends CDKTestCase {
         mol.addAtom(atom);
         IAtomContainer copy = CMLRoundTripTool.roundTripMolecule(convertor, mol);
         String difference = AtomDiff.diff(atom, copy.getAtom(0));
-        Assert.assertEquals("Found non-zero diff: " + difference, 0, difference.length());
+        Assertions.assertEquals(0, difference.length(), "Found non-zero diff: " + difference);
     }
 
     @Test
-    public void testIAtom_Charge() throws Exception {
+    void testIAtom_Charge() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom atom = builder.newInstance(IAtom.class, "C");
         atom.setID("a1");
@@ -220,11 +220,11 @@ public class CDKRoundTripTest extends CDKTestCase {
         mol.addAtom(atom);
         IAtomContainer copy = CMLRoundTripTool.roundTripMolecule(convertor, mol);
         String difference = AtomDiff.diff(atom, copy.getAtom(0));
-        Assert.assertEquals("Found non-zero diff: " + difference, 0, difference.length());
+        Assertions.assertEquals(0, difference.length(), "Found non-zero diff: " + difference);
     }
 
     @Test
-    public void testIAtom_HydrogenCount() throws Exception {
+    void testIAtom_HydrogenCount() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom atom = builder.newInstance(IAtom.class, "C");
         atom.setID("a1");
@@ -232,11 +232,11 @@ public class CDKRoundTripTest extends CDKTestCase {
         mol.addAtom(atom);
         IAtomContainer copy = CMLRoundTripTool.roundTripMolecule(convertor, mol);
         String difference = AtomDiff.diff(atom, copy.getAtom(0));
-        Assert.assertEquals("Found non-zero diff: " + difference, 0, difference.length());
+        Assertions.assertEquals(0, difference.length(), "Found non-zero diff: " + difference);
     }
 
     @Test
-    public void testIAtom_Point2d() throws Exception {
+    void testIAtom_Point2d() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom atom = builder.newInstance(IAtom.class, "C");
         atom.setID("a1");
@@ -244,11 +244,11 @@ public class CDKRoundTripTest extends CDKTestCase {
         mol.addAtom(atom);
         IAtomContainer copy = CMLRoundTripTool.roundTripMolecule(convertor, mol);
         String difference = AtomDiff.diff(atom, copy.getAtom(0));
-        Assert.assertEquals("Found non-zero diff: " + difference, 0, difference.length());
+        Assertions.assertEquals(0, difference.length(), "Found non-zero diff: " + difference);
     }
 
     @Test
-    public void testIAtom_Point3d() throws Exception {
+    void testIAtom_Point3d() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom atom = builder.newInstance(IAtom.class, "C");
         atom.setID("a1");
@@ -256,11 +256,11 @@ public class CDKRoundTripTest extends CDKTestCase {
         mol.addAtom(atom);
         IAtomContainer copy = CMLRoundTripTool.roundTripMolecule(convertor, mol);
         String difference = AtomDiff.diff(atom, copy.getAtom(0));
-        Assert.assertEquals("Found non-zero diff: " + difference, 0, difference.length());
+        Assertions.assertEquals(0, difference.length(), "Found non-zero diff: " + difference);
     }
 
     @Test
-    public void testIAtom_FractionalPoint3d() throws Exception {
+    void testIAtom_FractionalPoint3d() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom atom = builder.newInstance(IAtom.class, "C");
         atom.setID("a1");
@@ -268,11 +268,11 @@ public class CDKRoundTripTest extends CDKTestCase {
         mol.addAtom(atom);
         IAtomContainer copy = CMLRoundTripTool.roundTripMolecule(convertor, mol);
         String difference = AtomDiff.diff(atom, copy.getAtom(0));
-        Assert.assertEquals("Found non-zero diff: " + difference, 0, difference.length());
+        Assertions.assertEquals(0, difference.length(), "Found non-zero diff: " + difference);
     }
 
     @Test
-    public void testIAtom_Point8d() throws Exception {
+    void testIAtom_Point8d() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom atom = builder.newInstance(IAtom.class, "C");
         atom.setID("a1");
@@ -282,12 +282,12 @@ public class CDKRoundTripTest extends CDKTestCase {
         mol.addAtom(atom);
         IAtomContainer copy = CMLRoundTripTool.roundTripMolecule(convertor, mol);
         String difference = AtomDiff.diff(atom, copy.getAtom(0));
-        Assert.assertEquals("Found non-zero diff: " + difference, 0, difference.length());
+        Assertions.assertEquals(0, difference.length(), "Found non-zero diff: " + difference);
     }
 
-    @Ignore
+    @Disabled
     @Test
-    public void testIAtom_StereoParity() throws Exception {
+    void testIAtom_StereoParity() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom atom = builder.newInstance(IAtom.class, "C");
         atom.setID("a1");
@@ -295,7 +295,7 @@ public class CDKRoundTripTest extends CDKTestCase {
         mol.addAtom(atom);
         IAtomContainer copy = CMLRoundTripTool.roundTripMolecule(convertor, mol);
         String difference = AtomDiff.diff(atom, copy.getAtom(0));
-        Assert.assertEquals("Found non-zero diff: " + difference, 0, difference.length());
+        Assertions.assertEquals(0, difference.length(), "Found non-zero diff: " + difference);
     }
 
 }
