@@ -25,13 +25,13 @@
 package org.openscience.cdk.smiles;
 
 
-import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.config.Isotopes;
 import org.openscience.cdk.config.IsotopeFactory;
 import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
+import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.interfaces.IDoubleBondStereochemistry;
 import org.openscience.cdk.interfaces.IIsotope;
 import org.openscience.cdk.interfaces.IStereoElement;
@@ -39,6 +39,9 @@ import org.openscience.cdk.interfaces.ITetrahedralChirality;
 
 import org.openscience.cdk.stereo.ExtendedCisTrans;
 import org.openscience.cdk.stereo.ExtendedTetrahedral;
+import org.openscience.cdk.stereo.Octahedral;
+import org.openscience.cdk.stereo.SquarePlanar;
+import org.openscience.cdk.stereo.TrigonalBipyramidal;
 import uk.ac.ebi.beam.Atom;
 import uk.ac.ebi.beam.AtomBuilder;
 import uk.ac.ebi.beam.Bond;
@@ -50,6 +53,7 @@ import uk.ac.ebi.beam.GraphBuilder;
 
 import java.io.IOException;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 
@@ -86,6 +90,7 @@ import static org.openscience.cdk.interfaces.ITetrahedralChirality.Stereo.CLOCKW
  */
 final class CDKToBeam {
 
+    public static final Configuration[] CONFIGS = Configuration.values();
     /**
      * Whether to convert the molecule with isotope and stereo information -
      * Isomeric SMILES.
@@ -148,7 +153,7 @@ final class CDKToBeam {
             for (IStereoElement se : ac.stereoElements()) {
                 if (SmiFlavor.isSet(flavour, SmiFlavor.StereoTetrahedral) &&
                     se instanceof ITetrahedralChirality) {
-                    addTetrahedralConfiguration((ITetrahedralChirality) se, gb, indices);
+                    addAtomStereo(se, gb, indices);
                 } else if (SmiFlavor.isSet(flavour, SmiFlavor.StereoCisTrans) &&
                            se instanceof IDoubleBondStereochemistry) {
                     addGeometricConfiguration((IDoubleBondStereochemistry) se, flavour, gb, indices);
@@ -158,6 +163,15 @@ final class CDKToBeam {
                 } else if (SmiFlavor.isSet(flavour, SmiFlavor.StereoExCisTrans) &&
                            se instanceof ExtendedCisTrans) {
                     addExtendedCisTransConfig((ExtendedCisTrans) se, gb, indices, ac);
+                } else if (SmiFlavor.isSet(flavour, SmiFlavor.StereoSquarePlanar) &&
+                        se instanceof SquarePlanar) {
+                    addAtomStereo((SquarePlanar)se, gb, indices);
+                } else if (SmiFlavor.isSet(flavour, SmiFlavor.StereoTrigonalBipyramidal) &&
+                        se instanceof TrigonalBipyramidal) {
+                    addAtomStereo((TrigonalBipyramidal)se, gb, indices);
+                } else if (SmiFlavor.isSet(flavour, SmiFlavor.StereoOctahedral) &&
+                        se instanceof Octahedral) {
+                    addAtomStereo((Octahedral)se, gb, indices);
                 }
             }
         }
@@ -205,7 +219,7 @@ final class CDKToBeam {
      */
     static Atom toBeamAtom(final IAtom a, final int flavour) {
 
-        final boolean aromatic = SmiFlavor.isSet(flavour, SmiFlavor.UseAromaticSymbols) && a.getFlag(CDKConstants.ISAROMATIC);
+        final boolean aromatic = SmiFlavor.isSet(flavour, SmiFlavor.UseAromaticSymbols) && a.getFlag(IChemObject.AROMATIC);
         final Integer charge = a.getFormalCharge();
         final String symbol = Objects.requireNonNull(a.getSymbol(), "An atom had an undefined symbol");
 
@@ -227,7 +241,7 @@ final class CDKToBeam {
         // use the mass number to specify isotope?
         if (SmiFlavor.isSet(flavour, SmiFlavor.AtomicMass | SmiFlavor.AtomicMassStrict)) {
             Integer massNumber = a.getMassNumber();
-            if (massNumber != null) {
+            if (massNumber != null && massNumber != 0) {
                 ab.isotope(massNumber);
             }
         }
@@ -310,7 +324,7 @@ final class CDKToBeam {
         IBond[] bs = dbs.getBonds();
 
         // don't try to set a configuration on aromatic bonds
-        if (SmiFlavor.isSet(flavour, SmiFlavor.UseAromaticSymbols) && db.getFlag(CDKConstants.ISAROMATIC)) return;
+        if (SmiFlavor.isSet(flavour, SmiFlavor.UseAromaticSymbols) && db.getFlag(IChemObject.AROMATIC)) return;
 
         int u = indices.get(db.getBegin());
         int v = indices.get(db.getEnd());
@@ -385,4 +399,57 @@ final class CDKToBeam {
                          config);
         }
     }
+
+    private static Configuration getConfig(IStereoElement<IAtom,IAtom> se) {
+        final int base;
+        switch (se.getConfigClass()) {
+            case IStereoElement.Tetrahedral:
+                base = Configuration.TH1.ordinal();
+                break;
+            case IStereoElement.SquarePlanar:
+                base = Configuration.SP1.ordinal();
+                break;
+            case IStereoElement.TrigonalBipyramidal:
+                base = Configuration.TB1.ordinal();
+                break;
+            case IStereoElement.Octahedral:
+                base = Configuration.OH1.ordinal();
+                break;
+            default:
+                throw new IllegalArgumentException("Unexpected config: cls=" +
+                                                           Integer.toHexString(se.getConfigClass()) +
+                                                           " ord=" + Integer.toHexString(se.getConfigOrder()));
+        }
+        return CONFIGS[base+se.getConfigOrder()-1];
+    }
+
+    private static void addAtomStereo(IStereoElement<IAtom,IAtom> se,
+                                      GraphBuilder gb,
+                                      Map<IAtom, Integer> indices) {
+        Configuration config = getConfig(se);
+        IAtom focus = se.getFocus();
+        List<IAtom> carriers = se.getCarriers();
+
+        // invalid tetrahedral
+        if (config.type() == Configuration.Type.Tetrahedral) {
+            int numImplicit = 0;
+            for (IAtom atom : carriers) {
+                if (atom.equals(focus)) {
+                    numImplicit++;
+                }
+            }
+            if (numImplicit > 1)
+                return;
+        }
+
+
+        int[] neighbors = new int[carriers.size() - 1];
+        for (int i = 0; i < neighbors.length; i++) {
+            neighbors[i] = indices.get(carriers.get(i + 1));
+        }
+        GraphBuilder.AtomStereoBuilder builder;
+        builder = gb.atomStereo(indices.get(focus), config);
+        builder.lookingFrom(indices.get(carriers.get(0))).neighbors(neighbors);
+        builder.build();
+    }
 }
