@@ -54,7 +54,6 @@ import java.util.Collections;
 import java.util.Comparator;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -549,7 +548,11 @@ public final class SmilesGenerator {
         IAtomContainer    agentPart    = reaction.getBuilder().newInstance(IAtomContainer.class);
         IAtomContainer    productPart  = reaction.getBuilder().newInstance(IAtomContainer.class);
 
-        List<Sgroup> sgroups = new ArrayList<>();
+        List<Sgroup> sgroups = reaction.getProperty(CDKConstants.CTAB_SGROUPS);
+        if (sgroups == null)
+            sgroups = new ArrayList<>();
+        else
+            sgroups = new ArrayList<>(sgroups); // ensure not immutable
 
         for (IAtomContainer reactant : reactants.atomContainers()) {
             reactantPart.add(reactant);
@@ -575,9 +578,10 @@ public final class SmilesGenerator {
         }
 
         // we need to make sure we generate without the CXSMILES layers
-        String smi = create(reactantPart, flavour &~ SmiFlavor.CxSmilesWithCoords, reactantOrder) + ">" +
-                     create(agentPart, flavour &~ SmiFlavor.CxSmilesWithCoords, agentOrder) + ">" +
-                     create(productPart, flavour &~ SmiFlavor.CxSmilesWithCoords, productOrder);
+        int adjustedFlav = flavour & ~(SmiFlavor.CxSmilesWithCoords & ~SmiFlavor.StereoTetrahedral);
+        String smi = create(reactantPart, adjustedFlav, reactantOrder) + ">" +
+                     create(agentPart, adjustedFlav, agentOrder) + ">" +
+                     create(productPart, adjustedFlav, productOrder);
 
         // copy ordering back to unified array and adjust values
         int agentBeg = reactantOrder.length;
@@ -716,7 +720,7 @@ public final class SmilesGenerator {
             return (long[]) method.invoke(c, container);
         } catch (ClassNotFoundException e) {
             throw new CDKException("The cdk-inchi module is not loaded,"
-                    + " this module is need when generating absolute SMILES.");
+                    + " this module is needed when generating absolute SMILES.");
         } catch (NoSuchMethodException e) {
             throw new CDKException("The method " + mname + " was not found", e);
         } catch (InvocationTargetException e) {
@@ -882,7 +886,7 @@ public final class SmilesGenerator {
                         }
                         break;
                     case ExtAttachOrdering: {
-                        IAtom       beg   = null;
+                        IAtom       beg;
                         List<IAtom> ends  = new ArrayList<>();
                         if (sgroup.getAtoms().size() != 1)
                             throw new IllegalArgumentException("Attach ordering in inconsistent state!");
@@ -907,10 +911,10 @@ public final class SmilesGenerator {
                         // can be generated but currently ignored
                         CxSmilesState.CxDataSgroup cxDataSgrp;
                         cxDataSgrp= new CxSmilesState.CxDataSgroup(toAtomIdxs(sgroup.getAtoms(), atomidx),
-                                                                  (String)sgroup.getValue(SgroupKey.DataFieldName),
-                                                                  (String)sgroup.getValue(SgroupKey.Data),
+                                sgroup.getValue(SgroupKey.DataFieldName),
+                                sgroup.getValue(SgroupKey.Data),
                                                                    null,
-                                                                  (String)sgroup.getValue(SgroupKey.DataFieldUnits),
+                                sgroup.getValue(SgroupKey.DataFieldUnits),
                                                                   null);
                         state.mysgroups.add(cxDataSgrp);
                         mapping.put(sgroup, cxDataSgrp);
@@ -1015,7 +1019,7 @@ public final class SmilesGenerator {
                                                      final int flavor) {
         return new Comparator<IAtom>() {
 
-            final int unbox(Integer x) {
+            int unbox(Integer x) {
                 return x != null ? x : 0;
             }
 
