@@ -23,8 +23,8 @@
 package org.openscience.cdk.io.iterator;
 
 import org.hamcrest.CoreMatchers;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.DefaultChemObjectBuilder;
@@ -41,8 +41,6 @@ import java.io.StringReader;
 
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
 
 /**
  * TestCase for the reading SMILES mol files using one test file.
@@ -50,12 +48,12 @@ import static org.junit.Assert.assertTrue;
  * @cdk.module test-smiles
  * @see org.openscience.cdk.io.SMILESReader
  */
-public class IteratingSMILESReaderTest extends CDKTestCase {
+class IteratingSMILESReaderTest extends CDKTestCase {
 
-    private static ILoggingTool logger = LoggingToolFactory.createLoggingTool(IteratingSMILESReaderTest.class);
+    private static final ILoggingTool logger = LoggingToolFactory.createLoggingTool(IteratingSMILESReaderTest.class);
 
     @Test
-    public void testSMILESFileWithNames() throws Exception {
+    void testSMILESFileWithNames() throws Exception {
         String filename = "test.smi";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
@@ -64,18 +62,18 @@ public class IteratingSMILESReaderTest extends CDKTestCase {
         int molCount = 0;
         while (reader.hasNext()) {
             Object object = reader.next();
-            Assert.assertNotNull(object);
-            assertTrue(object instanceof IAtomContainer);
+            Assertions.assertNotNull(object);
+            Assertions.assertTrue(object instanceof IAtomContainer);
             molCount++;
         }
 
-        Assert.assertEquals(5, molCount);
+        Assertions.assertEquals(5, molCount);
 
         reader.close();
     }
 
     @Test
-    public void testSMILESFileWithSpacesAndTabs() throws Exception {
+    void testSMILESFileWithSpacesAndTabs() throws Exception {
         String filename = "tabs.smi";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
@@ -84,18 +82,18 @@ public class IteratingSMILESReaderTest extends CDKTestCase {
         int molCount = 0;
         while (reader.hasNext()) {
             Object object = reader.next();
-            Assert.assertNotNull(object);
-            assertTrue(object instanceof IAtomContainer);
+            Assertions.assertNotNull(object);
+            Assertions.assertTrue(object instanceof IAtomContainer);
             molCount++;
         }
 
-        Assert.assertEquals(5, molCount);
+        Assertions.assertEquals(5, molCount);
 
         reader.close();
     }
 
     @Test
-    public void testSMILESTitles() throws Exception {
+    void testSMILESTitles() throws Exception {
         String filename = "tabs.smi";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
@@ -103,15 +101,15 @@ public class IteratingSMILESReaderTest extends CDKTestCase {
 
         while (reader.hasNext()) {
 
-            IAtomContainer mol = (IAtomContainer) reader.next();
-            String title = (String) mol.getProperty(CDKConstants.TITLE);
-            Assert.assertNotNull(title);
+            IAtomContainer mol = reader.next();
+            String title = mol.getProperty(CDKConstants.TITLE);
+            Assertions.assertNotNull(title);
         }
 
     }
 
     @Test
-    public void testSMILESFile() {
+    void testSMILESFile() {
         String filename = "test2.smi";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
@@ -120,26 +118,26 @@ public class IteratingSMILESReaderTest extends CDKTestCase {
         int molCount = 0;
         while (reader.hasNext()) {
             Object object = reader.next();
-            Assert.assertNotNull(object);
-            assertTrue(object instanceof IAtomContainer);
+            Assertions.assertNotNull(object);
+            Assertions.assertTrue(object instanceof IAtomContainer);
             molCount++;
         }
 
-        Assert.assertEquals(5, molCount);
+        Assertions.assertEquals(5, molCount);
     }
 
     @Test
-    public void testGetFormat() {
+    void testGetFormat() {
         String filename = "test2.smi";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
         IteratingSMILESReader reader = new IteratingSMILESReader(ins, DefaultChemObjectBuilder.getInstance());
         IResourceFormat format = reader.getFormat();
-        assertTrue(format instanceof SMILESFormat);
+        Assertions.assertTrue(format instanceof SMILESFormat);
     }
 
     @Test
-    public void testSetReader1() {
+    void testSetReader1() {
         String filename = "test2.smi";
         InputStream ins1 = this.getClass().getResourceAsStream(filename);
         IteratingSMILESReader reader = new IteratingSMILESReader(ins1, DefaultChemObjectBuilder.getInstance());
@@ -156,11 +154,11 @@ public class IteratingSMILESReaderTest extends CDKTestCase {
             reader.next();
             molCount++;
         }
-        Assert.assertEquals(5, molCount);
+        Assertions.assertEquals(5, molCount);
     }
 
-    @Test(expected = UnsupportedOperationException.class)
-    public void testRemove() {
+    @Test
+    void testRemove() {
         String filename = "test2.smi";
         InputStream ins1 = this.getClass().getResourceAsStream(filename);
         IteratingSMILESReader reader = new IteratingSMILESReader(ins1, DefaultChemObjectBuilder.getInstance());
@@ -170,34 +168,35 @@ public class IteratingSMILESReaderTest extends CDKTestCase {
             molCount++;
             if (molCount > 2) break;
         }
-        reader.remove();
+        Assertions.assertThrows(UnsupportedOperationException.class,
+                                reader::remove);
     }
 
     @Test
-    public void empty() {
+    void empty() {
         Reader reader = new StringReader(" empty1\n empty2");
         IteratingSMILESReader smis = new IteratingSMILESReader(reader, SilentChemObjectBuilder.getInstance());
-        assertTrue(smis.hasNext());
+        Assertions.assertTrue(smis.hasNext());
         IAtomContainer m1 = smis.next();
         assertThat(m1.getAtomCount(), is(0));
         assertThat(m1.getProperty(CDKConstants.TITLE, String.class), CoreMatchers.is("empty1"));
-        assertTrue(smis.hasNext());
+        Assertions.assertTrue(smis.hasNext());
         IAtomContainer m2 = smis.next();
         assertThat(m2.getAtomCount(), is(0));
         assertThat(m2.getProperty(CDKConstants.TITLE, String.class), CoreMatchers.is("empty2"));
-        assertFalse(smis.hasNext());
+        Assertions.assertFalse(smis.hasNext());
     }
 
     @Test
-    public void problemSmiles() {
+    void problemSmiles() {
 
         Reader reader = new StringReader(" okay\nn1cccc1 bad\n okay");
         IteratingSMILESReader smis = new IteratingSMILESReader(reader, SilentChemObjectBuilder.getInstance());
-        assertTrue(smis.hasNext());
+        Assertions.assertTrue(smis.hasNext());
         IAtomContainer m1 = smis.next();
         assertThat(m1.getAtomCount(), is(0));
         assertThat(m1.getProperty(CDKConstants.TITLE, String.class), CoreMatchers.is("okay"));
-        assertTrue(smis.hasNext());
+        Assertions.assertTrue(smis.hasNext());
         IAtomContainer m2 = smis.next();
         assertThat(m2.getAtomCount(), is(0));
         assertThat(m2.getProperty(CDKConstants.TITLE, String.class), CoreMatchers.is("bad"));
@@ -205,6 +204,6 @@ public class IteratingSMILESReaderTest extends CDKTestCase {
         IAtomContainer m3 = smis.next();
         assertThat(m3.getAtomCount(), is(0));
         assertThat(m3.getProperty(CDKConstants.TITLE, String.class), CoreMatchers.is("okay"));
-        assertFalse(smis.hasNext());
+        Assertions.assertFalse(smis.hasNext());
     }
 }
