@@ -23,7 +23,6 @@
  *  */
 package org.openscience.cdk.tools.manipulator;
 
-import org.openscience.cdk.CDK;
 import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.config.AtomTypeFactory;
 import org.openscience.cdk.config.Elements;
@@ -119,7 +118,7 @@ public class MolecularFormulaManipulator {
 
         int count = 0;
         for (IIsotope isotope : formula.isotopes()) {
-            if (isotope.getSymbol().equals(element.getSymbol())) count += formula.getIsotopeCount(isotope);
+            if (isotope.getAtomicNumber().equals(element.getAtomicNumber())) count += formula.getIsotopeCount(isotope);
         }
         return count;
     }
@@ -158,9 +157,9 @@ public class MolecularFormulaManipulator {
      */
     public static List<IIsotope> getIsotopes(IMolecularFormula formula, IElement element) {
 
-        List<IIsotope> isotopeList = new ArrayList<IIsotope>();
+        List<IIsotope> isotopeList = new ArrayList<>();
         for (IIsotope isotope : formula.isotopes()) {
-            if (isotope.getSymbol().equals(element.getSymbol())) isotopeList.add(isotope);
+            if (isotope.getAtomicNumber().equals(element.getAtomicNumber())) isotopeList.add(isotope);
 
         }
         return isotopeList;
@@ -175,8 +174,8 @@ public class MolecularFormulaManipulator {
      */
     public static List<IElement> elements(IMolecularFormula formula) {
 
-        List<IElement> elementList = new ArrayList<IElement>();
-        List<String> stringList = new ArrayList<String>();
+        List<IElement> elementList = new ArrayList<>();
+        List<String> stringList = new ArrayList<>();
         for (IIsotope isotope : formula.isotopes()) {
             if (!stringList.contains(isotope.getSymbol())) {
                 elementList.add(isotope);
@@ -197,7 +196,7 @@ public class MolecularFormulaManipulator {
     public static boolean containsElement(IMolecularFormula formula, IElement element) {
 
         for (IIsotope isotope : formula.isotopes()) {
-            if (element.getSymbol().equals(isotope.getSymbol())) return true;
+            if (element.getAtomicNumber().equals(isotope.getAtomicNumber())) return true;
         }
 
         return false;
@@ -391,25 +390,24 @@ public class MolecularFormulaManipulator {
     }
 
     public static List<IIsotope> putInOrder(String[] orderElements, IMolecularFormula formula) {
-        List<IIsotope> isotopesList = new ArrayList<IIsotope>();
+        List<IIsotope> isotopesList = new ArrayList<>();
         for (String orderElement : orderElements) {
             IElement element = formula.getBuilder().newInstance(IElement.class, orderElement);
             if (containsElement(formula, element)) {
                 List<IIsotope> isotopes = getIsotopes(formula, element);
-                Collections.sort(isotopes,
-                                 new Comparator<IIsotope>() {
-                                     @Override
-                                     public int compare(IIsotope a,
-                                                        IIsotope b) {
-                                         Integer aMass = a.getMassNumber();
-                                         Integer bMass = b.getMassNumber();
-                                         if (aMass == null)
-                                             return -1;
-                                         if (bMass == null)
-                                             return +1;
-                                         return aMass.compareTo(bMass);
-                                     }
-                                 });
+                isotopes.sort(new Comparator<IIsotope>() {
+                    @Override
+                    public int compare(IIsotope a,
+                                       IIsotope b) {
+                        Integer aMass = a.getMassNumber();
+                        Integer bMass = b.getMassNumber();
+                        if (aMass == null)
+                            return -1;
+                        if (bMass == null)
+                            return +1;
+                        return aMass.compareTo(bMass);
+                    }
+                });
                 isotopesList.addAll(isotopes);
             }
         }
@@ -421,9 +419,9 @@ public class MolecularFormulaManipulator {
      */
     @Deprecated
     public static String getHillString(IMolecularFormula formula) {
-        StringBuffer hillString = new StringBuffer();
+        StringBuilder hillString = new StringBuilder();
 
-        Map<String, Integer> hillMap = new TreeMap<String, Integer>();
+        Map<String, Integer> hillMap = new TreeMap<>();
         for (IIsotope isotope : formula.isotopes()) {
             String symbol = isotope.getSymbol();
             if (hillMap.containsKey(symbol))
@@ -644,7 +642,9 @@ public class MolecularFormulaManipulator {
             return pos == str.length() ? '\0' : str.charAt(pos++);
         }
 
+        // maximum of 6 digits
         int nextUInt() {
+            int mark = pos;
             char c = next();
             if (!isDigit(c)) {
                 if (c != '\0')
@@ -652,8 +652,11 @@ public class MolecularFormulaManipulator {
                 return -1;
             }
             int res = c - '0';
-            while (isDigit(c = next()))
+            while (isDigit(c = next())) {
                 res = (10 * res) + (c - '0');
+            }
+            if (pos - mark > 7)
+                throw new NumberFormatException("Value too large, 7 digits max!");
             if (c != '\0')
                 pos--;
             return res;
@@ -689,7 +692,7 @@ public class MolecularFormulaManipulator {
                                         boolean setMajor) {
         Elements elem = null;
         int mass = 0;
-        int count = 0;
+        int count;
         if (iter.nextIf('[')) {
             mass = iter.nextUInt();
             if (mass < 0)
@@ -869,7 +872,8 @@ public class MolecularFormulaManipulator {
                     mass += isotope2.getMassNumber() * formula.getIsotopeCount(isotope);
                 }
             } catch (IOException e) {
-                e.printStackTrace();
+                LoggingToolFactory.createLoggingTool(MolecularFormulaManipulator.class)
+                                  .warn("Unexpected Error:", e);
             }
         }
         return mass;
@@ -1042,7 +1046,7 @@ public class MolecularFormulaManipulator {
      * @cdk.keyword double bond equivalent
      */
     public static double getDBE(IMolecularFormula formula) throws CDKException {
-        int valencies[] = new int[5];
+        int[] valencies = new int[5];
         IAtomContainer ac = getAtomContainer(formula);
         AtomTypeFactory factory = AtomTypeFactory.getInstance(
                 "org/openscience/cdk/config/data/structgen_atomtypes.xml", ac.getBuilder());
@@ -1056,7 +1060,7 @@ public class MolecularFormulaManipulator {
             //			valencies[(int) (types[0].getBondOrderSum() + ac.getAtom(f).getFormalCharge())]++;
             valencies[types[0].getBondOrderSum().intValue()]++;
         }
-        return 1 + (valencies[4]) + (valencies[3] / 2) - (valencies[1] / 2);
+        return 1 + (valencies[4]) + (valencies[3] / 2.0) - (valencies[1] / 2.0);
     }
 
     /**
@@ -1291,9 +1295,9 @@ public class MolecularFormulaManipulator {
      * @cdk.keyword    hydrogen, removal
      */
     public static List<IElement> getHeavyElements(IMolecularFormula formula) {
-        List<IElement> newEle = new ArrayList<IElement>();
+        List<IElement> newEle = new ArrayList<>();
         for (IElement element : elements(formula)) {
-            if (!element.getSymbol().equals("H")) {
+            if (element.getAtomicNumber() != IElement.H) {
                 newEle.add(element);
             }
         }
@@ -1317,7 +1321,7 @@ public class MolecularFormulaManipulator {
         }
         if (!formula.contains(".")) return breakExtractor(formula);
 
-        List<String> listMF = new ArrayList<String>();
+        List<String> listMF = new ArrayList<>();
         while (newFormula.contains(".")) {
             int pos = newFormula.indexOf('.');
             String thisFormula = newFormula.substring(0, pos);
@@ -1344,10 +1348,9 @@ public class MolecularFormulaManipulator {
         String recentElementSymbol = "";
         String recentElementCountString = "0";
 
-        List<String> eleSymb = new ArrayList<String>();
-        List<Integer> eleCount = new ArrayList<Integer>();
-        for (int i = 0; i < listMF.size(); i++) {
-            String thisFormula = listMF.get(i);
+        List<String> eleSymb = new ArrayList<>();
+        List<Integer> eleCount = new ArrayList<>();
+        for (String thisFormula : listMF) {
             for (int f = 0; f < thisFormula.length(); f++) {
                 thisChar = thisFormula.charAt(f);
                 if (f < thisFormula.length()) {
@@ -1365,12 +1368,12 @@ public class MolecularFormulaManipulator {
                 if (f == thisFormula.length() - 1
                         || (thisFormula.charAt(f + 1) >= 'A' && thisFormula.charAt(f + 1) <= 'Z')) {
                     int posit = eleSymb.indexOf(recentElementSymbol);
-                    int count = Integer.valueOf(recentElementCountString);
+                    int count = Integer.parseInt(recentElementCountString);
                     if (posit == -1) {
                         eleSymb.add(recentElementSymbol);
                         eleCount.add(count);
                     } else {
-                        int countP = Integer.valueOf(recentElementCountString);
+                        int countP = Integer.parseInt(recentElementCountString);
                         if (countP == 0) countP = 1;
                         int countA = eleCount.get(posit);
                         if (countA == 0) countA = 1;
@@ -1432,7 +1435,7 @@ public class MolecularFormulaManipulator {
                     multipliedformula += thisChar;
         	}
         }
-        finalformula += muliplier(multipliedformula, multiple.isEmpty() ? 1:Integer.valueOf(multiple)) + formulaEnd;
+        finalformula += muliplier(multipliedformula, multiple.isEmpty() ? 1:Integer.parseInt(multiple)) + formulaEnd;
 
         if (finalformula.contains("("))
         	return breakExtractor(finalformula);
@@ -1465,7 +1468,7 @@ public class MolecularFormulaManipulator {
                 recentCompound += thisChar;
             }
         }
-        return muliplier(recentCompound, Integer.valueOf(recentCompoundCount));
+        return muliplier(recentCompound, Integer.parseInt(recentCompoundCount));
     }
 
     /**
@@ -1542,7 +1545,7 @@ public class MolecularFormulaManipulator {
         int pcount = 0;
 
         for (IIsotope iso : mf.isotopes()) {
-            if ("H".equals(iso.getSymbol())) {
+            if (iso.getAtomicNumber() == IElement.H) {
                 final int count = mf.getIsotopeCount(iso);
                 if (count < hcnt)
                     continue;
