@@ -54,7 +54,7 @@ class BondRefinable implements Refinable {
     /**
      * Specialised option to allow generating automorphisms that ignore the bond order.
      */
-    private boolean ignoreBondOrders;
+    private final boolean ignoreBondOrders;
     
     public BondRefinable(IAtomContainer atomContainer) {
         this(atomContainer, false);
@@ -106,7 +106,7 @@ class BondRefinable implements Refinable {
      */
     public Partition getInitialPartition() {
         int bondCount = atomContainer.getBondCount();
-        Map<String, SortedSet<Integer>> cellMap = new HashMap<String, SortedSet<Integer>>();
+        Map<String, SortedSet<Integer>> cellMap = new HashMap<>();
 
         // make mini-'descriptors' for bonds like "C=O" or "C#N" etc
         for (int bondIndex = 0; bondIndex < bondCount; bondIndex++) {
@@ -132,14 +132,14 @@ class BondRefinable implements Refinable {
             if (cellMap.containsKey(bondString)) {
                 cell = cellMap.get(bondString);
             } else {
-                cell = new TreeSet<Integer>();
+                cell = new TreeSet<>();
                 cellMap.put(bondString, cell);
             }
             cell.add(bondIndex);
         }
 
         // sorting is necessary to get cells in order
-        List<String> bondStrings = new ArrayList<String>(cellMap.keySet());
+        List<String> bondStrings = new ArrayList<>(cellMap.keySet());
         Collections.sort(bondStrings);
 
         // the partition of the bonds by these 'descriptors'
@@ -155,8 +155,8 @@ class BondRefinable implements Refinable {
     private void setupConnectionTable(IAtomContainer atomContainer) {
         int bondCount = atomContainer.getBondCount();
         // unfortunately, we have to sort the bonds
-        List<IBond> bonds = new ArrayList<IBond>();
-        Map<String, IBond> bondMap = new HashMap<String, IBond>();
+        List<IBond> bonds = new ArrayList<>();
+        Map<String, IBond> bondMap = new HashMap<>();
         for (int bondIndexI = 0; bondIndexI < bondCount; bondIndexI++) {
             IBond bond = atomContainer.getBond(bondIndexI);
             bonds.add(bond);
@@ -180,7 +180,7 @@ class BondRefinable implements Refinable {
             bondMap.put(bondString, bond);
         }
 
-        List<String> keys = new ArrayList<String>(bondMap.keySet());
+        List<String> keys = new ArrayList<>(bondMap.keySet());
         Collections.sort(keys);
         for (String key : keys) {
             bonds.add(bondMap.get(key));
@@ -189,7 +189,7 @@ class BondRefinable implements Refinable {
         connectionTable = new int[bondCount][];
         for (int bondIndexI = 0; bondIndexI < bondCount; bondIndexI++) {
             IBond bondI = bonds.get(bondIndexI);
-            List<Integer> connectedBondIndices = new ArrayList<Integer>();
+            List<Integer> connectedBondIndices = new ArrayList<>();
             for (int bondIndexJ = 0; bondIndexJ < bondCount; bondIndexJ++) {
                 if (bondIndexI == bondIndexJ) continue;
                 IBond bondJ = bonds.get(bondIndexJ);
