@@ -3,8 +3,8 @@ package org.openscience.cdk.group;
 import java.util.HashSet;
 import java.util.Set;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.CDKTestCase;
 
 /**
@@ -15,19 +15,19 @@ public class AbstractDiscretePartitionRefinerTest extends CDKTestCase {
 
     public class Graph {
 
-        public int     vertexCount;
-        public int[][] connectionTable;
+        final int     vertexCount;
+        int[][] connectionTable;
 
-        public Graph(int vertexCount) {
+        Graph(int vertexCount) {
             this.vertexCount = vertexCount;
         }
     }
 
-    public class MockRefiner extends AbstractDiscretePartitionRefiner {
+    class MockRefiner extends AbstractDiscretePartitionRefiner {
 
-        public Graph graph;
+        final Graph graph;
 
-        public MockRefiner(Graph graph) {
+        MockRefiner(Graph graph) {
             super();
             this.graph = graph;
         }
@@ -48,7 +48,7 @@ public class AbstractDiscretePartitionRefinerTest extends CDKTestCase {
         
         private final Graph graph;
         
-        public GraphRefinable(Graph graph) {
+        GraphRefinable(Graph graph) {
             this.graph = graph;
         }
 
@@ -63,7 +63,7 @@ public class AbstractDiscretePartitionRefinerTest extends CDKTestCase {
         }
 
         private int[] getConnectedIndices(int vertexIndex) {
-            Set<Integer> connectedSet = new HashSet<Integer>();
+            Set<Integer> connectedSet = new HashSet<>();
             for (int index = 0; index < graph.connectionTable.length; index++) {
                 if (graph.connectionTable[vertexIndex][index] == 1) {
                     connectedSet.add(index);
@@ -97,26 +97,26 @@ public class AbstractDiscretePartitionRefinerTest extends CDKTestCase {
     }
 
     @Test
-    public void emptyConstructor() {
+    void emptyConstructor() {
         MockRefiner refiner = new MockRefiner(null);
-        Assert.assertNotNull(refiner);
+        Assertions.assertNotNull(refiner);
     }
 
     @Test
-    public void getVertexCountTest() {
+    void getVertexCountTest() {
         int n = 10;
         Graph g = new Graph(n);
         MockRefiner refiner = new MockRefiner(g);
-        Assert.assertEquals(g.vertexCount, refiner.getVertexCount());
+        Assertions.assertEquals(g.vertexCount, refiner.getVertexCount());
     }
 
     @Test
-    public void getConnectivityTest() {
+    void getConnectivityTest() {
         int n = 3;
         Graph g = new Graph(n);
         g.connectionTable = new int[][]{{0, 1, 0}, {1, 0, 1}, {0, 1, 0}};
         MockRefiner refiner = new MockRefiner(g);
-        Assert.assertEquals(1, refiner.getConnectivity(0, 1));
+        Assertions.assertEquals(1, refiner.getConnectivity(0, 1));
     }
     
     private void setup(MockRefiner refiner, PermutationGroup group, Graph g) {
@@ -124,17 +124,17 @@ public class AbstractDiscretePartitionRefinerTest extends CDKTestCase {
     }
 
     @Test
-    public void setupTest() {
+    void setupTest() {
         int n = 5;
         PermutationGroup group = new PermutationGroup(n);
         Graph g = new Graph(n);
         MockRefiner refiner = new MockRefiner(g);
         setup(refiner, group, g);
-        Assert.assertEquals(group, refiner.getAutomorphismGroup());
+        Assertions.assertEquals(group, refiner.getAutomorphismGroup());
     }
 
     @Test
-    public void firstIsIdentityTest() {
+    void firstIsIdentityTest() {
         int n = 3;
         Graph g = new Graph(n);
         g.connectionTable = new int[][]{{0, 1, 1}, {1, 0, 0}, {1, 0, 0}};
@@ -142,11 +142,11 @@ public class AbstractDiscretePartitionRefinerTest extends CDKTestCase {
         MockRefiner refiner = new MockRefiner(g);
         setup(refiner, group, g);
         refiner.refine(Partition.unit(n));
-        Assert.assertTrue(refiner.firstIsIdentity());
+        Assertions.assertTrue(refiner.firstIsIdentity());
     }
 
     @Test
-    public void getAutomorphismPartitionTest() {
+    void getAutomorphismPartitionTest() {
         int n = 3;
         Graph g = new Graph(n);
         g.connectionTable = new int[][]{{0, 1, 1}, {1, 0, 0}, {1, 0, 0}};
@@ -156,22 +156,22 @@ public class AbstractDiscretePartitionRefinerTest extends CDKTestCase {
         refiner.refine(Partition.unit(n));
         Partition autPartition = refiner.getAutomorphismPartition();
         Partition expected = Partition.fromString("0|1,2");
-        Assert.assertEquals(expected, autPartition);
+        Assertions.assertEquals(expected, autPartition);
     }
 
     @Test
-    public void getHalfMatrixStringTest() {
+    void getHalfMatrixStringTest() {
         int n = 3;
         Graph g = new Graph(n);
         g.connectionTable = new int[][]{{0, 1, 1}, {1, 0, 0}, {1, 0, 0}};
         MockRefiner refiner = new MockRefiner(g);
         String hms = refiner.getHalfMatrixString();
         String expected = "110";
-        Assert.assertEquals(expected, hms);
+        Assertions.assertEquals(expected, hms);
     }
 
     @Test
-    public void getFirstHalfMatrixStringTest() {
+    void getFirstHalfMatrixStringTest() {
         int n = 3;
         Graph g = new Graph(n);
         g.connectionTable = new int[][]{{0, 0, 1}, {0, 0, 1}, {1, 1, 0}};
@@ -181,22 +181,22 @@ public class AbstractDiscretePartitionRefinerTest extends CDKTestCase {
         refiner.refine(Partition.unit(n));
         String hms = refiner.getFirstHalfMatrixString();
         String expected = "110";
-        Assert.assertEquals(expected, hms);
+        Assertions.assertEquals(expected, hms);
     }
 
     @Test
-    public void getGroupTest() {
+    void getGroupTest() {
         int n = 3;
         Graph g = new Graph(n);
         g.connectionTable = new int[][]{{0, 1, 0}, {1, 0, 1}, {0, 1, 0}};
         PermutationGroup group = new PermutationGroup(n);
         MockRefiner refiner = new MockRefiner(g);
         setup(refiner, group, g);
-        Assert.assertNotNull(refiner.getAutomorphismGroup());
+        Assertions.assertNotNull(refiner.getAutomorphismGroup());
     }
 
     @Test
-    public void getBestTest() {
+    void getBestTest() {
         int n = 3;
         Graph g = new Graph(n);
         g.connectionTable = new int[][]{{0, 1, 0}, {1, 0, 1}, {0, 1, 0}};
@@ -206,11 +206,11 @@ public class AbstractDiscretePartitionRefinerTest extends CDKTestCase {
         refiner.refine(Partition.unit(n));
         Permutation best = refiner.getBest();
         Permutation expected = new Permutation(1, 0, 2);
-        Assert.assertEquals(expected, best);
+        Assertions.assertEquals(expected, best);
     }
 
     @Test
-    public void getFirstTest() {
+    void getFirstTest() {
         int n = 3;
         Graph g = new Graph(n);
         g.connectionTable = new int[][]{{0, 1, 0}, {1, 0, 1}, {0, 1, 0}};
@@ -220,11 +220,11 @@ public class AbstractDiscretePartitionRefinerTest extends CDKTestCase {
         refiner.refine(Partition.unit(n));
         Permutation first = refiner.getFirst();
         Permutation expected = new Permutation(1, 0, 2);
-        Assert.assertEquals(expected, first);
+        Assertions.assertEquals(expected, first);
     }
 
     @Test
-    public void isCanonical_TrueTest() {
+    void isCanonical_TrueTest() {
         int n = 3;
         Graph g = new Graph(n);
         g.connectionTable = new int[][]{{0, 1, 1}, {1, 0, 0}, {1, 0, 0}};
@@ -232,11 +232,11 @@ public class AbstractDiscretePartitionRefinerTest extends CDKTestCase {
         MockRefiner refiner = new MockRefiner(g);
         setup(refiner, group, g);
         refiner.refine(Partition.unit(n));
-        Assert.assertTrue(refiner.isCanonical());
+        Assertions.assertTrue(refiner.isCanonical());
     }
 
     @Test
-    public void isCanonical_FalseTest() {
+    void isCanonical_FalseTest() {
         int n = 3;
         Graph g = new Graph(n);
         g.connectionTable = new int[][]{{0, 1, 0}, {1, 0, 1}, {0, 1, 0}};
@@ -244,11 +244,11 @@ public class AbstractDiscretePartitionRefinerTest extends CDKTestCase {
         MockRefiner refiner = new MockRefiner(g);
         setup(refiner, group, g);
         refiner.refine(Partition.unit(n));
-        Assert.assertFalse(refiner.isCanonical());
+        Assertions.assertFalse(refiner.isCanonical());
     }
 
     @Test
-    public void refineTest() {
+    void refineTest() {
         int n = 3;
         Graph g = new Graph(n);
         g.connectionTable = new int[][]{{0, 1, 1}, {1, 0, 0}, {1, 0, 0}};
@@ -256,7 +256,7 @@ public class AbstractDiscretePartitionRefinerTest extends CDKTestCase {
         MockRefiner refiner = new MockRefiner(g);
         setup(refiner, group, g);
         refiner.refine(Partition.unit(n));
-        Assert.assertNotNull(refiner);
+        Assertions.assertNotNull(refiner);
     }
 
 }
