@@ -28,7 +28,6 @@ import org.hamcrest.CoreMatchers;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
-import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.graph.AtomContainerAtomPermutor;
@@ -808,7 +807,7 @@ class HashCodeScenariosTest {
     void butan2ol_UsingStereoElement() {
 
         // C[CH](O)CC
-        IAtomContainer butan2ol = new AtomContainer();
+        IAtomContainer butan2ol = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         butan2ol.addAtom(new Atom("C"));
         butan2ol.addAtom(new Atom("C"));
         butan2ol.addAtom(new Atom("O"));
@@ -876,7 +875,7 @@ class HashCodeScenariosTest {
     void dichloroethenes_stereoElements() {
 
         // CLC=CCL
-        IAtomContainer dichloroethene = new AtomContainer();
+        IAtomContainer dichloroethene = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         dichloroethene.addAtom(new Atom("Cl"));
         dichloroethene.addAtom(new Atom("C"));
         dichloroethene.addAtom(new Atom("C"));
@@ -917,7 +916,7 @@ class HashCodeScenariosTest {
     void dichloroethenes_stereoElements_explicitH() {
 
         // CLC=CCL
-        IAtomContainer dichloroethene = new AtomContainer();
+        IAtomContainer dichloroethene = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         dichloroethene.addAtom(new Atom("Cl")); // Cl1
         dichloroethene.addAtom(new Atom("C")); // C2
         dichloroethene.addAtom(new Atom("C")); // C3
@@ -1015,7 +1014,7 @@ class HashCodeScenariosTest {
     void dichloroethenes_stereoElements_explicitH_suppressed() {
 
         // CLC=CCL
-        IAtomContainer dichloroethene = new AtomContainer();
+        IAtomContainer dichloroethene = DefaultChemObjectBuilder.getInstance().newAtomContainer();
         dichloroethene.addAtom(new Atom("Cl")); // Cl1
         dichloroethene.addAtom(new Atom("C")); // C2
         dichloroethene.addAtom(new Atom("C")); // C3
