@@ -136,7 +136,7 @@ import java.util.Set;
  */
 public class PharmacophoreMatcher {
 
-    private ILoggingTool                  logger                = LoggingToolFactory
+    private final ILoggingTool                  logger                = LoggingToolFactory
                                                                         .createLoggingTool(PharmacophoreMatcher.class);
     private PharmacophoreQuery            pharmacophoreQuery    = null;
     private IAtomContainer                pharmacophoreMolecule = null;
@@ -200,7 +200,7 @@ public class PharmacophoreMatcher {
         if (!checkQuery(pharmacophoreQuery))
             throw new CDKException(
                     "A problem in the query. Make sure all pharmacophore groups of the same symbol have the same same SMARTS");
-        String title = (String) atomContainer.getTitle();
+        String title = atomContainer.getTitle();
 
         if (initializeTarget)
             pharmacophoreMolecule = getPharmacophoreMolecule(atomContainer);
@@ -210,7 +210,7 @@ public class PharmacophoreMatcher {
             // sure we get the latest set of effective coordinates
             for (IAtom iAtom : pharmacophoreMolecule.atoms()) {
                 PharmacophoreAtom patom = PharmacophoreAtom.get(iAtom);
-                List<Integer> tmpList = new ArrayList<Integer>();
+                List<Integer> tmpList = new ArrayList<>();
                 for (int idx : patom.getMatchingAtoms())
                     tmpList.add(idx);
                 Point3d coords = getEffectiveCoordinates(atomContainer, tmpList);
@@ -427,9 +427,9 @@ public class PharmacophoreMatcher {
 
                 // make a list of the patoms in the target that match
                 // each type of angle atom
-                List<IAtom> startl = new ArrayList<IAtom>();
-                List<IAtom> middlel = new ArrayList<IAtom>();
-                List<IAtom> endl = new ArrayList<IAtom>();
+                List<IAtom> startl = new ArrayList<>();
+                List<IAtom> middlel = new ArrayList<>();
+                List<IAtom> endl = new ArrayList<>();
 
                 for (IAtom tatom : pharmacophoreMolecule.atoms()) {
                     if (tatom.getSymbol().equals(startQAtom.getSymbol())) startl.add(tatom);
@@ -439,7 +439,7 @@ public class PharmacophoreMatcher {
 
                 // now we form the relevant angles, but we will
                 // have reversed repeats
-                List<IAtom[]> tmpl = new ArrayList<IAtom[]>();
+                List<IAtom[]> tmpl = new ArrayList<>();
                 for (IAtom middle : middlel) {
                     for (IAtom start : startl) {
                         if (middle.equals(start)) continue;
@@ -451,7 +451,7 @@ public class PharmacophoreMatcher {
                 }
 
                 // now clean up reversed repeats
-                List<IAtom[]> unique = new ArrayList<IAtom[]>();
+                List<IAtom[]> unique = new ArrayList<>();
                 for (int i = 0; i < tmpl.size(); i++) {
                     IAtom[] seq1 = tmpl.get(i);
                     boolean isRepeat = false;
@@ -544,7 +544,7 @@ public class PharmacophoreMatcher {
 
     private boolean checkQuery(IQueryAtomContainer query) {
         if (!(query instanceof PharmacophoreQuery)) return false;
-        HashMap<String, String> map = new HashMap<String, String>();
+        HashMap<String, String> map = new HashMap<>();
         for (int i = 0; i < query.getAtomCount(); i++) {
             IQueryAtom atom = (IQueryAtom) query.getAtom(i);
             if (!(atom instanceof PharmacophoreQueryAtom)) return false;
