@@ -37,7 +37,6 @@ import java.awt.geom.Line2D;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
-import java.util.Collections;
 import java.util.Comparator;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -247,7 +246,7 @@ final class LayoutRefiner {
         }
 
         // sort the pairs to attempt consistent overlap resolution (order independent)
-        Collections.sort(pairs, new Comparator<AtomPair>() {
+        pairs.sort(new Comparator<AtomPair>() {
             @Override
             public int compare(AtomPair a, AtomPair b) {
                 int a1 = atoms[a.fst].getProperty(AtomPlacer.PRIORITY);
@@ -259,18 +258,16 @@ final class LayoutRefiner {
                 if (a1 < a2) {
                     amin = a1;
                     amax = a2;
-                }
-                else {
+                } else {
                     amin = a2;
                     amax = a1;
                 }
                 if (b1 < b2) {
-                    bmin = a1;
-                    bmax = a2;
-                }
-                else {
-                    bmin = a2;
-                    bmax = a1;
+                    bmin = b1;
+                    bmax = b2;
+                } else {
+                    bmin = b2;
+                    bmax = b1;
                 }
                 int cmp = Integer.compare(amin, bmin);
                 if (cmp != 0) return cmp;
