@@ -35,12 +35,12 @@ import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IStereoElement;
 import org.openscience.cdk.interfaces.ITetrahedralChirality;
 import org.openscience.cdk.silent.Atom;
-import org.openscience.cdk.silent.AtomContainer;
 import org.openscience.cdk.silent.SilentChemObjectBuilder;
 import org.openscience.cdk.smiles.SmilesParser;
 import org.openscience.cdk.stereo.Atropisomeric;
 import org.openscience.cdk.stereo.DoubleBondStereochemistry;
 import org.openscience.cdk.stereo.ExtendedTetrahedral;
+import org.openscience.cdk.stereo.StereoElementFactory;
 import org.openscience.cdk.stereo.TetrahedralChirality;
 
 import javax.vecmath.Point2d;
@@ -62,7 +62,7 @@ class NonPlanarBondsTest {
     // [C@H](C)(N)O
     @Test
     void clockwise_implH_1() {
-        IAtomContainer m = new AtomContainer(4, 3, 0, 0);
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("C", 1, 0.00d, 1.50d));
         m.addAtom(atom("C", 3, 0.00d, 0.00d));
         m.addAtom(atom("N", 2, -1.30d, 2.25d));
@@ -82,7 +82,7 @@ class NonPlanarBondsTest {
     // N is favoured over CC
     @Test
     void clockwise_implH_2() {
-        IAtomContainer m = new AtomContainer(5, 4, 0, 0);
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("C", 1, -1.30d, 2.25d));
         m.addAtom(atom("C", 2, 0.00d, 1.50d));
         m.addAtom(atom("C", 3, 0.00d, 0.00d));
@@ -104,7 +104,7 @@ class NonPlanarBondsTest {
     // [C@H](C)(N)O
     @Test
     void anticlockwise_implH_1() {
-        IAtomContainer m = new AtomContainer(4, 3, 0, 0);
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("C", 1, 0.00d, 1.50d));
         m.addAtom(atom("C", 3, 0.00d, 0.00d));
         m.addAtom(atom("N", 2, -1.30d, 2.25d));
@@ -124,7 +124,7 @@ class NonPlanarBondsTest {
     // N is favoured over CC
     @Test
     void anticlockwise_implH_2() {
-        IAtomContainer m = new AtomContainer(5, 4, 0, 0);
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("C", 1, -1.30d, 2.25d));
         m.addAtom(atom("C", 2, 0.00d, 1.50d));
         m.addAtom(atom("C", 3, 0.00d, 0.00d));
@@ -146,7 +146,7 @@ class NonPlanarBondsTest {
     // [C@@](CCC)(C)(N)O
     @Test
     void clockwise_1() {
-        IAtomContainer m = new AtomContainer(7, 6, 0, 0);
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("C", 0, -1.47d, 3.62d));
         m.addAtom(atom("C", 2, -1.13d, 2.16d));
         m.addAtom(atom("C", 2, 0.30d, 1.72d));
@@ -172,7 +172,7 @@ class NonPlanarBondsTest {
     // [C@@](CCC)(C1)(C)C1 (favour acyclic)
     @Test
     void clockwise_2() {
-        IAtomContainer m = new AtomContainer(8, 8, 0, 0);
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("C", 0, -0.96d, -1.04d));
         m.addAtom(atom("C", 2, 0.18d, -0.08d));
         m.addAtom(atom("C", 2, -0.08d, 1.40d));
@@ -201,7 +201,7 @@ class NonPlanarBondsTest {
     // [C@](CCC)(C)(N)O
     @Test
     void anticlockwise_1() {
-        IAtomContainer m = new AtomContainer(7, 6, 0, 0);
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("C", 0, -1.47d, 3.62d));
         m.addAtom(atom("C", 2, -1.13d, 2.16d));
         m.addAtom(atom("C", 2, 0.30d, 1.72d));
@@ -227,7 +227,7 @@ class NonPlanarBondsTest {
     // [C@](CCC)(C1)(C)C1 (favour acyclic)
     @Test
     void anticlockwise_2() {
-        IAtomContainer m = new AtomContainer(8, 8, 0, 0);
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("C", 0, -0.96d, -1.04d));
         m.addAtom(atom("C", 2, 0.18d, -0.08d));
         m.addAtom(atom("C", 2, -0.08d, 1.40d));
@@ -255,7 +255,7 @@ class NonPlanarBondsTest {
 
     @Test
     void nonPlanarBondsForAntiClockwsieExtendedTetrahedral() throws CDKException {
-        IAtomContainer m = new AtomContainer(7, 6, 0, 0);
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("C", 3, -1.56d, 0.78d));
         m.addAtom(atom("C", 0, -1.13d, 1.49d));
         m.addAtom(atom("C", 0, -0.31d, 1.47d));
@@ -278,7 +278,7 @@ class NonPlanarBondsTest {
 
     @Test
     void nonPlanarBondsForClockwsieExtendedTetrahedral() throws CDKException {
-        IAtomContainer m = new AtomContainer(7, 6, 0, 0);
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("C", 3, -1.56d, 0.78d));
         m.addAtom(atom("C", 0, -1.13d, 1.49d));
         m.addAtom(atom("C", 0, -0.31d, 1.47d));
@@ -301,7 +301,7 @@ class NonPlanarBondsTest {
 
     @Test
     void clockwiseSortShouldHandleExactlyOppositeAtoms() throws Exception {
-        IAtomContainer m = new AtomContainer(8, 7, 0, 0);
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("C", 0, 4.50d, -14.84d));
         m.addAtom(atom("C", 3, 4.51d, -13.30d));
         m.addAtom(atom("C", 2, 4.93d, -14.13d));
@@ -322,12 +322,12 @@ class NonPlanarBondsTest {
         NonplanarBonds.assign(m);
         assertThat(m.getBond(2).getStereo(), is(IBond.Stereo.UP));
     }
-    
-    
+
+
     // ethene is left alone and not marked as crossed
     @Test
     void dontCrossEtheneDoubleBond() {
-        IAtomContainer m = new AtomContainer();
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("C", 2, 0.000, 0.000));
         m.addAtom(atom("C", 2, 1.299, -0.750));
         m.addBond(0, 1, IBond.Order.DOUBLE);
@@ -340,7 +340,7 @@ class NonPlanarBondsTest {
      */
     @Test
     void dontMarkTerminalBonds() {
-        IAtomContainer m = new AtomContainer();
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("C", 3, 0.000, 0.000));
         m.addAtom(atom("C", 0, 1.299, -0.750));
         m.addAtom(atom("C", 2, 2.598, -0.000));
@@ -361,7 +361,7 @@ class NonPlanarBondsTest {
      */
     @Test
     void markBut2eneWithWavyBond() {
-        IAtomContainer m = new AtomContainer();
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("C", 3, 0.000, 0.000));
         m.addAtom(atom("C", 1, 1.299, -0.750));
         m.addAtom(atom("C", 1, 2.598, -0.000));
@@ -378,7 +378,7 @@ class NonPlanarBondsTest {
      */
     @Test
     void useCrossedBondIfNeeded() {
-        IAtomContainer m = new AtomContainer();
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("C", 3, 0.000, 0.000));
         m.addAtom(atom("C", 1, 1.299, -0.750));
         m.addAtom(atom("C", 1, 2.598, -0.000));
@@ -411,11 +411,11 @@ class NonPlanarBondsTest {
     }
 
     /**
-     * @cdk.inchi InChI=1S/C6H14S/c1-5-7(4)6(2)3/h5H2,1-4H3/t7-/m0/s1 
-     */                                                                  
+     * @cdk.inchi InChI=1S/C6H14S/c1-5-7(4)6(2)3/h5H2,1-4H3/t7-/m0/s1
+     */
     @Test
     void dontMarkTetrahedralCentresWithDoubleBondsAsUnspecified() {
-        IAtomContainer m = new AtomContainer();
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("C", 3, 2.598, 1.500));
         m.addAtom(atom("S", 0, 2.598, -0.000));
         m.addAtom(atom("C", 1, 1.299, -0.750));
@@ -436,10 +436,10 @@ class NonPlanarBondsTest {
         assertThat(m.getBond(2).getStereo(), is(not(IBond.Stereo.UP_OR_DOWN)));
         assertThat(m.getBond(3).getStereo(), is(not(IBond.Stereo.UP_OR_DOWN)));
     }
-    
+
     @Test
     void dontMarkRingBondsInBezeneAsUnspecified() {
-        IAtomContainer m = new AtomContainer();
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("C", 1, -1.299, 0.750));
         m.addAtom(atom("C", 1, 0.000, 1.500));
         m.addAtom(atom("C", 1, 1.299, 0.750));
@@ -454,7 +454,7 @@ class NonPlanarBondsTest {
         m.addBond(0, 5, IBond.Order.SINGLE);
         NonplanarBonds.assign(m);
         for (IBond bond : m.bonds()) {
-            assertThat(bond.getStereo(), is(IBond.Stereo.NONE));   
+            assertThat(bond.getStereo(), is(IBond.Stereo.NONE));
         }
     }
 
@@ -463,7 +463,7 @@ class NonPlanarBondsTest {
      */
     @Test
     void dontMarkGuanidineAsUnspecified() {
-        IAtomContainer m = new AtomContainer();
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("R", 0, 0.00, 0.00));
         m.addAtom(atom("C", 2, 1.30, -0.75));
         m.addAtom(atom("N", 0, 2.60, -0.00));
@@ -485,7 +485,7 @@ class NonPlanarBondsTest {
      */
     @Test
     void dontUnspecifiedDueToHRepresentation() {
-        IAtomContainer m = new AtomContainer();
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("R", 0, 0.00, 0.00));
         m.addAtom(atom("C", 2, 1.30, -0.75));
         m.addAtom(atom("N", 0, 2.60, -0.00));
@@ -517,7 +517,7 @@ class NonPlanarBondsTest {
      */
     @Test
     void dontMarkUnspecifiedForLinearEqualChains() {
-        IAtomContainer m = new AtomContainer();
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("R", 0, 0.00, -0.00));
         m.addAtom(atom("C", 2, 1.30, -0.75));
         m.addAtom(atom("N", 0, 2.60, -0.00));
@@ -547,7 +547,7 @@ class NonPlanarBondsTest {
      */
     @Test
     void markUnspecifiedForCyclicLigands() {
-        IAtomContainer m = new AtomContainer();
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("R", 0, -4.22, 3.05));
         m.addAtom(atom("C", 2, -2.92, 2.30));
         m.addAtom(atom("N", 0, -1.62, 3.05));
@@ -572,7 +572,7 @@ class NonPlanarBondsTest {
         for (IBond bond : m.bonds())
             if (bond.getStereo() == IBond.Stereo.UP_OR_DOWN)
                 wavyCount++;
-        assertThat(wavyCount, is(1));
+        assertThat(wavyCount, is(0));
     }
 
     /**
@@ -580,7 +580,7 @@ class NonPlanarBondsTest {
      */
     @Test
     void unspecifiedMarkedOnDifferentLigands() {
-        IAtomContainer m = new AtomContainer();
+        IAtomContainer m = SilentChemObjectBuilder.getInstance().newAtomContainer();
         m.addAtom(atom("R", 0, 0.00, -0.00));
         m.addAtom(atom("C", 2, 1.30, -0.75));
         m.addAtom(atom("N", 0, 2.60, -0.00));
@@ -644,8 +644,8 @@ class NonPlanarBondsTest {
         SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
         IAtomContainer mol = smipar.parseSmiles("OC1=CC=C2C=CC=CC2=C1C1=C(O)C=CC2=C1C=CC=C2");
 
-        IBond       focus    = mol.getBond(mol.getAtom(10),
-                                           mol.getAtom(11));
+        IBond focus = mol.getBond(mol.getAtom(10),
+                                  mol.getAtom(11));
         List<IAtom> carriers = new ArrayList<>();
         carriers.addAll(mol.getConnectedAtomsList(focus.getBegin()));
         carriers.addAll(mol.getConnectedAtomsList(focus.getEnd()));
@@ -664,7 +664,7 @@ class NonPlanarBondsTest {
         assertThat(bond2.getOrder(), is(IBond.Order.SINGLE));
 
         Assertions.assertTrue(bond1.getStereo() == IBond.Stereo.DOWN ||
-        bond2.getStereo() == IBond.Stereo.DOWN, "One of the single bonds should have been wedged");
+                                      bond2.getStereo() == IBond.Stereo.DOWN, "One of the single bonds should have been wedged");
 
     }
 
@@ -674,7 +674,7 @@ class NonPlanarBondsTest {
             final String smi = "O[C@]([H])(C)CCC";
             SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
             IAtomContainer mol = smipar.parseSmiles(smi);
-            mol.removeBond(1);
+            // mol.removeBond(1); // updates stereo correctly!
             mol.removeAtomOnly(2); // unsafe-removes
             StructureDiagramGenerator sdg = new StructureDiagramGenerator();
             sdg.generateCoordinates(mol);
@@ -775,4 +775,90 @@ class NonPlanarBondsTest {
         return a;
     }
 
+    @Test
+    void testColinearD3bonds() throws CDKException {
+        SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
+        IAtomContainer mol = smipar.parseSmiles("[C@@H]12[C@@H]([C@H]([C@@H]([C@@H](CO1)O2)O)O)O |(1.3,0.1,;1.3,-1.4,;0.01,-2.15,;-1.29,-1.4,;-1.29,0.1,;-1.29,1.95,;1.26,1.93,;0.01,0.85,;-2.59,-2.15,;0.01,-3.65,;2.6,-2.15,)|");
+        NonplanarBonds.assign(mol);
+        // there are 4
+        Assertions.assertEquals(5,
+                                StereoElementFactory.using2DCoordinates(mol).withStrictMode().createAll().size());
+    }
+
+    @Test
+    void wavyBondNeeded() throws CDKException {
+        final String smi = "C1CC(=C(O)(C))COC1";
+        SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
+        IAtomContainer mol = smipar.parseSmiles(smi);
+        StructureDiagramGenerator sdg = new StructureDiagramGenerator();
+        sdg.generateCoordinates(mol);
+        int count = 0;
+        for (IBond bond : mol.bonds()) {
+            switch (bond.getStereo()) {
+                case UP_OR_DOWN:
+                case UP_OR_DOWN_INVERTED:
+                    ++count;
+                    break;
+            }
+        }
+        assertThat(count, is(1));
+    }
+
+    @Test
+    void wavyBondNotNeeded() throws CDKException {
+        final String smi = "C1CC(=C(O)(C))CCC1";
+        SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
+        IAtomContainer mol = smipar.parseSmiles(smi);
+        StructureDiagramGenerator sdg = new StructureDiagramGenerator();
+        sdg.generateCoordinates(mol);
+        int count = 0;
+        for (IBond bond : mol.bonds()) {
+            switch (bond.getStereo()) {
+                case UP_OR_DOWN:
+                case UP_OR_DOWN_INVERTED:
+                    ++count;
+                    break;
+            }
+        }
+        assertThat(count, is(0));
+    }
+
+    @Test
+    void wavyBondNeeded2() throws CDKException {
+        final String smi = "CC=C(C/C=C/C)C/C=C\\C";
+        SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
+        IAtomContainer mol = smipar.parseSmiles(smi);
+        StructureDiagramGenerator sdg = new StructureDiagramGenerator();
+        sdg.generateCoordinates(mol);
+        int count = 0;
+        for (IBond bond : mol.bonds()) {
+            switch (bond.getStereo()) {
+                case UP_OR_DOWN:
+                case UP_OR_DOWN_INVERTED:
+                    ++count;
+                    break;
+            }
+        }
+        assertThat(count, is(1));
+    }
+
+    @Test
+    void wavyBondNotNeeded2() throws CDKException {
+        final String smi = "CC=C(C/C=C/C)C/C=C/C";
+        SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
+        IAtomContainer mol = smipar.parseSmiles(smi);
+        StructureDiagramGenerator sdg = new StructureDiagramGenerator();
+        sdg.generateCoordinates(mol);
+        int count = 0;
+        for (IBond bond : mol.bonds()) {
+            switch (bond.getStereo()) {
+                case UP_OR_DOWN:
+                case UP_OR_DOWN_INVERTED:
+                    ++count;
+                    break;
+            }
+        }
+        assertThat(count, is(0));
+    }
+
 }
