@@ -23,17 +23,15 @@
 
 package org.openscience.cdk.smarts;
 
-import org.hamcrest.CoreMatchers;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.config.Elements;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.isomorphism.matchers.Expr;
 import org.openscience.cdk.isomorphism.matchers.QueryAtomContainer;
-import org.openscience.cdk.smarts.Smarts;
 import org.openscience.cdk.tools.manipulator.AtomContainerManipulator;
 
-import static junit.framework.TestCase.assertTrue;
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.openscience.cdk.isomorphism.matchers.Expr.Type.ALIPHATIC_ELEMENT;
@@ -58,7 +56,7 @@ import static org.openscience.cdk.isomorphism.matchers.Expr.Type.TOTAL_DEGREE;
 import static org.openscience.cdk.isomorphism.matchers.Expr.Type.TOTAL_H_COUNT;
 import static org.openscience.cdk.isomorphism.matchers.Expr.Type.VALENCE;
 
-public class SmartsExprWriteTest {
+class SmartsExprWriteTest {
 
     static Expr expr(Expr.Type type) {
         return new Expr(type);
@@ -77,7 +75,8 @@ public class SmartsExprWriteTest {
     }
 
     // C&r6 not Cr
-    @Test public void useExplAnd1() {
+    @Test
+    void useExplAnd1() {
         Expr expr = new Expr(ALIPHATIC_ELEMENT, 6).and(
             new Expr(RING_SMALLEST, 6)
         );
@@ -85,7 +84,8 @@ public class SmartsExprWriteTest {
     }
 
     // D&2 not D2
-    @Test public void useExplAnd2() {
+    @Test
+    void useExplAnd2() {
         Expr expr = new Expr(DEGREE, 1).and(
             new Expr(ISOTOPE, 2)
         );
@@ -93,53 +93,63 @@ public class SmartsExprWriteTest {
     }
 
     // aromatic or aliphatic
-    @Test public void carbon() {
+    @Test
+    void carbon() {
         Expr expr = new Expr(ELEMENT, 6);
         assertThat(Smarts.generateAtom(expr), is("[#6]"));
     }
 
     // helium can't be aromatic so we can always use the symbol
-    @Test public void helium() {
+    @Test
+    void helium() {
         Expr expr = new Expr(ELEMENT, 2);
         assertThat(Smarts.generateAtom(expr), is("[He]"));
     }
 
-    @Test public void degree() {
+    @Test
+    void degree() {
         assertThat(Smarts.generateAtom(expr(DEGREE, 1)), is("[D]"));
         assertThat(Smarts.generateAtom(expr(DEGREE, 2)), is("[D2]"));
     }
 
     // can sometimes write just 'H' but a lot of effort to figure out when
-    @Test public void totalHCount() {
+    @Test
+    void totalHCount() {
         assertThat(Smarts.generateAtom(expr(TOTAL_H_COUNT, 1)), is("[H1]"));
         assertThat(Smarts.generateAtom(expr(TOTAL_H_COUNT, 2)), is("[H2]"));
     }
 
-    @Test public void connectivity() {
+    @Test
+    void connectivity() {
         assertThat(Smarts.generateAtom(expr(TOTAL_DEGREE, 1)), is("[X]"));
         assertThat(Smarts.generateAtom(expr(TOTAL_DEGREE, 2)), is("[X2]"));
     }
 
-    @Test public void ringMembership() {
+    @Test
+    void ringMembership() {
         assertThat(Smarts.generateAtom(expr(IS_IN_RING)), is("[R]"));
         assertThat(Smarts.generateAtom(expr(IS_IN_CHAIN)), is("[!R]"));
     }
 
-    @Test public void ringCount() {
+    @Test
+    void ringCount() {
         assertThat(Smarts.generateAtom(expr(RING_COUNT, 2)), is("[R2]"));
     }
 
-    @Test public void ringSmallest() {
+    @Test
+    void ringSmallest() {
         assertThat(Smarts.generateAtom(expr(RING_SMALLEST, 4)), is("[r4]"));
     }
 
-    @Test public void isotopes() {
+    @Test
+    void isotopes() {
         assertThat(Smarts.generateAtom(expr(ISOTOPE, 13)), is("[13]"));
         assertThat(Smarts.generateAtom(expr(HAS_UNSPEC_ISOTOPE)), is("[0]"));
         assertThat(Smarts.generateAtom(expr(HAS_ISOTOPE)), is("[!0]"));
     }
 
-    @Test public void formalCharges() {
+    @Test
+    void formalCharges() {
         assertThat(Smarts.generateAtom(expr(FORMAL_CHARGE, -2)), is("[-2]"));
         assertThat(Smarts.generateAtom(expr(FORMAL_CHARGE, -1)), is("[-]"));
         assertThat(Smarts.generateAtom(expr(FORMAL_CHARGE, 0)), is("[+0]"));
@@ -147,12 +157,14 @@ public class SmartsExprWriteTest {
         assertThat(Smarts.generateAtom(expr(FORMAL_CHARGE, 2)), is("[+2]"));
     }
 
-    @Test public void valence() {
+    @Test
+    void valence() {
         assertThat(Smarts.generateAtom(expr(VALENCE, 1)), is("[v]"));
         assertThat(Smarts.generateAtom(expr(VALENCE, 2)), is("[v2]"));
     }
 
-    @Test public void atomicNum() {
+    @Test
+    void atomicNum() {
         assertThat(Smarts.generateAtom(expr(ELEMENT, 0)), is("[#0]"));
         assertThat(Smarts.generateAtom(expr(ALIPHATIC_ELEMENT, 0)), is("[#0]"));
         assertThat(Smarts.generateAtom(expr(AROMATIC_ELEMENT, 0)), is("[#0]"));
@@ -179,7 +191,8 @@ public class SmartsExprWriteTest {
 
     // Ds, Ts and Nh etc can be ambiguous - we write anything above radon as
     // '#<num>'
-    @Test public void atomicNumHighWeightElements() {
+    @Test
+    void atomicNumHighWeightElements() {
         assertThat(Smarts.generateAtom(expr(ELEMENT, Elements.Darmstadtium.number())),
                    is("[#110]"));
         assertThat(Smarts.generateAtom(expr(ELEMENT, Elements.Tennessine.number())),
@@ -194,19 +207,22 @@ public class SmartsExprWriteTest {
                    is("[#113]"));
     }
 
-    @Test public void aromaticElement() {
+    @Test
+    void aromaticElement() {
         assertThat(Smarts.generateAtom(expr(AROMATIC_ELEMENT, 6)), is("c"));
         assertThat(Smarts.generateAtom(expr(AROMATIC_ELEMENT, 7)), is("n"));
     }
 
-    @Test public void useLowPrecedenceAnd() {
+    @Test
+    void useLowPrecedenceAnd() {
         Expr expr = new Expr(ELEMENT, 8).and(
             new Expr(DEGREE, 2).or(
                 new Expr(DEGREE, 1)));
         assertThat(Smarts.generateAtom(expr), is("[#8;D2,D]"));
     }
 
-    @Test public void useImplAnd() {
+    @Test
+    void useImplAnd() {
         Expr expr = new Expr(AROMATIC_ELEMENT, 7).and(
             new Expr(DEGREE, 2).and(
                 new Expr(HAS_IMPLICIT_HYDROGEN)));
@@ -214,7 +230,8 @@ public class SmartsExprWriteTest {
     }
 
     // logical under a negate needs to be recursive
-    @Test public void usrRecrNot() {
+    @Test
+    void usrRecrNot() {
         Expr expr = new Expr(ELEMENT, 9)
             .or(new Expr(ELEMENT, 17))
             .or(new Expr(ELEMENT, 35))
@@ -223,7 +240,8 @@ public class SmartsExprWriteTest {
     }
 
     // or -> and -> or needs to be recursive
-    @Test public void usrRecrOr() {
+    @Test
+    void usrRecrOr() {
         Expr expr = or(and(or(expr(ELEMENT, 6),
                               expr(ELEMENT, 7)),
                            expr(IS_IN_RING)),
@@ -232,128 +250,148 @@ public class SmartsExprWriteTest {
                           is("[$([#6,#7])R,a]"));
     }
 
-    @Test public void singleOrDouble() {
+    @Test
+    void singleOrDouble() {
         Expr expr = new Expr(ALIPHATIC_ORDER, 1)
             .or(new Expr(ALIPHATIC_ORDER, 2));
         assertThat(Smarts.generateBond(expr), is("-,="));
     }
 
-    @Test public void singleOrDoubleInRing() {
+    @Test
+    void singleOrDoubleInRing() {
         Expr expr = new Expr(IS_IN_RING)
             .and(new Expr(ALIPHATIC_ORDER, 1)
                       .or(new Expr(ALIPHATIC_ORDER, 2)));
         assertThat(Smarts.generateBond(expr), is("@;-,="));
     }
 
-    @Test public void singleOrDoubleInRing2() {
+    @Test
+    void singleOrDoubleInRing2() {
         Expr expr = new Expr(IS_IN_RING)
             .and(new Expr(SINGLE_OR_DOUBLE));
         assertThat(Smarts.generateBond(expr), is("@;-,="));
     }
 
-    @Test public void indoleRoundTrip() {
+    @Test
+    void indoleRoundTrip() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "n1ccc2c1cccc2"));
+        Assertions.assertTrue(Smarts.parse(mol, "n1ccc2c1cccc2"));
         // CDK choice of data structures lose local arrangement but
         // output is still indole
         assertThat(Smarts.generate(mol), is("n1c2c(cc1)cccc2"));
     }
 
-    @Test public void indoleWithExprRoundTrip() {
+    @Test
+    void indoleWithExprRoundTrip() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "[n;$(*C),$(*OC)]1ccc2c1cccc2"));
+        Assertions.assertTrue(Smarts.parse(mol, "[n;$(*C),$(*OC)]1ccc2c1cccc2"));
         // CDK choice of data structures lose local arrangement but
         // output is still indole
         assertThat(Smarts.generate(mol), is("[n;$(*C),$(*OC)]1c2c(cc1)cccc2"));
     }
 
-    @Test public void bondTrue() {
+    @Test
+    void bondTrue() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C~C~N(~O)~O"));
+        Assertions.assertTrue(Smarts.parse(mol, "C~C~N(~O)~O"));
         assertThat(Smarts.generate(mol), is("C~C~N(~O)~O"));
     }
 
-    @Test public void bondFalse() {
+    @Test
+    void bondFalse() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C!~C"));
+        Assertions.assertTrue(Smarts.parse(mol, "C!~C"));
         assertThat(Smarts.generate(mol), is("C!~C"));
     }
 
-    @Test public void bondInChain() {
+    @Test
+    void bondInChain() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C!@C"));
+        Assertions.assertTrue(Smarts.parse(mol, "C!@C"));
         assertThat(Smarts.generate(mol), is("C!@C"));
     }
 
-    @Test public void bondInRing() {
+    @Test
+    void bondInRing() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C@C"));
+        Assertions.assertTrue(Smarts.parse(mol, "C@C"));
         assertThat(Smarts.generate(mol), is("C@C"));
     }
 
-    @Test public void tripleBond() {
+    @Test
+    void tripleBond() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C#C"));
+        Assertions.assertTrue(Smarts.parse(mol, "C#C"));
         assertThat(Smarts.generate(mol), is("C#C"));
     }
 
-    @Test public void notTripleBond() {
+    @Test
+    void notTripleBond() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C!#C"));
+        Assertions.assertTrue(Smarts.parse(mol, "C!#C"));
         assertThat(Smarts.generate(mol), is("C!#C"));
     }
 
-    @Test public void aromaticBond() {
+    @Test
+    void aromaticBond() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "[#6]:[#6]"));
+        Assertions.assertTrue(Smarts.parse(mol, "[#6]:[#6]"));
         assertThat(Smarts.generate(mol), is("[#6]:[#6]"));
     }
 
-    @Test public void ringClosureExprs() {
+    @Test
+    void ringClosureExprs() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C1CCCC-,=1"));
+        Assertions.assertTrue(Smarts.parse(mol, "C1CCCC-,=1"));
         assertThat(Smarts.generate(mol), is("C1-,=CCCC1"));
     }
 
-    @Test public void ringClosureExprs2() {
+    @Test
+    void ringClosureExprs2() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C-,=1CCCC1"));
+        Assertions.assertTrue(Smarts.parse(mol, "C-,=1CCCC1"));
         assertThat(Smarts.generate(mol), is("C1-,=CCCC1"));
     }
 
-    @Test public void ringClosureExprs3() {
+    @Test
+    void ringClosureExprs3() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C1-,=CCCC1"));
+        Assertions.assertTrue(Smarts.parse(mol, "C1-,=CCCC1"));
         assertThat(Smarts.generate(mol), is("C1CCCC-,=1"));
     }
 
-    @Test public void reaction() {
+    @Test
+    void reaction() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "c1ccccc1[NH2]>>c1ccccc1N(~O)~O"));
+        Assertions.assertTrue(Smarts.parse(mol, "c1ccccc1[NH2]>>c1ccccc1N(~O)~O"));
         assertThat(Smarts.generate(mol), is("c1c(cccc1)[NH2]>>c1c(cccc1)N(~O)~O"));
     }
 
-    @Test public void reactionWithMaps() {
+    @Test
+    void reactionWithMaps() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "c1cccc[c:1]1[NH2:2]>>c1cccc[c:1]1[N:2](~O)~O"));
+        Assertions.assertTrue(Smarts.parse(mol, "c1cccc[c:1]1[NH2:2]>>c1cccc[c:1]1[N:2](~O)~O"));
         assertThat(Smarts.generate(mol), is("c1[c:1](cccc1)[NH2:2]>>c1[c:1](cccc1)[N:2](~O)~O"));
     }
 
-    @Test public void compGrouping() {
+    @Test
+    void compGrouping() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "([Na+].[Cl-]).c1ccccc1"));
+        Assertions.assertTrue(Smarts.parse(mol, "([Na+].[Cl-]).c1ccccc1"));
         assertThat(Smarts.generate(mol), is("c1ccccc1.([Na+].[Cl-])"));
     }
 
-    @Test public void compGroupingOnAgent() {
+    @Test
+    void compGroupingOnAgent() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, ">(c1ccccc1[O-].[Na+])>"));
+        Assertions.assertTrue(Smarts.parse(mol, ">(c1ccccc1[O-].[Na+])>"));
         assertThat(Smarts.generate(mol), is(">(c1c(cccc1)[O-].[Na+])>"));
     }
 
-    @Test public void atomStereo() {
+    @Test
+    void atomStereo() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C[C@H](O)CC"));
+        Assertions.assertTrue(Smarts.parse(mol, "C[C@H](O)CC"));
         assertThat(Smarts.generate(mol), is("C[C@H1](O)CC"));
     }
 
@@ -363,42 +401,47 @@ public class SmartsExprWriteTest {
         a[j] = tmp;
     }
 
-    @Test public void atomStereoReordered() {
+    @Test
+    void atomStereoReordered() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C[C@H](O)CC"));
+        Assertions.assertTrue(Smarts.parse(mol, "C[C@H](O)CC"));
         IBond[] bonds = AtomContainerManipulator.getBondArray(mol);
         swap(bonds, 1, 2);
         mol.setBonds(bonds);
         assertThat(Smarts.generate(mol), is("C[C@@H1](CC)O"));
     }
 
-    @Test public void atomStereoReordered2() {
+    @Test
+    void atomStereoReordered2() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C[C@H](O)CC"));
+        Assertions.assertTrue(Smarts.parse(mol, "C[C@H](O)CC"));
         IAtom[] atoms = AtomContainerManipulator.getAtomArray(mol);
         swap(atoms, 0, 1);
         mol.setAtoms(atoms);
         assertThat(Smarts.generate(mol), is("[C@@H1](C)(O)CC"));
     }
 
-    @Test public void atomStereoReordered3() {
+    @Test
+    void atomStereoReordered3() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "[C@H](C)(O)CC"));
+        Assertions.assertTrue(Smarts.parse(mol, "[C@H](C)(O)CC"));
         IAtom[] atoms = AtomContainerManipulator.getAtomArray(mol);
         swap(atoms, 0, 1);
         mol.setAtoms(atoms);
         assertThat(Smarts.generate(mol), is("C[C@@H1](O)CC"));
     }
 
-    @Test public void atomStereoOrUnspec() {
+    @Test
+    void atomStereoOrUnspec() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C[C@?H](O)CC"));
+        Assertions.assertTrue(Smarts.parse(mol, "C[C@?H](O)CC"));
         assertThat(Smarts.generate(mol), is("C[CH1@?](O)CC"));
     }
 
-    @Test public void bondStereoTrans() {
+    @Test
+    void bondStereoTrans() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C/C=C/C"));
+        Assertions.assertTrue(Smarts.parse(mol, "C/C=C/C"));
         assertThat(Smarts.generate(mol), is("C/C=C/C"));
         IAtom[] atoms = AtomContainerManipulator.getAtomArray(mol);
         swap(atoms, 0, 1);
@@ -406,57 +449,64 @@ public class SmartsExprWriteTest {
         assertThat(Smarts.generate(mol), is("C(\\C)=C/C"));
     }
 
-    @Test public void bondStereoCisTrans() {
+    @Test
+    void bondStereoCisTrans() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C/C=C/,\\C"));
+        Assertions.assertTrue(Smarts.parse(mol, "C/C=C/,\\C"));
         assertThat(Smarts.generate(mol), is("C/C=C/,\\C"));
     }
 
-    @Test public void bondStereoCisUnspec() {
+    @Test
+    void bondStereoCisUnspec() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C/C=C\\?C"));
+        Assertions.assertTrue(Smarts.parse(mol, "C/C=C\\?C"));
         assertThat(Smarts.generate(mol), is("C/C=C\\?C"));
         // not trans same as cis/unspec
         mol.removeAllElements();
-        assertTrue(Smarts.parse(mol, "C/C=C!/C"));
+        Assertions.assertTrue(Smarts.parse(mol, "C/C=C!/C"));
         assertThat(Smarts.generate(mol), is("C/C=C\\?C"));
     }
 
-    @Test public void bondStereoTransUnspec() {
+    @Test
+    void bondStereoTransUnspec() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C/?C=C/C"));
+        Assertions.assertTrue(Smarts.parse(mol, "C/?C=C/C"));
         assertThat(Smarts.generate(mol), is("C/C=C/?C"));
         // not cis same as trans/unspec
         mol.removeAllElements();
-        assertTrue(Smarts.parse(mol, "C/C=C!\\C"));
+        Assertions.assertTrue(Smarts.parse(mol, "C/C=C!\\C"));
         assertThat(Smarts.generate(mol), is("C/C=C/?C"));
     }
 
     // unspecified db can be written as either /?\\? or !/!\\
-    @Test public void bondStereoUnspec() {
+    @Test
+    void bondStereoUnspec() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C/C=C/?\\?C"));
+        Assertions.assertTrue(Smarts.parse(mol, "C/C=C/?\\?C"));
         assertThat(Smarts.generate(mol), is("C/C=C!/!\\C"));
     }
 
     // here we have one bond symbol shared between two stereo
     // bonds, changing it's affects both stereos
-    @Test public void bondStereoCisThenTrans() {
+    @Test
+    void bondStereoCisThenTrans() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C/C=C\\C=C\\C"));
+        Assertions.assertTrue(Smarts.parse(mol, "C/C=C\\C=C\\C"));
         assertThat(Smarts.generate(mol), is("C/C=C\\C=C\\C"));
     }
 
     // make sure we set the bond direction on the correct neighbor
-    @Test public void bondStereoCisThenTransWithNbr() {
+    @Test
+    void bondStereoCisThenTransWithNbr() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C/C=C(C)\\C=C\\C"));
+        Assertions.assertTrue(Smarts.parse(mol, "C/C=C(C)\\C=C\\C"));
         assertThat(Smarts.generate(mol), is("C/C=C(C)\\C=C\\C"));
     }
 
-    @Test public void bondStereoCisThenTransUnspecWithNbr() {
+    @Test
+    void bondStereoCisThenTransUnspecWithNbr() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C/C=C(C)\\C=C\\?O"));
+        Assertions.assertTrue(Smarts.parse(mol, "C/C=C(C)\\C=C\\?O"));
         assertThat(Smarts.generate(mol), is("C/C=C(C)\\C=C\\?O"));
         IAtom[] atoms = AtomContainerManipulator.getAtomArray(mol);
         swap(atoms, 0, atoms.length-1);
@@ -467,28 +517,32 @@ public class SmartsExprWriteTest {
     // this case is tricky, we need to set the non-query bond stereo
     // first then the 'or unspecified' one otherwise we would initially
     // set 'C/C=C(C)/?C=CO' and there is no way to set the other bond
-    @Test public void bondStereoCisThenTransUnspecWithNbrComplex() {
+    @Test
+    void bondStereoCisThenTransUnspecWithNbrComplex() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C/?C=C(C)\\C=C\\O"));
+        Assertions.assertTrue(Smarts.parse(mol, "C/?C=C(C)\\C=C\\O"));
         assertThat(Smarts.generate(mol), is("C/?C=C(C)/C=C/O"));
     }
 
     // multiple calls to parse should set the stereo correctly and
     // put the queries in a single atom container
-    @Test public void multipleReads() {
+    @Test
+    void multipleReads() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
-        assertTrue(Smarts.parse(mol, "C/C=C/C"));
-        assertTrue(Smarts.parse(mol, "C/C=C\\C"));
+        Assertions.assertTrue(Smarts.parse(mol, "C/C=C/C"));
+        Assertions.assertTrue(Smarts.parse(mol, "C/C=C\\C"));
         assertThat(Smarts.generate(mol), is("C/C=C/C.C/C=C\\C"));
     }
 
-    @Test public void roundTripStereo() {
+    @Test
+    void roundTripStereo() {
         QueryAtomContainer mol = new QueryAtomContainer(null);
         Smarts.parse(mol, "O1.[S@]=1(C)CC");
         assertThat(Smarts.generate(mol), is("O=[S@@](C)CC"));
     }
 
-    @Test public void ringClosures() {
+    @Test
+    void ringClosures() {
         String sma = "C12=C3C4=C5C1=C1C6=C7C2=C2C8=C3C3=C9C4=C4C%10=C5C5=C1C1=C6C6=C%11C7=C2C2=C7C8=C3C3=C8C9=C4C4=C9C%10=C5C5=C1C1=C6C6=C%11C2=C2C7=C3C3=C8C4=C4C9=C5C1=C1C6=C2C3=C41";
         QueryAtomContainer mol = new QueryAtomContainer(null);
         Smarts.parse(mol, sma);
