@@ -32,6 +32,7 @@ import org.openscience.cdk.interfaces.IChemObjectBuilder;
 import org.openscience.cdk.interfaces.IReaction;
 import org.openscience.cdk.isomorphism.Mappings;
 import org.openscience.cdk.isomorphism.Pattern;
+import org.openscience.cdk.isomorphism.matchers.QueryAtomContainer;
 import org.openscience.cdk.silent.SilentChemObjectBuilder;
 import org.openscience.cdk.smiles.SmilesParser;
 
@@ -255,6 +256,136 @@ class SmartsPatternTest {
         assertMatch("[$([C@](C)(CC)(N)O)]", "CC(N)(CC)O", 0, 0);
     }
 
+    @Test
+    void testPrep() throws Exception {
+        IAtomContainer query = SilentChemObjectBuilder.getInstance().newAtomContainer();
+        Assertions.assertTrue(Smarts.parse(query, "*"));
+        Assertions.assertEquals(SmartsPattern.getRequiredPrep(query), 0);
+
+        query.removeAllElements();
+        Assertions.assertTrue(Smarts.parse(query, "a"));
+        Assertions.assertEquals(SmartsPattern.getRequiredPrep(query),
+                                SmartsPattern.AROM_REQUIRED);
+
+        query.removeAllElements();
+        Assertions.assertTrue(Smarts.parse(query, "*@*"));
+        Assertions.assertEquals(SmartsPattern.getRequiredPrep(query),
+                                SmartsPattern.RING_REQUIRED);
+
+        query.removeAllElements();
+        Assertions.assertTrue(Smarts.parse(query, "*!@*"));
+        Assertions.assertEquals(SmartsPattern.getRequiredPrep(query),
+                                SmartsPattern.RING_REQUIRED);
+
+        query.removeAllElements();
+        Assertions.assertTrue(Smarts.parse(query, "Cl"));
+        Assertions.assertEquals(SmartsPattern.getRequiredPrep(query),
+                                0);
+    }
+
+    @Test
+    void testOctahedralMatching() throws Exception {
+        // octahedral vs octahedral
+        // U
+        assertMatch("N[Co@OH1](Cl)(Cl)(Cl)(Cl)N",
+                    "N[Co@OH1](Cl)(Cl)(Cl)(Cl)N", 8, 1);
+        assertMatch("N[Co@OH2](Cl)(Cl)(Cl)(Cl)N",
+                    "N[Co@OH1](Cl)(Cl)(Cl)(Cl)N", 8, 1);
+        assertMatch("N[Co@OH1](Cl)(Cl)(Cl)(Cl)N",
+                    "N[Co@OH2](Cl)(Cl)(Cl)(Cl)N", 8, 1);
+        // Z
+        assertMatch("N[Co@OH1](Cl)(Cl)(Cl)(Cl)N",
+                    "N[Co@OH4](Cl)(Cl)(Cl)(Cl)N", 8, 1);
+        assertMatch("N[Co@OH1](Cl)(Cl)(Cl)(Cl)N",
+                    "N[Co@OH14](Cl)(Cl)(Cl)(Cl)N", 8, 1);
+        // 4
+        assertMatch("N[Co@OH1](Cl)(Cl)(Cl)(Cl)N",
+                    "N[Co@OH4](Cl)(Cl)(Cl)(Cl)N", 8, 1);
+        assertMatch("N[Co@OH10](Cl)(Cl)(Cl)(Cl)N",
+                    "N[Co@OH8](Cl)(Cl)(Cl)(Cl)N", 8, 1);
+        assertMatch("N[Co@OH1](Cl)(Cl)(Cl)(Cl)N",
+                    "N[Co@OH3](Cl)(Cl)(Cl)(Cl)N", 0, 0);
+        assertMatch("N[Co@OH1](Cl)(Cl)(Cl)(Cl)N",
+                    "N[Co@OH5](Cl)(Cl)(Cl)(Cl)N", 0, 0);
+        assertMatch("N[Co@OH1](Cl)(Cl)(Cl)(Cl)N",
+                    "N[Co@OH6](Cl)(Cl)(Cl)(Cl)N", 0, 0);
+        // ... and all the rest ...
+        assertMatch("N[Co@OH1](Cl)(Cl)(Cl)(Cl)N",
+                    "N[Co@OH29](Cl)(Cl)(Cl)(Cl)N", 0, 0);
+        assertMatch("N[Co@OH1](Cl)(Cl)(Cl)(Cl)N",
+                    "N[Co@OH30](Cl)(Cl)(Cl)(Cl)N", 0, 0);
+    }
+
+    @Test
+    void testDegenerateOctahedralMatching() throws Exception {
+        // trans-N-Co-N (match)
+        assertMatch("N[Co@OH1]N",
+                    "N[Co@OH1](Cl)(Cl)(Cl)(Cl)N", 2, 1);
+        assertMatch("N[Co@OH1]N",
+                    "N[Co@OH1]N", 2, 1);
+        assertMatch("N[Co@OH1]N",
+                    "N[Co@OH3]N", 0, 0);
+        // trans-N-Co-Cl (no match)
+        assertMatch("N[Co@OH1]Cl",
+                    "N[Co@OH1](Cl)(Cl)(Cl)(Cl)N", 0, 0);
+        // trans-Cl-Co-Cl
+        assertMatch("Cl[Co@OH1]Cl",
+                    "N[Co@OH1](Cl)(Cl)(Cl)(Cl)N", 4, 2);
+        // cis-N-Co-Cl
+        assertMatch("N[Co@OH3]Cl",
+                    "N[Co@OH1](Cl)(Cl)(Cl)(Cl)N", 8, 8);
+    }
+
+    @Test
+    void testOcVsTbpy() throws Exception {
+        // trans-N-Co-N (match)
+        assertMatch("N[Co@OH1]N",
+                    "N[Co@TB1](Cl)(Cl)(Cl)N", 2, 1);
+        assertMatch("N[Co@TB1]N",
+                    "N[Co@OH1]N", 2, 1);
+        assertMatch("N[Co@TB1]N",
+                    "N[Co@OH1](Cl)(Cl)(Cl)(Cl)N", 2, 1);
+        assertMatch("N[Co@TB1]N",
+                    "N[Co@SP3](Cl)(Cl)N", 2, 1);
+        assertMatch("N[Co@TB1](Cl)N",
+                    "N[Co@SP3](Cl)(Cl)N", 4, 2);
+        assertMatch("N[Co@TB1](Cl)N",
+                    "N[Co@OH1](Cl)(Cl)(Cl)(Cl)N", 8, 4);
+    }
+
+    @Test
+    void testSpVsOC() throws Exception {
+        assertMatch("N[Co@SP3](Cl)(Cl)N",
+                    "N[Co@SP3](Cl)(Cl)N", 4, 1);
+        assertMatch("N[Co@SP3](Cl)(Cl)N",
+                    "N[Co@OH1](Cl)(Cl)(Cl)(Cl)N", 8, 2);
+    }
+
+    // also implicit H! Cl[Pt@SP1H](F)Br
+    // C[Pt@SP2]([H])(F)Cl vs C[Pt@SP3](F)(Cl)[H] etc
+
+    @Test
+    void testSpVsSp() throws Exception {
+        assertMatch("C[Pt@SP2]([H])(F)Cl",
+                    "C[Pt@SP2]([H])(F)Cl", 1, 1);
+        assertMatch("C[Pt@SP2]([H])(F)Cl",
+                    "C[Pt@SP3](F)(Cl)[H]", 1, 1);
+        assertMatch("C[Pt@SP2]([H])(F)Cl",
+                    "*[Pt@OH8](C)([H])(F)(Cl)*", 1, 1);
+        assertMatch("C[Pt@SP2]([H])(F)Cl",
+                    "*[Pt@OH1](C)(F)([H])(Cl)*", 1, 1);
+        assertMatch("C[Pt@SP3](F)(Cl)[H]",
+                    "*[Pt@OH8](C)([H])(F)(Cl)*", 1, 1);
+        assertMatch("C[Pt@SP3](F)(Cl)[H]",
+                    "*[Pt@OH1](C)(F)([H])(Cl)*", 1, 1);
+    }
+
+    @Test
+    void testInsaturationOnTriple() throws Exception {
+        assertMatch("[Ci]~[Ci]O", "C#CO", 1, 1);
+        assertMatch("[Ci2]~[Ci2]O", "C#CO", 1, 1);
+    }
+
     IAtomContainer smi(String smi) throws Exception {
         return new SmilesParser(bldr).parseSmiles(smi);
     }
